# Overview

Dataset info

Number of variables | 242
Number of observations | 98393
Total Missing (%) | 62.3%
Total size in memory | 179.7 MiB
Average record size in memory | 1.9 KiB

Variables types

Numeric | 34
Categorical | 188
Date | 0
Text (Unique) | 0
Rejected | 20

Warnings

- `coordinates_coordinates` has 98068 / 99.7% missing values Missing
- `coordinates_coordinates` has a high cardinality: 184 distinct values Warning
- `coordinates_type` has 98068 / 99.7% missing values Missing
- `created_at` has a high cardinality: 89544 distinct values Warning
- `entities_hashtags` has a high cardinality: 20741 distinct values Warning
- `entities_media` has 75011 / 76.2% missing values Missing
- `entities_media` has a high cardinality: 13684 distinct values Warning
- `entities_urls` has 33879 / 34.4% missing values Missing
- `entities_urls` has a high cardinality: 29672 distinct values Warning
- `entities_user_mentions` has 2379 / 2.4% missing values Missing
- `entities_user_mentions` has a high cardinality: 16712 distinct values Warning
- `favorite_count` is highly skewed (γ1 = 95.43)
- `favorite_count` has 80852 / 82.2% zeros
- `favorited` has constant value False Rejected
- `geo_coordinates` has 98068 / 99.7% missing values Missing
- `geo_coordinates` has a high cardinality: 184 distinct values Warning
- `geo_type` has 98068 / 99.7% missing values Missing
- `id_str` is highly correlated with `id` (ρ = 1) Rejected
- `in_reply_to_screen_name` has 92226 / 93.7% missing values Missing
- `in_reply_to_screen_name` has a high cardinality: 4467 distinct values Warning
- `in_reply_to_status_id` is highly skewed (γ1 = -21.815)
- `in_reply_to_status_id` has 93099 / 94.6% missing values Missing
- `in_reply_to_status_id_str` is highly correlated with `in_reply_to_status_id` (ρ = 1) Rejected
- `in_reply_to_user_id` has 92226 / 93.7% missing values Missing
- `in_reply_to_user_id_str` is highly correlated with `in_reply_to_user_id` (ρ = 1) Rejected
- `is_quote_status` has 96191 / 97.8% zeros
- `lat` has 98068 / 99.7% missing values Missing
- `lon` has 98068 / 99.7% missing values Missing
- `metadata_result_type` has constant value recent Rejected
- `place_bounding_box_coordinates` has 97112 / 98.7% missing values Missing
- `place_bounding_box_coordinates` has a high cardinality: 607 distinct values Warning
- `place_bounding_box_type` has 97112 / 98.7% missing values Missing
- `place_contained_within` has 97112 / 98.7% missing values Missing
- `place_country` has 97221 / 98.8% missing values Missing
- `place_country_code` has 97115 / 98.7% missing values Missing
- `place_country_code` has a high cardinality: 71 distinct values Warning
- `place_full_name` has 97135 / 98.7% missing values Missing
- `place_full_name` has a high cardinality: 587 distinct values Warning
- `place_id` has 97112 / 98.7% missing values Missing
- `place_id` has a high cardinality: 609 distinct values Warning
- `place_name` has 97131 / 98.7% missing values Missing
- `place_name` has a high cardinality: 582 distinct values Warning
- `place_place_type` has 97112 / 98.7% missing values Missing
- `place_url` has 97112 / 98.7% missing values Missing
- `place_url` has a high cardinality: 609 distinct values Warning
- `possibly_sensitive` has 17708 / 18.0% missing values Missing
- `quoted_status_created_at` has 97639 / 99.2% missing values Missing
- `quoted_status_created_at` has a high cardinality: 663 distinct values Warning
- `quoted_status_entities_hashtags` has 97642 / 99.2% missing values Missing
- `quoted_status_entities_hashtags` has a high cardinality: 225 distinct values Warning
- `quoted_status_entities_symbols` has 97639 / 99.2% missing values Missing
- `quoted_status_entities_urls` has 97893 / 99.5% missing values Missing
- `quoted_status_entities_urls` has a high cardinality: 190 distinct values Warning
- `quoted_status_entities_user_mentions` has 97647 / 99.2% missing values Missing
- `quoted_status_entities_user_mentions` has a high cardinality: 195 distinct values Warning
- `quoted_status_favorite_count` has 97639 / 99.2% missing values Missing
- `quoted_status_favorited` has 97639 / 99.2% missing values Missing
- `quoted_status_id` has 1110 / 1.1% missing values Missing
- `quoted_status_id_str` is highly correlated with `quoted_status_id` (ρ = 1) Rejected
- `quoted_status_is_quote_status` has 97639 / 99.2% missing values Missing
- `quoted_status_lang` has 97639 / 99.2% missing values Missing
- `quoted_status_metadata_iso_language_code` has 97639 / 99.2% missing values Missing
- `quoted_status_metadata_result_type` has 97639 / 99.2% missing values Missing
- `quoted_status_possibly_sensitive` has 97807 / 99.4% missing values Missing
- `quoted_status_retweet_count` is highly correlated with `quoted_status_favorite_count` (ρ = 0.96633) Rejected
- `quoted_status_retweeted` has 97639 / 99.2% missing values Missing
- `quoted_status_source` has 97646 / 99.2% missing values Missing
- `quoted_status_source` has a high cardinality: 59 distinct values Warning
- `quoted_status_text` has 97742 / 99.3% missing values Missing
- `quoted_status_text` has a high cardinality: 565 distinct values Warning
- `quoted_status_truncated` has 97639 / 99.2% missing values Missing
- `quoted_status_user_contributors_enabled` has 97639 / 99.2% missing values Missing
- `quoted_status_user_created_at` has 97639 / 99.2% missing values Missing
- `quoted_status_user_created_at` has a high cardinality: 587 distinct values Warning
- `quoted_status_user_default_profile` has 97639 / 99.2% missing values Missing
- `quoted_status_user_default_profile_image` has 97639 / 99.2% missing values Missing
- `quoted_status_user_description` has 97752 / 99.3% missing values Missing
- `quoted_status_user_description` has a high cardinality: 496 distinct values Warning
- `quoted_status_user_entities_description_urls` has 97654 / 99.2% missing values Missing
- `quoted_status_user_entities_description_urls` has a high cardinality: 63 distinct values Warning
- `quoted_status_user_entities_url_urls` has 97865 / 99.5% missing values Missing
- `quoted_status_user_entities_url_urls` has a high cardinality: 413 distinct values Warning
- `quoted_status_user_favourites_count` has 97639 / 99.2% missing values Missing
- `quoted_status_user_followers_count` has 97639 / 99.2% missing values Missing
- `quoted_status_user_friends_count` has 97639 / 99.2% missing values Missing
- `quoted_status_user_geo_enabled` has 97639 / 99.2% missing values Missing
- `quoted_status_user_has_extended_profile` has 97639 / 99.2% missing values Missing
- `quoted_status_user_id` has 97639 / 99.2% missing values Missing
- `quoted_status_user_id_str` is highly correlated with `quoted_status_user_id` (ρ = 1) Rejected
- `quoted_status_user_is_translation_enabled` has 97639 / 99.2% missing values Missing
- `quoted_status_user_is_translator` has 97639 / 99.2% missing values Missing
- `quoted_status_user_lang` has 97639 / 99.2% missing values Missing
- `quoted_status_user_listed_count` is highly correlated with `quoted_status_user_followers_count` (ρ = 0.91088) Rejected
- `quoted_status_user_location` has 97813 / 99.4% missing values Missing
- `quoted_status_user_location` has a high cardinality: 343 distinct values Warning
- `quoted_status_user_name` has 97668 / 99.3% missing values Missing
- `quoted_status_user_name` has a high cardinality: 558 distinct values Warning
- `quoted_status_user_profile_background_color` has 97639 / 99.2% missing values Missing
- `quoted_status_user_profile_background_color` has a high cardinality: 119 distinct values Warning
- `quoted_status_user_profile_background_image_url` has 97666 / 99.3% missing values Missing
- `quoted_status_user_profile_background_image_url` has a high cardinality: 252 distinct values Warning
- `quoted_status_user_profile_background_image_url_https` has 97666 / 99.3% missing values Missing
- `quoted_status_user_profile_background_image_url_https` has a high cardinality: 252 distinct values Warning
- `quoted_status_user_profile_background_tile` has 97639 / 99.2% missing values Missing
- `quoted_status_user_profile_banner_url` has 97771 / 99.4% missing values Missing
- `quoted_status_user_profile_banner_url` has a high cardinality: 483 distinct values Warning
- `quoted_status_user_profile_image_url` has 97639 / 99.2% missing values Missing
- `quoted_status_user_profile_image_url` has a high cardinality: 587 distinct values Warning
- `quoted_status_user_profile_image_url_https` has 97639 / 99.2% missing values Missing
- `quoted_status_user_profile_image_url_https` has a high cardinality: 587 distinct values Warning
- `quoted_status_user_profile_link_color` has 97639 / 99.2% missing values Missing
- `quoted_status_user_profile_link_color` has a high cardinality: 196 distinct values Warning
- `quoted_status_user_profile_sidebar_border_color` has 97639 / 99.2% missing values Missing
- `quoted_status_user_profile_sidebar_fill_color` has 97639 / 99.2% missing values Missing
- `quoted_status_user_profile_sidebar_fill_color` has a high cardinality: 85 distinct values Warning
- `quoted_status_user_profile_text_color` has 97639 / 99.2% missing values Missing
- `quoted_status_user_profile_text_color` has a high cardinality: 52 distinct values Warning
- `quoted_status_user_profile_use_background_image` has 97639 / 99.2% missing values Missing
- `quoted_status_user_protected` has 97639 / 99.2% missing values Missing
- `quoted_status_user_screen_name` has 97639 / 99.2% missing values Missing
- `quoted_status_user_screen_name` has a high cardinality: 587 distinct values Warning
- `quoted_status_user_statuses_count` has 97639 / 99.2% missing values Missing
- `quoted_status_user_time_zone` has 97770 / 99.4% missing values Missing
- `quoted_status_user_time_zone` has a high cardinality: 61 distinct values Warning
- `quoted_status_user_url` has 97819 / 99.4% missing values Missing
- `quoted_status_user_url` has a high cardinality: 433 distinct values Warning
- `quoted_status_user_utc_offset` has 97770 / 99.4% missing values Missing
- `quoted_status_user_verified` has 97639 / 99.2% missing values Missing
- `retweet_count` is highly skewed (γ1 = 101.75)
- `retweet_count` has 48609 / 49.4% zeros
- `retweeted` has constant value False Rejected
- `retweeted_status_created_at` has 63829 / 64.9% missing values Missing
- `retweeted_status_created_at` has a high cardinality: 11461 distinct values Warning
- `retweeted_status_entities_hashtags` has 63876 / 64.9% missing values Missing
- `retweeted_status_entities_hashtags` has a high cardinality: 4833 distinct values Warning
- `retweeted_status_entities_media` has 85101 / 86.5% missing values Missing
- `retweeted_status_entities_media` has a high cardinality: 3617 distinct values Warning
- `retweeted_status_entities_symbols` has 63829 / 64.9% missing values Missing
- `retweeted_status_entities_urls` has 63829 / 64.9% missing values Missing
- `retweeted_status_entities_urls` has a high cardinality: 7892 distinct values Warning
- `retweeted_status_entities_user_mentions` has 64135 / 65.2% missing values Missing
- `retweeted_status_entities_user_mentions` has a high cardinality: 2882 distinct values Warning
- `retweeted_status_favorite_count` is highly correlated with `retweet_count` (ρ = 0.95171) Rejected
- `retweeted_status_favorited` has 63829 / 64.9% missing values Missing
- `retweeted_status_id` has 63829 / 64.9% missing values Missing
- `retweeted_status_id_str` is highly correlated with `retweeted_status_id` (ρ = 1) Rejected
- `retweeted_status_in_reply_to_screen_name` has 97000 / 98.6% missing values Missing
- `retweeted_status_in_reply_to_screen_name` has a high cardinality: 878 distinct values Warning
- `retweeted_status_in_reply_to_status_id` is highly correlated with `retweeted_status_id_str` (ρ = 0.98947) Rejected
- `retweeted_status_in_reply_to_status_id_str` is highly correlated with `retweeted_status_in_reply_to_status_id` (ρ = 1) Rejected
- `retweeted_status_in_reply_to_user_id` has 97000 / 98.6% missing values Missing
- `retweeted_status_in_reply_to_user_id_str` is highly correlated with `retweeted_status_in_reply_to_user_id` (ρ = 1) Rejected
- `retweeted_status_is_quote_status` has 63829 / 64.9% missing values Missing
- `retweeted_status_lang` has 63829 / 64.9% missing values Missing
- `retweeted_status_metadata_iso_language_code` has 63829 / 64.9% missing values Missing
- `retweeted_status_metadata_result_type` has 63829 / 64.9% missing values Missing
- `retweeted_status_place_bounding_box_coordinates` has 97129 / 98.7% missing values Missing
- `retweeted_status_place_bounding_box_coordinates` has a high cardinality: 239 distinct values Warning
- `retweeted_status_place_bounding_box_type` has 97129 / 98.7% missing values Missing
- `retweeted_status_place_contained_within` has 97129 / 98.7% missing values Missing
- `retweeted_status_place_country` has 97223 / 98.8% missing values Missing
- `retweeted_status_place_country_code` has 97131 / 98.7% missing values Missing
- `retweeted_status_place_full_name` has 97157 / 98.7% missing values Missing
- `retweeted_status_place_full_name` has a high cardinality: 230 distinct values Warning
- `retweeted_status_place_id` has 97129 / 98.7% missing values Missing
- `retweeted_status_place_id` has a high cardinality: 239 distinct values Warning
- `retweeted_status_place_name` has 97156 / 98.7% missing values Missing
- `retweeted_status_place_name` has a high cardinality: 229 distinct values Warning
- `retweeted_status_place_place_type` has 97129 / 98.7% missing values Missing
- `retweeted_status_place_url` has 97129 / 98.7% missing values Missing
- `retweeted_status_place_url` has a high cardinality: 239 distinct values Warning
- `retweeted_status_possibly_sensitive` has 69243 / 70.4% missing values Missing
- `retweeted_status_quoted_status_created_at` has 96981 / 98.6% missing values Missing
- `retweeted_status_quoted_status_created_at` has a high cardinality: 217 distinct values Warning
- `retweeted_status_quoted_status_entities_hashtags` has 96981 / 98.6% missing values Missing
- `retweeted_status_quoted_status_entities_hashtags` has a high cardinality: 88 distinct values Warning
- `retweeted_status_quoted_status_entities_media` has 97278 / 98.9% missing values Missing
- `retweeted_status_quoted_status_entities_media` has a high cardinality: 79 distinct values Warning
- `retweeted_status_quoted_status_entities_symbols` has 96981 / 98.6% missing values Missing
- `retweeted_status_quoted_status_entities_urls` has 96981 / 98.6% missing values Missing
- `retweeted_status_quoted_status_entities_urls` has a high cardinality: 123 distinct values Warning
- `retweeted_status_quoted_status_entities_user_mentions` has 96983 / 98.6% missing values Missing
- `retweeted_status_quoted_status_entities_user_mentions` has a high cardinality: 73 distinct values Warning
- `retweeted_status_quoted_status_favorite_count` is highly skewed (γ1 = 31.483)
- `retweeted_status_quoted_status_favorite_count` has 96981 / 98.6% missing values Missing
- `retweeted_status_quoted_status_favorited` has 96981 / 98.6% missing values Missing
- `retweeted_status_quoted_status_id` has 1110 / 1.1% missing values Missing
- `retweeted_status_quoted_status_id_str` is highly correlated with `retweeted_status_quoted_status_id` (ρ = 1) Rejected
- `retweeted_status_quoted_status_is_quote_status` has 96981 / 98.6% missing values Missing
- `retweeted_status_quoted_status_lang` has 96981 / 98.6% missing values Missing
- `retweeted_status_quoted_status_metadata_iso_language_code` has 96981 / 98.6% missing values Missing
- `retweeted_status_quoted_status_metadata_result_type` has 96981 / 98.6% missing values Missing
- `retweeted_status_quoted_status_place_bounding_box_coordinates` has 97425 / 99.0% missing values Missing
- `retweeted_status_quoted_status_place_bounding_box_type` has 97425 / 99.0% missing values Missing
- `retweeted_status_quoted_status_place_contained_within` has 97425 / 99.0% missing values Missing
- `retweeted_status_quoted_status_place_country` has 97425 / 99.0% missing values Missing
- `retweeted_status_quoted_status_place_country_code` has 97425 / 99.0% missing values Missing
- `retweeted_status_quoted_status_place_full_name` has 97430 / 99.0% missing values Missing
- `retweeted_status_quoted_status_place_id` has 97425 / 99.0% missing values Missing
- `retweeted_status_quoted_status_place_name` has 97425 / 99.0% missing values Missing
- `retweeted_status_quoted_status_place_place_type` has 97425 / 99.0% missing values Missing
- `retweeted_status_quoted_status_place_url` has 97425 / 99.0% missing values Missing
- `retweeted_status_quoted_status_possibly_sensitive` has 97099 / 98.7% missing values Missing
- `retweeted_status_quoted_status_retweet_count` is highly correlated with `retweeted_status_quoted_status_favorite_count` (ρ = 0.99487) Rejected
- `retweeted_status_quoted_status_retweeted` has 96981 / 98.6% missing values Missing
- `retweeted_status_quoted_status_source` has 96981 / 98.6% missing values Missing
- `retweeted_status_quoted_status_text` has 97055 / 98.6% missing values Missing
- `retweeted_status_quoted_status_text` has a high cardinality: 185 distinct values Warning
- `retweeted_status_quoted_status_truncated` has 96981 / 98.6% missing values Missing
- `retweeted_status_retweet_count` is highly correlated with `retweeted_status_favorite_count` (ρ = 0.95171) Rejected
- `retweeted_status_retweeted` has 63829 / 64.9% missing values Missing
- `retweeted_status_source` has 64013 / 65.1% missing values Missing
- `retweeted_status_source` has a high cardinality: 527 distinct values Warning
- `retweeted_status_text` has 67571 / 68.7% missing values Missing
- `retweeted_status_text` has a high cardinality: 9940 distinct values Warning
- `retweeted_status_truncated` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_contributors_enabled` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_created_at` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_created_at` has a high cardinality: 6486 distinct values Warning
- `retweeted_status_user_default_profile` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_default_profile_image` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_description` has 69449 / 70.6% missing values Missing
- `retweeted_status_user_description` has a high cardinality: 5307 distinct values Warning
- `retweeted_status_user_entities_description_urls` has 64206 / 65.3% missing values Missing
- `retweeted_status_user_entities_description_urls` has a high cardinality: 706 distinct values Warning
- `retweeted_status_user_entities_url_urls` has 75893 / 77.1% missing values Missing
- `retweeted_status_user_entities_url_urls` has a high cardinality: 4563 distinct values Warning
- `retweeted_status_user_favourites_count` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_favourites_count` has 3482 / 3.5% zeros
- `retweeted_status_user_followers_count` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_friends_count` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_friends_count` has 1055 / 1.1% zeros
- `retweeted_status_user_geo_enabled` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_has_extended_profile` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_id` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_id_str` is highly correlated with `retweeted_status_user_id` (ρ = 1) Rejected
- `retweeted_status_user_is_translation_enabled` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_is_translator` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_lang` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_listed_count` has 63829 / 64.9% missing values Missing
- `retweeted_status_user_location` has 72481 / 73.7% missing values Missing
- `retweeted_status_user_location` has a high cardinality: 2695 distinct values Warning
- `retweeted_status_user_name` has 65260 / 66.3% missing values Missing
- `retweeted_status_user_name` has a high cardinality: 6039 distinct values Warning
- `retweeted_status_user_profile_background_color` has 63841 / 64.9% missing values Missing
- `retweeted_status_user_profile_background_color` has a high cardinality: 732 distinct values Warning
- `retweeted_status_user_profile_background_image_url` has 65443 / 66.5% missing values Missing
- `retweeted_status_user_profile_background_image_url` has a high cardinality: 2114 distinct values Warning
- `retweeted_status_user_profile_background_image_url_https` has 65443 / 66.5% missing values Missing
- `retweeted_status_user_profile_background_image_url_https` has a high cardinality: 2114 distinct values Warning
- `retweeted_status_user_profile_background_tile` has 63841 / 64.9% missing values Missing
- `retweeted_status_user_profile_banner_url` has 71385 / 72.6% missing values Missing
- `retweeted_status_user_profile_banner_url` has a high cardinality: 4893 distinct values Warning
- `retweeted_status_user_profile_image_url` has 63841 / 64.9% missing values Missing
- `retweeted_status_user_profile_image_url` has a high cardinality: 6417 distinct values Warning
- `retweeted_status_user_profile_image_url_https` has 63841 / 64.9% missing values Missing
- `retweeted_status_user_profile_image_url_https` has a high cardinality: 6417 distinct values Warning
- `retweeted_status_user_profile_link_color` has 63841 / 64.9% missing values Missing
- `retweeted_status_user_profile_link_color` has a high cardinality: 1406 distinct values Warning
- `retweeted_status_user_profile_sidebar_border_color` has 63841 / 64.9% missing values Missing
- `retweeted_status_user_profile_sidebar_border_color` has a high cardinality: 261 distinct values Warning
- `retweeted_status_user_profile_sidebar_fill_color` has 63841 / 64.9% missing values Missing
- `retweeted_status_user_profile_sidebar_fill_color` has a high cardinality: 509 distinct values Warning
- `retweeted_status_user_profile_text_color` has 63841 / 64.9% missing values Missing
- `retweeted_status_user_profile_text_color` has a high cardinality: 398 distinct values Warning
- `retweeted_status_user_profile_use_background_image` has 63841 / 64.9% missing values Missing
- `retweeted_status_user_protected` has 63841 / 64.9% missing values Missing
- `retweeted_status_user_screen_name` has 63841 / 64.9% missing values Missing
- `retweeted_status_user_screen_name` has a high cardinality: 6485 distinct values Warning
- `retweeted_status_user_statuses_count` has 63841 / 64.9% missing values Missing
- `retweeted_status_user_time_zone` has 73090 / 74.3% missing values Missing
- `retweeted_status_user_time_zone` has a high cardinality: 142 distinct values Warning
- `retweeted_status_user_url` has 70757 / 71.9% missing values Missing
- `retweeted_status_user_url` has a high cardinality: 4471 distinct values Warning
- `retweeted_status_user_utc_offset` has 73090 / 74.3% missing values Missing
- `retweeted_status_user_verified` has 63841 / 64.9% missing values Missing
- `source` has a high cardinality: 1681 distinct values Warning
- `text` has a high cardinality: 71549 distinct values Warning
- `user_created_at` has a high cardinality: 37931 distinct values Warning
- `user_description` has 22323 / 22.7% missing values Missing
- `user_description` has a high cardinality: 27457 distinct values Warning
- `user_entities_description_urls` has 1074 / 1.1% missing values Missing
- `user_entities_description_urls` has a high cardinality: 2671 distinct values Warning
- `user_entities_url_urls` has 46930 / 47.7% missing values Missing
- `user_entities_url_urls` has a high cardinality: 19771 distinct values Warning
- `user_favourites_count` has 25011 / 25.4% zeros
- `user_followers_count` is highly skewed (γ1 = 115.54)
- `user_friends_count` is highly skewed (γ1 = 20.519)
- `user_friends_count` has 8004 / 8.1% zeros
- `user_id_str` is highly correlated with `user_id` (ρ = 1) Rejected
- `user_lang` has a high cardinality: 52 distinct values Warning
- `user_listed_count` has 3775 / 3.8% zeros
- `user_location` has 29408 / 29.9% missing values Missing
- `user_location` has a high cardinality: 11672 distinct values Warning
- `user_name` has 5255 / 5.3% missing values Missing
- `user_name` has a high cardinality: 34039 distinct values Warning
- `user_profile_background_color` has a high cardinality: 2865 distinct values Warning
- `user_profile_background_image_url` has 16195 / 16.5% missing values Missing
- `user_profile_background_image_url` has a high cardinality: 10149 distinct values Warning
- `user_profile_background_image_url_https` has 16195 / 16.5% missing values Missing
- `user_profile_background_image_url_https` has a high cardinality: 10149 distinct values Warning
- `user_profile_banner_url` has 35040 / 35.6% missing values Missing
- `user_profile_banner_url` has a high cardinality: 27131 distinct values Warning
- `user_profile_image_url` has a high cardinality: 36954 distinct values Warning
- `user_profile_image_url_https` has a high cardinality: 36954 distinct values Warning
- `user_profile_link_color` has a high cardinality: 5376 distinct values Warning
- `user_profile_sidebar_border_color` has a high cardinality: 1061 distinct values Warning
- `user_profile_sidebar_fill_color` has a high cardinality: 1950 distinct values Warning
- `user_profile_text_color` has a high cardinality: 1602 distinct values Warning
- `user_screen_name` has a high cardinality: 37937 distinct values Warning
- `user_time_zone` has 40653 / 41.3% missing values Missing
- `user_time_zone` has a high cardinality: 210 distinct values Warning
- `user_url` has 38739 / 39.4% missing values Missing
- `user_url` has a high cardinality: 19961 distinct values Warning
- `user_utc_offset` has 40653 / 41.3% missing values Missing
- Dataset has 155 duplicate rows Warning

# Variables

coordinates_coordinates
Categorical

Distinct count | 184
Unique (%) | 56.6%
Missing (%) | 99.7%
Missing (n) | 98068

[-76.4921829, 38.9784453] | 15
[-71.0588801, 42.3600825] | 13
[-122.2455364, 37.5364134] | 9
Other values (180) | 288
(Missing) | 98068

Toggle details

Value | Count | Frequency (%) |
[-76.4921829, 38.9784453] | 15 | 0.0% |
[-71.0588801, 42.3600825] | 13 | 0.0% |
[-122.2455364, 37.5364134] | 9 | 0.0% |
[-105.0866504, 39.9205411] | 6 | 0.0% |
[-122.1430195, 37.4418834] | 6 | 0.0% |
[106.81396893, -6.21167266] | 5 | 0.0% |
[-97.7525352, 30.401356] | 4 | 0.0% |
[-71.4128343, 41.8239891] | 4 | 0.0% |
[-93.4044187, 44.9260794] | 4 | 0.0% |
[-84.3879824, 33.7489954] | 4 | 0.0% |
[-118.4717975, 34.02875] | 4 | 0.0% |
[-122.2363548, 37.4852152] | 4 | 0.0% |
[123.93939268, 9.61432594] | 4 | 0.0% |
[-96.994174, 33.046233] | 4 | 0.0% |
[-0.172366, 51.4916039] | 3 | 0.0% |
[-74.0064, 40.7142] | 3 | 0.0% |
[-117.8282121, 33.6588951] | 3 | 0.0% |
[-87.6297982, 41.8781136] | 3 | 0.0% |
[-81.6943605, 41.49932] | 3 | 0.0% |
[-78.898619, 35.9940329] | 3 | 0.0% |
Other values (163) | 221 | 0.2% |
(Missing) | 98068 | 99.7% |

coordinates_type
Categorical

Distinct count | 2
Unique (%) | 0.6%
Missing (%) | 99.7%
Missing (n) | 98068

Point | 325
(Missing) | 98068

Toggle details

Value | Count | Frequency (%) |
Point | 325 | 0.3% |
(Missing) | 98068 | 99.7% |

created_at
Categorical

Distinct count | 89544
Unique (%) | 91.0%
Missing (%) | 0.0%
Missing (n) | 0

Sat Apr 23 20:34:12 +0000 2016 | 25
Sat Apr 23 20:34:16 +0000 2016 | 23
Sat Apr 23 20:34:29 +0000 2016 | 20
Other values (89541) | 98325

Toggle details

Value | Count | Frequency (%) |
Sat Apr 23 20:34:12 +0000 2016 | 25 | 0.0% |
Sat Apr 23 20:34:16 +0000 2016 | 23 | 0.0% |
Sat Apr 23 20:34:29 +0000 2016 | 20 | 0.0% |
Mon Apr 25 21:27:55 +0000 2016 | 16 | 0.0% |
Sat Apr 23 21:06:01 +0000 2016 | 16 | 0.0% |
Mon Apr 25 10:18:44 +0000 2016 | 15 | 0.0% |
Sat Apr 23 21:03:50 +0000 2016 | 12 | 0.0% |
Sat Apr 23 21:03:51 +0000 2016 | 12 | 0.0% |
Tue Apr 19 14:00:28 +0000 2016 | 11 | 0.0% |
Mon Apr 25 21:27:54 +0000 2016 | 11 | 0.0% |
Mon May 02 16:38:22 +0000 2016 | 9 | 0.0% |
Sat Apr 23 16:01:24 +0000 2016 | 8 | 0.0% |
Tue Apr 19 11:45:50 +0000 2016 | 8 | 0.0% |
Sat Apr 23 16:01:25 +0000 2016 | 7 | 0.0% |
Sun Apr 24 15:59:28 +0000 2016 | 7 | 0.0% |
Sat Apr 23 21:06:00 +0000 2016 | 7 | 0.0% |
Mon Apr 25 10:18:42 +0000 2016 | 7 | 0.0% |
Thu Apr 21 11:48:07 +0000 2016 | 7 | 0.0% |
Sun May 01 20:56:40 +0000 2016 | 7 | 0.0% |
Sat Apr 23 07:42:36 +0000 2016 | 7 | 0.0% |
Other values (89524) | 98158 | 99.8% |

entities_hashtags
Categorical

Distinct count | 20741
Unique (%) | 21.1%
Missing (%) | 0.1%
Missing (n) | 111

[] | 46340
[{u'indices': [0, 7], u'text': u'python'}] | 3121
[{u'indices': [0, 10], u'text': u'raspberry'}, {u'indices': [11, 16], u'text': u'tech'}, {u'indices': [17, 20], u'text': u'pi'}] | 483
Other values (20737) | 48338

Toggle details

Value | Count | Frequency (%) |
[] | 46340 | 47.1% |
[{u'indices': [0, 7], u'text': u'python'}] | 3121 | 3.2% |
[{u'indices': [0, 10], u'text': u'raspberry'}, {u'indices': [11, 16], u'text': u'tech'}, {u'indices': [17, 20], u'text': u'pi'}] | 483 | 0.5% |
[{u'indices': [110, 124], u'text': u'CallOfTheWild'}, {u'indices': [125, 137], u'text': u'SaveTheWild'}] | 308 | 0.3% |
[{u'indices': [18, 25], u'text': u'Google'}, {u'indices': [44, 51], u'text': u'Python'}, {u'indices': [52, 68], u'text': u'MachineLearning'}, {u'indices': [88, 96], u'text': u'sklearn'}] | 290 | 0.3% |
[{u'indices': [19, 23], u'text': u'TWD'}, {u'indices': [113, 128], u'text': u'TheWalkingDead'}] | 263 | 0.3% |
[{u'indices': [18, 24], u'text': u'ITJob'}, {u'indices': [25, 29], u'text': u'Job'}, {u'indices': [30, 34], u'text': u'San'}] | 219 | 0.2% |
[{u'indices': [49, 56], u'text': u'Python'}] | 187 | 0.2% |
[{u'indices': [18, 24], u'text': u'ITJob'}, {u'indices': [25, 29], u'text': u'Job'}, {u'indices': [30, 34], u'text': u'New'}] | 174 | 0.2% |
[{u'indices': [32, 37], u'text': u'Java'}, {u'indices': [38, 45], u'text': u'csharp'}, {u'indices': [46, 53], u'text': u'python'}] | 171 | 0.2% |
[{u'indices': [0, 7], u'text': u'Python'}] | 165 | 0.2% |
[{u'indices': [19, 26], u'text': u'python'}] | 151 | 0.2% |
[{u'indices': [54, 61], u'text': u'DevOps'}, {u'indices': [62, 66], u'text': u'IoT'}, {u'indices': [67, 81], u'text': u'Microservices'}, {u'indices': [106, 112], u'text': u'Cloud'}] | 145 | 0.1% |
[{u'indices': [18, 24], u'text': u'ITJob'}, {u'indices': [25, 29], u'text': u'Job'}, {u'indices': [30, 37], u'text': u'Boston'}] | 141 | 0.1% |
[{u'indices': [0, 4], u'text': u'Job'}, {u'indices': [5, 17], u'text': u'Opportunity'}] | 136 | 0.1% |
[{u'indices': [20, 36], u'text': u'MachineLearning'}, {u'indices': [42, 49], u'text': u'Python'}, {u'indices': [99, 105], u'text': u'abdsc'}, {u'indices': [106, 114], u'text': u'BigData'}, {u'indices': [115, 127], u'text': u'DataScience'}] | 126 | 0.1% |
[{u'indices': [16, 23], u'text': u'python'}] | 107 | 0.1% |
[{u'indices': [96, 102], u'text': u'Opera'}, {u'indices': [103, 107], u'text': u'VPN'}] | 97 | 0.1% |
[{u'indices': [19, 33], u'text': u'coloroftheday'}, {u'indices': [52, 66], u'text': u'TravelTuesday'}] | 96 | 0.1% |
[{u'indices': [55, 71], u'text': u'Electricity4All'}] | 95 | 0.1% |
Other values (20720) | 45467 | 46.2% |
(Missing) | 111 | 0.1% |

entities_media
Categorical

Distinct count | 13684
Unique (%) | 58.5%
Missing (%) | 76.2%
Missing (n) | 75011

[{u'source_user_id': 4804550526, u'source_status_id_str': u'723543199315300352', u'expanded_url': u'http://twitter.com/Delilah_Alvares/status/723543199315300352/photo/1', u'display_url': u'pic.twitter.com/uMhFFIHrbo', u'url': u'https://t.co/uMhFFIHrbo', u'media_url_https': u'https://pbs.twimg.com/media/CgqKrq8XEAI0ZPo.jpg', u'source_user_id_str': u'4804550526', u'source_status_id': 723543199315300352, u'id_str': u'723543173012852738', u'sizes': {u'small': {u'h': 512, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 960, u'w': 638, u'resize': u'fit'}, u'medium': {u'h': 903, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [139, 140], u'type': u'photo', u'id': 723543173012852738, u'media_url': u'http://pbs.twimg.com/media/CgqKrq8XEAI0ZPo.jpg'}] | 308
[{u'source_user_id': 3331829713, u'source_status_id_str': u'726544327824957440', u'expanded_url': u'http://twitter.com/FTWDFans/status/726544327824957440/photo/1', u'sizes': {u'small': {u'h': 434, u'resize': u'fit', u'w': 340}, u'large': {u'h': 1307, u'resize': u'fit', u'w': 1024}, u'medium': {u'h': 766, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/RyxstTwr5I', u'media_url_https': u'https://pbs.twimg.com/media/ChU0L7FUcAAwfgD.jpg', u'source_user_id_str': u'3331829713', u'source_status_id': 726544327824957440, u'id_str': u'726544294333411328', u'indices': [139, 140], u'media_url': u'http://pbs.twimg.com/media/ChU0L7FUcAAwfgD.jpg', u'type': u'photo', u'id': 726544294333411328, u'display_url': u'pic.twitter.com/RyxstTwr5I'}] | 263
[{u'source_user_id': 49413866, u'source_status_id_str': u'721324803207131136', u'expanded_url': u'http://twitter.com/randal_olson/status/721324803207131136/photo/1', u'display_url': u'pic.twitter.com/aoMntyJudr', u'url': u'https://t.co/aoMntyJudr', u'media_url_https': u'https://pbs.twimg.com/media/CgKpFXQUEAEk-d6.jpg', u'source_user_id_str': u'49413866', u'source_status_id': 721324803207131136, u'id_str': u'721324799939579905', u'sizes': {u'large': {u'h': 515, u'w': 1024, u'resize': u'fit'}, u'small': {u'h': 171, u'w': 340, u'resize': u'fit'}, u'medium': {u'h': 302, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [122, 140], u'type': u'photo', u'id': 721324799939579905, u'media_url': u'http://pbs.twimg.com/media/CgKpFXQUEAEk-d6.jpg'}] | 239
Other values (13680) | 22572
(Missing) | 75011

Toggle details

Value | Count | Frequency (%) |
[{u'source_user_id': 4804550526, u'source_status_id_str': u'723543199315300352', u'expanded_url': u'http://twitter.com/Delilah_Alvares/status/723543199315300352/photo/1', u'display_url': u'pic.twitter.com/uMhFFIHrbo', u'url': u'https://t.co/uMhFFIHrbo', u'media_url_https': u'https://pbs.twimg.com/media/CgqKrq8XEAI0ZPo.jpg', u'source_user_id_str': u'4804550526', u'source_status_id': 723543199315300352, u'id_str': u'723543173012852738', u'sizes': {u'small': {u'h': 512, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 960, u'w': 638, u'resize': u'fit'}, u'medium': {u'h': 903, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [139, 140], u'type': u'photo', u'id': 723543173012852738, u'media_url': u'http://pbs.twimg.com/media/CgqKrq8XEAI0ZPo.jpg'}] | 308 | 0.3% |
[{u'source_user_id': 3331829713, u'source_status_id_str': u'726544327824957440', u'expanded_url': u'http://twitter.com/FTWDFans/status/726544327824957440/photo/1', u'sizes': {u'small': {u'h': 434, u'resize': u'fit', u'w': 340}, u'large': {u'h': 1307, u'resize': u'fit', u'w': 1024}, u'medium': {u'h': 766, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/RyxstTwr5I', u'media_url_https': u'https://pbs.twimg.com/media/ChU0L7FUcAAwfgD.jpg', u'source_user_id_str': u'3331829713', u'source_status_id': 726544327824957440, u'id_str': u'726544294333411328', u'indices': [139, 140], u'media_url': u'http://pbs.twimg.com/media/ChU0L7FUcAAwfgD.jpg', u'type': u'photo', u'id': 726544294333411328, u'display_url': u'pic.twitter.com/RyxstTwr5I'}] | 263 | 0.3% |
[{u'source_user_id': 49413866, u'source_status_id_str': u'721324803207131136', u'expanded_url': u'http://twitter.com/randal_olson/status/721324803207131136/photo/1', u'display_url': u'pic.twitter.com/aoMntyJudr', u'url': u'https://t.co/aoMntyJudr', u'media_url_https': u'https://pbs.twimg.com/media/CgKpFXQUEAEk-d6.jpg', u'source_user_id_str': u'49413866', u'source_status_id': 721324803207131136, u'id_str': u'721324799939579905', u'sizes': {u'large': {u'h': 515, u'w': 1024, u'resize': u'fit'}, u'small': {u'h': 171, u'w': 340, u'resize': u'fit'}, u'medium': {u'h': 302, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [122, 140], u'type': u'photo', u'id': 721324799939579905, u'media_url': u'http://pbs.twimg.com/media/CgKpFXQUEAEk-d6.jpg'}] | 239 | 0.2% |
[{u'source_user_id': 1637123371, u'source_status_id_str': u'724302929285505026', u'expanded_url': u'http://twitter.com/SneakerPics23/status/724302929285505026/photo/1', u'sizes': {u'small': {u'h': 323, u'resize': u'fit', u'w': 340}, u'large': {u'h': 713, u'resize': u'fit', u'w': 750}, u'medium': {u'h': 570, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/qpdP0DUKAu', u'media_url_https': u'https://pbs.twimg.com/media/Cg09p_JUUAEu3vh.jpg', u'source_user_id_str': u'1637123371', u'source_status_id': 724302929285505026, u'id_str': u'724302906610962433', u'indices': [50, 73], u'media_url': u'http://pbs.twimg.com/media/Cg09p_JUUAEu3vh.jpg', u'type': u'photo', u'id': 724302906610962433, u'display_url': u'pic.twitter.com/qpdP0DUKAu'}] | 150 | 0.2% |
[{u'source_user_id': 49413866, u'source_status_id_str': u'723584753597878272', u'expanded_url': u'http://twitter.com/randal_olson/status/723584753597878272/photo/1', u'display_url': u'pic.twitter.com/sYkjvn7hzu', u'url': u'https://t.co/sYkjvn7hzu', u'media_url_https': u'https://pbs.twimg.com/media/Cgqwf7uW0AIvENf.jpg', u'source_user_id_str': u'49413866', u'source_status_id': 723584753597878272, u'id_str': u'723584752800944130', u'sizes': {u'small': {u'h': 113, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 340, u'w': 1024, u'resize': u'fit'}, u'medium': {u'h': 199, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [139, 140], u'type': u'photo', u'id': 723584752800944130, u'media_url': u'http://pbs.twimg.com/media/Cgqwf7uW0AIvENf.jpg'}] | 143 | 0.1% |
[{u'source_user_id': 3407121572, u'source_status_id_str': u'724987767000801280', u'expanded_url': u'http://twitter.com/fashionkiIIas/status/724987767000801280/photo/1', u'sizes': {u'small': {u'h': 254, u'resize': u'fit', u'w': 340}, u'large': {u'h': 560, u'resize': u'fit', u'w': 750}, u'medium': {u'h': 448, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/bmzH4MVi94', u'media_url_https': u'https://pbs.twimg.com/media/Cg-sh87WgAEPoHS.jpg', u'source_user_id_str': u'3407121572', u'source_status_id': 724987767000801280, u'id_str': u'724987764320665601', u'indices': [69, 92], u'media_url': u'http://pbs.twimg.com/media/Cg-sh87WgAEPoHS.jpg', u'type': u'photo', u'id': 724987764320665601, u'display_url': u'pic.twitter.com/bmzH4MVi94'}] | 139 | 0.1% |
[{u'source_user_id': 2892560250, u'source_status_id_str': u'653947766473949184', u'expanded_url': u'http://twitter.com/BigAssAddicted/status/653947766473949184/video/1', u'sizes': {u'small': {u'h': 187, u'resize': u'fit', u'w': 340}, u'large': {u'h': 396, u'resize': u'fit', u'w': 720}, u'medium': {u'h': 330, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/jbLCwPRmqI', u'media_url_https': u'https://pbs.twimg.com/ext_tw_video_thumb/653947265200033792/pu/img/WZ19nUbaGWtnsW93.jpg', u'source_user_id_str': u'2892560250', u'source_status_id': 653947766473949184, u'id_str': u'653947265200033792', u'indices': [47, 70], u'media_url': u'http://pbs.twimg.com/ext_tw_video_thumb/653947265200033792/pu/img/WZ19nUbaGWtnsW93.jpg', u'type': u'photo', u'id': 653947265200033792, u'display_url': u'pic.twitter.com/jbLCwPRmqI'}] | 116 | 0.1% |
[{u'source_user_id': 15823805, u'source_status_id_str': u'724605272560377856', u'expanded_url': u'http://twitter.com/spazef0rze/status/724605272560377856/photo/1', u'sizes': {u'small': {u'h': 255, u'resize': u'fit', u'w': 340}, u'large': {u'h': 375, u'resize': u'fit', u'w': 500}, u'medium': {u'h': 375, u'resize': u'fit', u'w': 500}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/y8YXIvM57S', u'media_url_https': u'https://pbs.twimg.com/media/Cg5QbymU0AEv7V0.jpg', u'source_user_id_str': u'15823805', u'source_status_id': 724605272560377856, u'id_str': u'724605028422438913', u'indices': [139, 140], u'media_url': u'http://pbs.twimg.com/media/Cg5QbymU0AEv7V0.jpg', u'type': u'photo', u'id': 724605028422438913, u'display_url': u'pic.twitter.com/y8YXIvM57S'}] | 97 | 0.1% |
[{u'source_user_id': 14159148, u'source_status_id_str': u'726644827769593858', u'expanded_url': u'http://twitter.com/UN/status/726644827769593858/photo/1', u'sizes': {u'small': {u'h': 170, u'resize': u'fit', u'w': 340}, u'large': {u'h': 220, u'resize': u'fit', u'w': 440}, u'medium': {u'h': 220, u'resize': u'fit', u'w': 440}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/Tn9trH2Nih', u'media_url_https': u'https://pbs.twimg.com/media/Cg0B8UwUYAE5Cw4.jpg', u'source_user_id_str': u'14159148', u'source_status_id': 726644827769593858, u'id_str': u'724237250951667713', u'indices': [125, 140], u'media_url': u'http://pbs.twimg.com/media/Cg0B8UwUYAE5Cw4.jpg', u'type': u'photo', u'id': 724237250951667713, u'display_url': u'pic.twitter.com/Tn9trH2Nih'}] | 95 | 0.1% |
[{u'source_user_id': 20431922, u'source_status_id_str': u'722434350298591232', u'expanded_url': u'http://twitter.com/500px/status/722434350298591232/photo/1', u'display_url': u'pic.twitter.com/BjAO7UXyj2', u'url': u'https://t.co/BjAO7UXyj2', u'media_url_https': u'https://pbs.twimg.com/media/CgaaNm6UMAEYpkq.jpg', u'source_user_id_str': u'20431922', u'source_status_id': 722434350298591232, u'id_str': u'722434348813660161', u'sizes': {u'large': {u'h': 628, u'w': 900, u'resize': u'fit'}, u'small': {u'h': 237, u'w': 340, u'resize': u'fit'}, u'medium': {u'h': 419, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [123, 140], u'type': u'photo', u'id': 722434348813660161, u'media_url': u'http://pbs.twimg.com/media/CgaaNm6UMAEYpkq.jpg'}] | 94 | 0.1% |
[{u'source_user_id': 534563976, u'source_status_id_str': u'725455009626886144', u'expanded_url': u'http://twitter.com/KirkDBorne/status/725455009626886144/photo/1', u'sizes': {u'small': {u'h': 189, u'resize': u'fit', u'w': 340}, u'large': {u'h': 568, u'resize': u'fit', u'w': 1024}, u'medium': {u'h': 333, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/TK8DqOw04E', u'media_url_https': u'https://pbs.twimg.com/media/ChFVfIqU0AEsnTl.png', u'source_user_id_str': u'534563976', u'source_status_id': 725455009626886144, u'id_str': u'725455008372674561', u'indices': [139, 140], u'media_url': u'http://pbs.twimg.com/media/ChFVfIqU0AEsnTl.png', u'type': u'photo', u'id': 725455008372674561, u'display_url': u'pic.twitter.com/TK8DqOw04E'}] | 89 | 0.1% |
[{u'source_user_id': 49413866, u'source_status_id_str': u'726798373639077888', u'expanded_url': u'http://twitter.com/randal_olson/status/726798373639077888/photo/1', u'sizes': {u'small': {u'h': 469, u'resize': u'fit', u'w': 340}, u'large': {u'h': 577, u'resize': u'fit', u'w': 418}, u'medium': {u'h': 577, u'resize': u'fit', u'w': 418}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/IO7RTTiqWB', u'media_url_https': u'https://pbs.twimg.com/media/ChYbRQ0WUAA5E0U.png', u'source_user_id_str': u'49413866', u'source_status_id': 726798373639077888, u'id_str': u'726798373253173248', u'indices': [108, 131], u'media_url': u'http://pbs.twimg.com/media/ChYbRQ0WUAA5E0U.png', u'type': u'photo', u'id': 726798373253173248, u'display_url': u'pic.twitter.com/IO7RTTiqWB'}] | 84 | 0.1% |
[{u'source_user_id': 3093129209, u'source_status_id_str': u'726953811953094656', u'expanded_url': u'http://twitter.com/preregrintook/status/726953811953094656/photo/1', u'sizes': {u'small': {u'h': 414, u'resize': u'fit', u'w': 340}, u'large': {u'h': 1248, u'resize': u'fit', u'w': 1024}, u'medium': {u'h': 731, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/7q8Brq9igj', u'media_url_https': u'https://pbs.twimg.com/media/ChaooqTVEAABD8N.jpg', u'source_user_id_str': u'3093129209', u'source_status_id': 726953811953094656, u'id_str': u'726953806370508800', u'indices': [139, 140], u'media_url': u'http://pbs.twimg.com/media/ChaooqTVEAABD8N.jpg', u'type': u'photo', u'id': 726953806370508800, u'display_url': u'pic.twitter.com/7q8Brq9igj'}] | 78 | 0.1% |
[{u'source_user_id': 103865213, u'source_status_id_str': u'722397141499539456', u'expanded_url': u'http://twitter.com/mwrlabs/status/722397141499539456/photo/1', u'display_url': u'pic.twitter.com/8pcxzepzJX', u'url': u'https://t.co/8pcxzepzJX', u'media_url_https': u'https://pbs.twimg.com/media/CgZ4XzlWsAA_jBi.jpg', u'source_user_id_str': u'103865213', u'source_status_id': 722397141499539456, u'id_str': u'722397140618752000', u'sizes': {u'small': {u'h': 57, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 101, u'w': 600, u'resize': u'fit'}, u'medium': {u'h': 101, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 101, u'w': 101, u'resize': u'crop'}}, u'indices': [117, 140], u'type': u'photo', u'id': 722397140618752000, u'media_url': u'http://pbs.twimg.com/media/CgZ4XzlWsAA_jBi.jpg'}] | 74 | 0.1% |
[{u'source_user_id': 555031989, u'source_status_id_str': u'724481351701921792', u'expanded_url': u'http://twitter.com/Ronald_vanLoon/status/724481351701921792/photo/1', u'sizes': {u'small': {u'h': 276, u'resize': u'fit', u'w': 340}, u'large': {u'h': 831, u'resize': u'fit', u'w': 1024}, u'medium': {u'h': 487, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/ZQ0lvCJvlZ', u'media_url_https': u'https://pbs.twimg.com/media/Cg3f8ynWkAAuQ_m.jpg', u'source_user_id_str': u'555031989', u'source_status_id': 724481351701921792, u'id_str': u'724481350548492288', u'indices': [139, 140], u'media_url': u'http://pbs.twimg.com/media/Cg3f8ynWkAAuQ_m.jpg', u'type': u'photo', u'id': 724481350548492288, u'display_url': u'pic.twitter.com/ZQ0lvCJvlZ'}] | 70 | 0.1% |
[{u'source_user_id': 14159148, u'source_status_id_str': u'724675621318578177', u'expanded_url': u'http://twitter.com/UN/status/724675621318578177/photo/1', u'sizes': {u'small': {u'h': 170, u'resize': u'fit', u'w': 340}, u'large': {u'h': 220, u'resize': u'fit', u'w': 440}, u'medium': {u'h': 220, u'resize': u'fit', u'w': 440}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/ARQDomg4GO', u'media_url_https': u'https://pbs.twimg.com/media/Cg0BjMLU4AUZT3_.jpg', u'source_user_id_str': u'14159148', u'source_status_id': 724675621318578177, u'id_str': u'724236819152297989', u'indices': [125, 140], u'media_url': u'http://pbs.twimg.com/media/Cg0BjMLU4AUZT3_.jpg', u'type': u'photo', u'id': 724236819152297989, u'display_url': u'pic.twitter.com/ARQDomg4GO'}] | 69 | 0.1% |
[{u'source_user_id': 41154258, u'source_status_id_str': u'726407560874582018', u'expanded_url': u'http://twitter.com/KyleHanslovan/status/726407560874582018/photo/1', u'sizes': {u'small': {u'h': 142, u'resize': u'fit', u'w': 340}, u'large': {u'h': 246, u'resize': u'fit', u'w': 591}, u'medium': {u'h': 246, u'resize': u'fit', u'w': 591}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/u1mj8MwTR8', u'media_url_https': u'https://pbs.twimg.com/media/ChS3ymUWUAAmdt2.jpg', u'source_user_id_str': u'41154258', u'source_status_id': 726407560874582018, u'id_str': u'726407519820730368', u'indices': [122, 140], u'media_url': u'http://pbs.twimg.com/media/ChS3ymUWUAAmdt2.jpg', u'type': u'photo', u'id': 726407519820730368, u'display_url': u'pic.twitter.com/u1mj8MwTR8'}] | 67 | 0.1% |
[{u'source_user_id': 757365218, u'source_status_id_str': u'724118258232754176', u'expanded_url': u'http://twitter.com/RickKing16/status/724118258232754176/photo/1', u'display_url': u'pic.twitter.com/hYIdiAMTrD', u'source_status_id': 724118258232754176, u'media_url_https': u'https://pbs.twimg.com/media/CgyVuBUWsAAErbP.jpg', u'source_user_id_str': u'757365218', u'url': u'https://t.co/hYIdiAMTrD', u'id_str': u'724118257960136704', u'sizes': {u'small': {u'h': 190, u'resize': u'fit', u'w': 340}, u'large': {u'h': 280, u'resize': u'fit', u'w': 500}, u'medium': {u'h': 280, u'resize': u'fit', u'w': 500}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'indices': [117, 140], u'type': u'photo', u'id': 724118257960136704, u'media_url': u'http://pbs.twimg.com/media/CgyVuBUWsAAErbP.jpg'}] | 66 | 0.1% |
[{u'source_user_id': 14174897, u'source_status_id_str': u'723208994769096706', u'expanded_url': u'http://twitter.com/analyticbridge/status/723208994769096706/photo/1', u'display_url': u'pic.twitter.com/wbI1IzvEdZ', u'url': u'https://t.co/wbI1IzvEdZ', u'media_url_https': u'https://pbs.twimg.com/media/Cglav58U4AAz10D.jpg', u'source_user_id_str': u'14174897', u'source_status_id': 723208994769096706, u'id_str': u'723208994223874048', u'sizes': {u'small': {u'h': 176, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 254, u'w': 490, u'resize': u'fit'}, u'medium': {u'h': 254, u'w': 490, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [90, 113], u'type': u'photo', u'id': 723208994223874048, u'media_url': u'http://pbs.twimg.com/media/Cglav58U4AAz10D.jpg'}] | 63 | 0.1% |
[{u'source_user_id': 20167623, u'source_status_id_str': u'726051946973507584', u'expanded_url': u'http://twitter.com/kdnuggets/status/726051946973507584/photo/1', u'sizes': {u'small': {u'h': 343, u'resize': u'fit', u'w': 340}, u'large': {u'h': 408, u'resize': u'fit', u'w': 404}, u'medium': {u'h': 408, u'resize': u'fit', u'w': 404}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/JUe30cDjoI', u'media_url_https': u'https://pbs.twimg.com/media/ChN0ZhJW0AA1qc_.jpg', u'source_user_id_str': u'20167623', u'source_status_id': 726051946973507584, u'id_str': u'726051946679947264', u'indices': [109, 132], u'media_url': u'http://pbs.twimg.com/media/ChN0ZhJW0AA1qc_.jpg', u'type': u'photo', u'id': 726051946679947264, u'display_url': u'pic.twitter.com/JUe30cDjoI'}] | 61 | 0.1% |
Other values (13663) | 21017 | 21.4% |
(Missing) | 75011 | 76.2% |

entities_symbols
Categorical

Distinct count | 13
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 0

[] | 98381
[{u'indices': [88, 92], u'text': u'SPY'}] | 1
[{u'indices': [0, 4], u'text': u'BTC'}] | 1
Other values (10) | 10

Toggle details

Value | Count | Frequency (%) |
[] | 98381 | 100.0% |
[{u'indices': [88, 92], u'text': u'SPY'}] | 1 | 0.0% |
[{u'indices': [0, 4], u'text': u'BTC'}] | 1 | 0.0% |
[{u'indices': [105, 110], u'text': u'PANW'}] | 1 | 0.0% |
[{u'indices': [108, 112], u'text': u'SPY'}] | 1 | 0.0% |
[{u'indices': [116, 121], u'text': u'PANW'}] | 1 | 0.0% |
[{u'indices': [131, 133], u'text': u's'}] | 1 | 0.0% |
[{u'indices': [13, 17], u'text': u'USD'}] | 1 | 0.0% |
[{u'indices': [0, 4], u'text': u'USD'}] | 1 | 0.0% |
[{u'indices': [118, 120], u'text': u's'}] | 1 | 0.0% |
[{u'indices': [98, 100], u'text': u'v'}] | 1 | 0.0% |
[{u'indices': [45, 49], u'text': u'PHP'}, {u'indices': [52, 57], u'text': u'Java'}, {u'indices': [60, 67], u'text': u'Python'}, {u'indices': [70, 75], u'text': u'HTML'}, {u'indices': [78, 80], u'text': u'C'}, {u'indices': [87, 89], u'text': u'C'}] | 1 | 0.0% |
[{u'indices': [51, 56], u'text': u'NFLX'}] | 1 | 0.0% |

entities_urls
Categorical

Distinct count | 29672
Unique (%) | 46.0%
Missing (%) | 34.4%
Missing (n) | 33879

[] | 22872
[{u'url': u'https://t.co/99ttVa37RC', u'indices': [82, 105], u'expanded_url': u'http://bit.ly/1rrY3i3', u'display_url': u'bit.ly/1rrY3i3'}] | 145
[{u'url': u'https://t.co/m4576sRH5a', u'indices': [88, 111], u'expanded_url': u'http://youtu.be/ys8fyr_hxws?a', u'display_url': u'youtu.be/ys8fyr_hxws?a'}] | 129
Other values (29668) | 41368
(Missing) | 33879

Toggle details

Value | Count | Frequency (%) |
[] | 22872 | 23.2% |
[{u'url': u'https://t.co/99ttVa37RC', u'indices': [82, 105], u'expanded_url': u'http://bit.ly/1rrY3i3', u'display_url': u'bit.ly/1rrY3i3'}] | 145 | 0.1% |
[{u'url': u'https://t.co/m4576sRH5a', u'indices': [88, 111], u'expanded_url': u'http://youtu.be/ys8fyr_hxws?a', u'display_url': u'youtu.be/ys8fyr_hxws?a'}] | 129 | 0.1% |
[{u'url': u'https://t.co/hOdcRLTG0k', u'indices': [75, 98], u'expanded_url': u'http://bit.ly/1NUIT9t', u'display_url': u'bit.ly/1NUIT9t'}] | 126 | 0.1% |
[{u'url': u'https://t.co/qhwzvuhl1t', u'indices': [114, 137], u'expanded_url': u'http://tinyurl.com/gr89wcl', u'display_url': u'tinyurl.com/gr89wcl'}] | 107 | 0.1% |
[{u'url': u'https://t.co/Xe205pWGuq', u'indices': [40, 63], u'expanded_url': u'http://bit.ly/20gNQir', u'display_url': u'bit.ly/20gNQir'}] | 97 | 0.1% |
[{u'url': u'https://t.co/TLsTPzBGel', u'indices': [82, 105], u'expanded_url': u'http://bit.ly/electricity4all', u'display_url': u'bit.ly/electricity4all'}] | 95 | 0.1% |
[{u'url': u'https://t.co/i019MUteJw', u'indices': [113, 136], u'expanded_url': u'http://bit.ly/1U9mRni', u'display_url': u'bit.ly/1U9mRni'}] | 93 | 0.1% |
[{u'url': u'https://t.co/lVK5ggmUG4', u'indices': [53, 76], u'expanded_url': u'http://bit.ly/1UUgu9Q', u'display_url': u'bit.ly/1UUgu9Q'}] | 92 | 0.1% |
[{u'indices': [88, 111], u'url': u'https://t.co/m4576sRH5a', u'expanded_url': u'http://youtu.be/ys8fyr_hxws?a', u'display_url': u'youtu.be/ys8fyr_hxws?a'}] | 91 | 0.1% |
[{u'url': u'https://t.co/mO4MqPAzTX', u'indices': [99, 122], u'expanded_url': u'https://goo.gl/mbRBdI', u'display_url': u'goo.gl/mbRBdI'}] | 90 | 0.1% |
[{u'url': u'https://t.co/rXlDQJBdmz', u'indices': [76, 99], u'expanded_url': u'http://bit.ly/22h94TK', u'display_url': u'bit.ly/22h94TK'}] | 88 | 0.1% |
[{u'url': u'https://t.co/F9WgHsGkgm', u'indices': [115, 138], u'expanded_url': u'http://bit.ly/HBHacking', u'display_url': u'bit.ly/HBHacking'}] | 84 | 0.1% |
[{u'indices': [115, 138], u'url': u'https://t.co/IW0kXRWfom', u'expanded_url': u'https://python.libhunt.com/', u'display_url': u'python.libhunt.com'}] | 80 | 0.1% |
[{u'url': u'https://t.co/vlmg0ClnKw', u'indices': [43, 66], u'expanded_url': u'http://bit.ly/20gNQir', u'display_url': u'bit.ly/20gNQir'}] | 80 | 0.1% |
[{u'url': u'https://t.co/VIsSSyzahj', u'indices': [63, 86], u'expanded_url': u'http://buff.ly/1pEH7E9', u'display_url': u'buff.ly/1pEH7E9'}] | 78 | 0.1% |
[{u'url': u'https://t.co/TLsTPzBGel', u'indices': [101, 124], u'expanded_url': u'http://bit.ly/electricity4all', u'display_url': u'bit.ly/electricity4all'}] | 69 | 0.1% |
[{u'url': u'https://t.co/YhuSawVd5q', u'indices': [82, 105], u'expanded_url': u'http://ti.me/22AtSAl', u'display_url': u'ti.me/22AtSAl'}] | 67 | 0.1% |
[{u'indices': [89, 112], u'url': u'https://t.co/hapACvDtXW', u'expanded_url': u'http://buff.ly/1r5t0bt', u'display_url': u'buff.ly/1r5t0bt'}] | 66 | 0.1% |
[{u'url': u'https://t.co/GNn3o2sZoz', u'indices': [85, 108], u'expanded_url': u'http://buff.ly/1NXQEvo', u'display_url': u'buff.ly/1NXQEvo'}] | 61 | 0.1% |
Other values (29651) | 39904 | 40.6% |
(Missing) | 33879 | 34.4% |

entities_user_mentions
Categorical

Distinct count | 16712
Unique (%) | 17.4%
Missing (%) | 2.4%
Missing (n) | 2379

[] | 52071
[{u'indices': [3, 12], u'id_str': u'30417501', u'screen_name': u'msisodia', u'name': u'Manish Sisodia', u'id': 30417501}] | 1809
[{u'indices': [3, 14], u'id_str': u'534563976', u'screen_name': u'KirkDBorne', u'name': u'Kirk Borne', u'id': 534563976}] | 380
Other values (16708) | 41754
(Missing) | 2379

Toggle details

Value | Count | Frequency (%) |
[] | 52071 | 52.9% |
[{u'indices': [3, 12], u'id_str': u'30417501', u'screen_name': u'msisodia', u'name': u'Manish Sisodia', u'id': 30417501}] | 1809 | 1.8% |
[{u'indices': [3, 14], u'id_str': u'534563976', u'screen_name': u'KirkDBorne', u'name': u'Kirk Borne', u'id': 534563976}] | 380 | 0.4% |
[{u'indices': [3, 16], u'id_str': u'49413866', u'screen_name': u'randal_olson', u'name': u'Randy Olson', u'id': 49413866}] | 326 | 0.3% |
[{u'indices': [3, 16], u'id': 49413866, u'id_str': u'49413866', u'name': u'Randy Olson', u'screen_name': u'randal_olson'}] | 324 | 0.3% |
[{u'indices': [3, 19], u'screen_name': u'Delilah_Alvares', u'id': 4804550526, u'name': u'Delilah Alvares', u'id_str': u'4804550526'}] | 308 | 0.3% |
[{u'indices': [3, 12], u'id_str': u'3331829713', u'screen_name': u'FTWDFans', u'name': u'#TWD Fan Page', u'id': 3331829713}] | 263 | 0.3% |
[{u'indices': [3, 18], u'id_str': u'14174897', u'screen_name': u'analyticbridge', u'name': u'Big Data Science', u'id': 14174897}] | 251 | 0.3% |
[{u'indices': [3, 16], u'screen_name': u'randal_olson', u'id': 49413866, u'name': u'Randy Olson', u'id_str': u'49413866'}] | 220 | 0.2% |
[{u'indices': [3, 18], u'id': 14174897, u'id_str': u'14174897', u'name': u'Big Data Science', u'screen_name': u'analyticbridge'}] | 207 | 0.2% |
[{u'indices': [3, 14], u'id': 534563976, u'id_str': u'534563976', u'name': u'Kirk Borne', u'screen_name': u'KirkDBorne'}] | 175 | 0.2% |
[{u'indices': [3, 16], u'id_str': u'373620985', u'screen_name': u'PythonWeekly', u'name': u'Python Weekly', u'id': 373620985}] | 170 | 0.2% |
[{u'indices': [3, 18], u'screen_name': u'analyticbridge', u'id': 14174897, u'name': u'Big Data Science', u'id_str': u'14174897'}] | 166 | 0.2% |
[{u'indices': [3, 18], u'id_str': u'2445802928', u'screen_name': u'pythontrending', u'name': u'Python Trending', u'id': 2445802928}] | 151 | 0.2% |
[{u'indices': [3, 17], u'id_str': u'1637123371', u'screen_name': u'SneakerPics23', u'name': u'Sneaker Pics', u'id': 1637123371}] | 150 | 0.2% |
[{u'indices': [3, 12], u'id_str': u'14585767', u'screen_name': u'kubernan', u'name': u'Laurent MILTGEN', u'id': 14585767}] | 145 | 0.1% |
[{u'indices': [3, 17], u'id_str': u'3407121572', u'screen_name': u'fashionkiIIas', u'name': u'Fashionable KiIIas', u'id': 3407121572}] | 139 | 0.1% |
[{u'indices': [3, 18], u'id_str': u'555031989', u'screen_name': u'Ronald_vanLoon', u'name': u'Ronald van Loon', u'id': 555031989}] | 137 | 0.1% |
[{u'indices': [3, 17], u'id': 163154809, u'id_str': u'163154809', u'name': u'Alice Goldfuss', u'screen_name': u'alicegoldfuss'}] | 131 | 0.1% |
[{u'indices': [3, 13], u'id_str': u'20167623', u'screen_name': u'kdnuggets', u'name': u'Gregory Piatetsky', u'id': 20167623}] | 129 | 0.1% |
Other values (16691) | 38362 | 39.0% |
(Missing) | 2379 | 2.4% |

favorite_count
Numeric

Distinct count | 111
Unique (%) | 0.1%
Missing (%) | 0.0%
Missing (n) | 0

Mean | 0.59821
Minimum | 0
Maximum | 1165
Zeros (%) | 82.2%

Toggle details

Quantile statistics

Minimum | 0
5-th percentile | 0
Q1 | 0
Median | 0
Q3 | 0
95-th percentile | 2
Maximum | 1165
Range | 1165
Interquartile range | 0

Descriptive statistics

Standard deviation | 6.6348
Coef of variation | 11.091
Kurtosis | 13257
Mean | 0.59821
MAD | 0.98313
Skewness | 95.43
Sum | 58860
Variance | 44.02
Memory size | 768.8 KiB

favorited
Constant

This variable is constant and should be ignored for analysis

Constant value | False

geo_coordinates
Categorical

Distinct count | 184
Unique (%) | 56.6%
Missing (%) | 99.7%
Missing (n) | 98068

[38.9784453, -76.4921829] | 15
[42.3600825, -71.0588801] | 13
[37.5364134, -122.2455364] | 9
Other values (180) | 288
(Missing) | 98068

Toggle details

Value | Count | Frequency (%) |
[38.9784453, -76.4921829] | 15 | 0.0% |
[42.3600825, -71.0588801] | 13 | 0.0% |
[37.5364134, -122.2455364] | 9 | 0.0% |
[37.4418834, -122.1430195] | 6 | 0.0% |
[39.9205411, -105.0866504] | 6 | 0.0% |
[-6.21167266, 106.81396893] | 5 | 0.0% |
[33.046233, -96.994174] | 4 | 0.0% |
[44.9260794, -93.4044187] | 4 | 0.0% |
[34.02875, -118.4717975] | 4 | 0.0% |
[30.401356, -97.7525352] | 4 | 0.0% |
[33.7489954, -84.3879824] | 4 | 0.0% |
[9.61432594, 123.93939268] | 4 | 0.0% |
[41.8239891, -71.4128343] | 4 | 0.0% |
[37.4852152, -122.2363548] | 4 | 0.0% |
[35.9940329, -78.898619] | 3 | 0.0% |
[54.0633, -2.88424] | 3 | 0.0% |
[40.7142, -74.0064] | 3 | 0.0% |
[41.49932, -81.6943605] | 3 | 0.0% |
[33.6588951, -117.8282121] | 3 | 0.0% |
[33.68933986, -117.95339591] | 3 | 0.0% |
Other values (163) | 221 | 0.2% |
(Missing) | 98068 | 99.7% |

geo_type
Categorical

Distinct count | 2
Unique (%) | 0.6%
Missing (%) | 99.7%
Missing (n) | 98068

Point | 325
(Missing) | 98068

Toggle details

Value | Count | Frequency (%) |
Point | 325 | 0.3% |
(Missing) | 98068 | 99.7% |

id
Numeric

Distinct count | 97449
Unique (%) | 99.0%
Missing (%) | 0.0%
Missing (n) | 0

Mean | 7.2435e+17
Minimum | 721430635231911936
Maximum | 727529937045872644
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 721430635231911936
5-th percentile | 7.2177e+17
Q1 | 7.2286e+17
Median | 7.2426e+17
Q3 | 7.2573e+17
95-th percentile | 7.2721e+17
Maximum | 727529937045872644
Range | 6099301813960708
Interquartile range | 2.8662e+15

Descriptive statistics

Standard deviation | 1.7143e+15
Coef of variation | 0.0023667
Kurtosis | -1.1128
Mean | 7.2435e+17
MAD | 1.473e+15
Skewness | 0.14224
Sum | -7619339832347346675
Variance | 2.9389e+3
Memory size | 768.8 KiB

id_str
Highly correlated

This variable is highly correlated with `id` and should be ignored for analysis

Correlation | 1

in_reply_to_screen_name
Categorical

Distinct count | 4467
Unique (%) | 72.4%
Missing (%) | 93.7%
Missing (n) | 92226

AlbinoNagaBoy | 76
MC5_Python | 31
SnakeBytesTV | 22
Other values (4463) | 6038
(Missing) | 92226

Toggle details

Value | Count | Frequency (%) |
AlbinoNagaBoy | 76 | 0.1% |
MC5_Python | 31 | 0.0% |
SnakeBytesTV | 22 | 0.0% |
Cyptic_Python | 19 | 0.0% |
masonasons | 19 | 0.0% |
AlbinoCornsnxke | 18 | 0.0% |
Python_Cyptic | 17 | 0.0% |
JohnCleese | 15 | 0.0% |
kuramanga | 15 | 0.0% |
msisodia | 14 | 0.0% |
PythonGB | 13 | 0.0% |
eevee | 13 | 0.0% |
DrSoulHope_ | 12 | 0.0% |
Python_85 | 12 | 0.0% |
mikegrimshaw2 | 12 | 0.0% |
randal_olson | 12 | 0.0% |
grayj_ | 11 | 0.0% |
ThePSF | 11 | 0.0% |
GoDz_Leofur | 11 | 0.0% |
Raimuteru | 10 | 0.0% |
Other values (4446) | 5804 | 5.9% |
(Missing) | 92226 | 93.7% |

in_reply_to_status_id
Numeric

Distinct count | 5028
Unique (%) | 95.0%
Missing (%) | 94.6%
Missing (n) | 93099

Mean | 7.2387e+17
Minimum | 4.6637e+17
Maximum | 7.2753e+17
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 4.6637e+17
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 7.2753e+17
Range | 2.6115e+17
Interquartile range |

Descriptive statistics

Standard deviation | 8.5396e+15
Coef of variation | 0.011797
Kurtosis | 565.48
Mean | 7.2387e+17
MAD | 2.0589e+15
Skewness | -21.815
Sum | 3.8322e+21
Variance | 7.2925e+31
Memory size | 768.8 KiB

in_reply_to_status_id_str
Highly correlated

This variable is highly correlated with `in_reply_to_status_id` and should be ignored for analysis

Correlation | 1

in_reply_to_user_id
Numeric

Distinct count | 4463
Unique (%) | 72.4%
Missing (%) | 93.7%
Missing (n) | 92226

Mean | 2.3003e+16
Minimum | 409
Maximum | 7.2675e+17
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 409
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 7.2675e+17
Range | 7.2675e+17
Interquartile range |

Descriptive statistics

Standard deviation | 1.2632e+17
Coef of variation | 5.4913
Kurtosis | 26.216
Mean | 2.3003e+16
MAD | 4.453e+16
Skewness | 5.3107
Sum | 1.4186e+2
Variance | 1.5957e+34
Memory size | 768.8 KiB

in_reply_to_user_id_str
Highly correlated

This variable is highly correlated with `in_reply_to_user_id` and should be ignored for analysis

Correlation | 1

is_quote_status
Numeric

Distinct count | 2
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 0

Mean | 0.02238
Minimum | False
Maximum | True
Zeros (%) | 97.8%

Toggle details

Quantile statistics

Minimum | False
5-th percentile | 0
Q1 | 0
Median | 0
Q3 | 0
95-th percentile | 0
Maximum | True
Range | True
Interquartile range | 0

Descriptive statistics

Standard deviation | 0.14792
Coef of variation | 6.6094
Kurtosis | 39.708
Mean | 0.02238
MAD | 0.043758
Skewness | 6.4581
Sum | 2202
Variance | 0.021879
Memory size | 96.2 KiB

lang
Categorical

Distinct count | 5
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 0

en | 98387
in | 3
es | 1
Other values (2) | 2

Toggle details

Value | Count | Frequency (%) |
en | 98387 | 100.0% |
in | 3 | 0.0% |
es | 1 | 0.0% |
und | 1 | 0.0% |
ru | 1 | 0.0% |

lat
Numeric

Distinct count | 184
Unique (%) | 56.6%
Missing (%) | 99.7%
Missing (n) | 98068

Mean | 33.934
Minimum | -33.925
Maximum | 59.801
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | -33.925
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 59.801
Range | 93.726
Interquartile range |

Descriptive statistics

Standard deviation | 16.855
Coef of variation | 0.49671
Kurtosis | 5.3495
Mean | 33.934
MAD | 10.38
Skewness | -2.2806
Sum | 11028
Variance | 284.1
Memory size | 768.8 KiB

lon
Numeric

Distinct count | 184
Unique (%) | 56.6%
Missing (%) | 99.7%
Missing (n) | 98068

Mean | -56.554
Minimum | -123.01
Maximum | 151.74
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | -123.01
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 151.74
Range | 274.75
Interquartile range |

Descriptive statistics

Standard deviation | 71.105
Coef of variation | -1.2573
Kurtosis | 0.99508
Mean | -56.554
MAD | 55.355
Skewness | 1.4185
Sum | -18380
Variance | 5055.9
Memory size | 768.8 KiB

metadata_iso_language_code
Categorical

Distinct count | 5
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 0

en | 98387
in | 3
es | 1
Other values (2) | 2

Toggle details

Value | Count | Frequency (%) |
en | 98387 | 100.0% |
in | 3 | 0.0% |
es | 1 | 0.0% |
und | 1 | 0.0% |
ru | 1 | 0.0% |

metadata_result_type
Constant

This variable is constant and should be ignored for analysis

Constant value | recent

place_bounding_box_coordinates
Categorical

Distinct count | 607
Unique (%) | 47.4%
Missing (%) | 98.7%
Missing (n) | 97112

[[[-74.026675, 40.683935], [-73.910408, 40.683935], [-73.910408, 40.877483], [-74.026675, 40.877483]]] | 33
[[[-117.282538, 32.53962], [-116.9274403, 32.53962], [-116.9274403, 33.0804044], [-117.282538, 33.0804044]]] | 23
[[[-122.514926, 37.708075], [-122.357031, 37.708075], [-122.357031, 37.833238], [-122.514926, 37.833238]]] | 20
Other values (603) | 1205
(Missing) | 97112

Toggle details

Value | Count | Frequency (%) |
[[[-74.026675, 40.683935], [-73.910408, 40.683935], [-73.910408, 40.877483], [-74.026675, 40.877483]]] | 33 | 0.0% |
[[[-117.282538, 32.53962], [-116.9274403, 32.53962], [-116.9274403, 33.0804044], [-117.282538, 33.0804044]]] | 23 | 0.0% |
[[[-122.514926, 37.708075], [-122.357031, 37.708075], [-122.357031, 37.833238], [-122.514926, 37.833238]]] | 20 | 0.0% |
[[[-85.9730292, 42.943183], [-85.876713, 42.943183], [-85.876713, 42.99425], [-85.9730292, 42.99425]]] | 19 | 0.0% |
[[[-71.191421, 42.227797], [-70.986004, 42.227797], [-70.986004, 42.399542], [-71.191421, 42.399542]]] | 18 | 0.0% |
[[[-84.576827, 33.6475029], [-84.289385, 33.6475029], [-84.289385, 33.8868859], [-84.576827, 33.8868859]]] | 16 | 0.0% |
[[[2.2241006, 48.8155214], [2.4699053, 48.8155214], [2.4699053, 48.9021461], [2.2241006, 48.9021461]]] | 15 | 0.0% |
[[[-76.5533209, 38.941032], [-76.468263, 38.941032], [-76.468263, 38.9989], [-76.5533209, 38.9989]]] | 15 | 0.0% |
[[[-118.668404, 33.704538], [-118.155409, 33.704538], [-118.155409, 34.337041], [-118.668404, 34.337041]]] | 14 | 0.0% |
[[[-122.436232, 47.4953154], [-122.2249728, 47.4953154], [-122.2249728, 47.734319], [-122.436232, 47.734319]]] | 14 | 0.0% |
[[[-122.28853, 37.443954], [-122.177339, 37.443954], [-122.177339, 37.550633], [-122.28853, 37.550633]]] | 13 | 0.0% |
[[[-97.928935, 30.127892], [-97.5805133, 30.127892], [-97.5805133, 30.5187994], [-97.928935, 30.5187994]]] | 12 | 0.0% |
[[[-6.387438, 53.2987449], [-6.1078047, 53.2987449], [-6.1078047, 53.4110598], [-6.387438, 53.4110598]]] | 12 | 0.0% |
[[[-87.940033, 41.644102], [-87.523993, 41.644102], [-87.523993, 42.0230669], [-87.940033, 42.0230669]]] | 10 | 0.0% |
[[[-0.112442, 51.5068], [-0.0733794, 51.5068], [-0.0733794, 51.522161], [-0.112442, 51.522161]]] | 9 | 0.0% |
[[[-79.76259, 40.477383], [-71.777492, 40.477383], [-71.777492, 45.015851], [-79.76259, 45.015851]]] | 8 | 0.0% |
[[[-77.119401, 38.801826], [-76.909396, 38.801826], [-76.909396, 38.9953797], [-77.119401, 38.9953797]]] | 8 | 0.0% |
[[[-87.634643, 24.396308], [-79.974307, 24.396308], [-79.974307, 31.001056], [-87.634643, 31.001056]]] | 8 | 0.0% |
[[[-71.160356, 42.352429], [-71.064398, 42.352429], [-71.064398, 42.4039663], [-71.160356, 42.4039663]]] | 8 | 0.0% |
[[[-95.823268, 29.522325], [-95.069705, 29.522325], [-95.069705, 30.1546646], [-95.823268, 30.1546646]]] | 7 | 0.0% |
Other values (586) | 999 | 1.0% |
(Missing) | 97112 | 98.7% |

place_bounding_box_type
Categorical

Distinct count | 2
Unique (%) | 0.2%
Missing (%) | 98.7%
Missing (n) | 97112

Polygon | 1281
(Missing) | 97112

Toggle details

Value | Count | Frequency (%) |
Polygon | 1281 | 1.3% |
(Missing) | 97112 | 98.7% |

place_contained_within
Categorical

Distinct count | 2
Unique (%) | 0.2%
Missing (%) | 98.7%
Missing (n) | 97112

[] | 1281
(Missing) | 97112

Toggle details

Value | Count | Frequency (%) |
[] | 1281 | 1.3% |
(Missing) | 97112 | 98.7% |

place_country
Categorical

Distinct count | 46
Unique (%) | 3.9%
Missing (%) | 98.8%
Missing (n) | 97221

United States | 750
United Kingdom | 147
Canada | 41
Other values (42) | 234
(Missing) | 97221

Toggle details

Value | Count | Frequency (%) |
United States | 750 | 0.8% |
United Kingdom | 147 | 0.1% |
Canada | 41 | 0.0% |
Australia | 31 | 0.0% |
Deutschland | 22 | 0.0% |
France | 21 | 0.0% |
Ireland | 16 | 0.0% |
Brasil | 15 | 0.0% |
Italia | 14 | 0.0% |
Polska | 13 | 0.0% |
South Africa | 12 | 0.0% |
Republika ng Pilipinas | 12 | 0.0% |
Malaysia | 12 | 0.0% |
Nederland | 6 | 0.0% |
Indonesia | 6 | 0.0% |
Schweiz | 4 | 0.0% |
Colombia | 4 | 0.0% |
Bangladesh | 4 | 0.0% |
Danmark | 3 | 0.0% |
Sverige | 3 | 0.0% |
Other values (25) | 36 | 0.0% |
(Missing) | 97221 | 98.8% |

place_country_code
Categorical

Distinct count | 71
Unique (%) | 5.6%
Missing (%) | 98.7%
Missing (n) | 97115

US | 750
GB | 147
CA | 41
Other values (67) | 340
(Missing) | 97115

Toggle details

Value | Count | Frequency (%) |
US | 750 | 0.8% |
GB | 147 | 0.1% |
CA | 41 | 0.0% |
IN | 36 | 0.0% |
AU | 31 | 0.0% |
DE | 22 | 0.0% |
FR | 21 | 0.0% |
IE | 16 | 0.0% |
BR | 15 | 0.0% |
IT | 14 | 0.0% |
PL | 13 | 0.0% |
PH | 12 | 0.0% |
MY | 12 | 0.0% |
ZA | 12 | 0.0% |
ES | 9 | 0.0% |
SG | 7 | 0.0% |
NL | 6 | 0.0% |
ID | 6 | 0.0% |
MX | 5 | 0.0% |
BE | 5 | 0.0% |
Other values (50) | 98 | 0.1% |
(Missing) | 97115 | 98.7% |

place_full_name
Categorical

Distinct count | 587
Unique (%) | 46.7%
Missing (%) | 98.7%
Missing (n) | 97135

Manhattan, NY | 33
San Diego, CA | 23
San Francisco, CA | 20
Other values (583) | 1182
(Missing) | 97135

Toggle details

Value | Count | Frequency (%) |
Manhattan, NY | 33 | 0.0% |
San Diego, CA | 23 | 0.0% |
San Francisco, CA | 20 | 0.0% |
Allendale, MI | 19 | 0.0% |
Boston, MA | 18 | 0.0% |
Atlanta, GA | 16 | 0.0% |
Seattle, WA | 15 | 0.0% |
Paris, France | 15 | 0.0% |
Annapolis, MD | 15 | 0.0% |
Los Angeles, CA | 14 | 0.0% |
Redwood City, CA | 13 | 0.0% |
Austin, TX | 12 | 0.0% |
Dublin City, Ireland | 12 | 0.0% |
Chicago, IL | 10 | 0.0% |
City of London, London | 9 | 0.0% |
Cambridge, MA | 8 | 0.0% |
Washington, DC | 8 | 0.0% |
New York, USA | 8 | 0.0% |
Florida, USA | 8 | 0.0% |
Berlin, Germany | 7 | 0.0% |
Other values (566) | 975 | 1.0% |
(Missing) | 97135 | 98.7% |

place_id
Categorical

Distinct count | 609
Unique (%) | 47.5%
Missing (%) | 98.7%
Missing (n) | 97112

01a9a39529b27f36 | 33
a592bd6ceb1319f7 | 23
5a110d312052166f | 20
Other values (605) | 1205
(Missing) | 97112

Toggle details

Value | Count | Frequency (%) |
01a9a39529b27f36 | 33 | 0.0% |
a592bd6ceb1319f7 | 23 | 0.0% |
5a110d312052166f | 20 | 0.0% |
5b0caebf50f0bf61 | 19 | 0.0% |
67b98f17fdcf20be | 18 | 0.0% |
8173485c72e78ca5 | 16 | 0.0% |
09f6a7707f18e0b1 | 15 | 0.0% |
aa509e938179ea44 | 15 | 0.0% |
300bcc6e23a88361 | 14 | 0.0% |
3b77caf94bfc81fe | 14 | 0.0% |
a409256339a7c6a1 | 13 | 0.0% |
7dde0febc9ef245b | 12 | 0.0% |
c3f37afa9efcf94b | 12 | 0.0% |
1d9a5370a355ab0c | 10 | 0.0% |
3eb2c704fe8a50cb | 9 | 0.0% |
94965b2c45386f87 | 8 | 0.0% |
4ec01c9dbc693497 | 8 | 0.0% |
01fbe706f872cb32 | 8 | 0.0% |
8193d87541f11dfb | 8 | 0.0% |
3ad0f706b3fa62a8 | 7 | 0.0% |
Other values (588) | 999 | 1.0% |
(Missing) | 97112 | 98.7% |

place_name
Categorical

Distinct count | 582
Unique (%) | 46.1%
Missing (%) | 98.7%
Missing (n) | 97131

Manhattan | 35
San Diego | 23
San Francisco | 20
Other values (578) | 1184
(Missing) | 97131

Toggle details

Value | Count | Frequency (%) |
Manhattan | 35 | 0.0% |
San Diego | 23 | 0.0% |
San Francisco | 20 | 0.0% |
Allendale | 19 | 0.0% |
Boston | 18 | 0.0% |
Atlanta | 16 | 0.0% |
Seattle | 15 | 0.0% |
Paris | 15 | 0.0% |
Annapolis | 15 | 0.0% |
Los Angeles | 14 | 0.0% |
Redwood City | 13 | 0.0% |
Austin | 13 | 0.0% |
Dublin City | 12 | 0.0% |
Cambridge | 10 | 0.0% |
Chicago | 10 | 0.0% |
Washington | 9 | 0.0% |
City of London | 9 | 0.0% |
New York | 8 | 0.0% |
Florida | 8 | 0.0% |
Maryland | 7 | 0.0% |
Other values (561) | 973 | 1.0% |
(Missing) | 97131 | 98.7% |

place_place_type
Categorical

Distinct count | 6
Unique (%) | 0.5%
Missing (%) | 98.7%
Missing (n) | 97112

city | 1041
admin | 130
neighborhood | 45
Other values (2) | 65
(Missing) | 97112

Toggle details

Value | Count | Frequency (%) |
city | 1041 | 1.1% |
admin | 130 | 0.1% |
neighborhood | 45 | 0.0% |
country | 45 | 0.0% |
poi | 20 | 0.0% |
(Missing) | 97112 | 98.7% |

place_url
Categorical

Distinct count | 609
Unique (%) | 47.5%
Missing (%) | 98.7%
Missing (n) | 97112

https://api.twitter.com/1.1/geo/id/01a9a39529b27f36.json | 33
https://api.twitter.com/1.1/geo/id/a592bd6ceb1319f7.json | 23
https://api.twitter.com/1.1/geo/id/5a110d312052166f.json | 20
Other values (605) | 1205
(Missing) | 97112

Toggle details

Value | Count | Frequency (%) |
https://api.twitter.com/1.1/geo/id/01a9a39529b27f36.json | 33 | 0.0% |
https://api.twitter.com/1.1/geo/id/a592bd6ceb1319f7.json | 23 | 0.0% |
https://api.twitter.com/1.1/geo/id/5a110d312052166f.json | 20 | 0.0% |
https://api.twitter.com/1.1/geo/id/5b0caebf50f0bf61.json | 19 | 0.0% |
https://api.twitter.com/1.1/geo/id/67b98f17fdcf20be.json | 18 | 0.0% |
https://api.twitter.com/1.1/geo/id/8173485c72e78ca5.json | 16 | 0.0% |
https://api.twitter.com/1.1/geo/id/09f6a7707f18e0b1.json | 15 | 0.0% |
https://api.twitter.com/1.1/geo/id/aa509e938179ea44.json | 15 | 0.0% |
https://api.twitter.com/1.1/geo/id/300bcc6e23a88361.json | 14 | 0.0% |
https://api.twitter.com/1.1/geo/id/3b77caf94bfc81fe.json | 14 | 0.0% |
https://api.twitter.com/1.1/geo/id/a409256339a7c6a1.json | 13 | 0.0% |
https://api.twitter.com/1.1/geo/id/c3f37afa9efcf94b.json | 12 | 0.0% |
https://api.twitter.com/1.1/geo/id/7dde0febc9ef245b.json | 12 | 0.0% |
https://api.twitter.com/1.1/geo/id/1d9a5370a355ab0c.json | 10 | 0.0% |
https://api.twitter.com/1.1/geo/id/3eb2c704fe8a50cb.json | 9 | 0.0% |
https://api.twitter.com/1.1/geo/id/94965b2c45386f87.json | 8 | 0.0% |
https://api.twitter.com/1.1/geo/id/01fbe706f872cb32.json | 8 | 0.0% |
https://api.twitter.com/1.1/geo/id/8193d87541f11dfb.json | 8 | 0.0% |
https://api.twitter.com/1.1/geo/id/4ec01c9dbc693497.json | 8 | 0.0% |
https://api.twitter.com/1.1/geo/id/1c69a67ad480e1b1.json | 7 | 0.0% |
Other values (588) | 999 | 1.0% |
(Missing) | 97112 | 98.7% |

possibly_sensitive
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 18.0%
Missing (n) | 17708

False | 77060
True | 3625
(Missing) | 17708

Toggle details

Value | Count | Frequency (%) |
False | 77060 | 78.3% |
True | 3625 | 3.7% |
(Missing) | 17708 | 18.0% |

quoted_status_created_at
Categorical

Distinct count | 663
Unique (%) | 87.9%
Missing (%) | 99.2%
Missing (n) | 97639

Sun Apr 24 12:30:30 +0000 2016 | 20
Fri Apr 01 18:43:01 +0000 2016 | 7
Wed Apr 27 17:18:34 +0000 2016 | 6
Other values (659) | 721
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
Sun Apr 24 12:30:30 +0000 2016 | 20 | 0.0% |
Fri Apr 01 18:43:01 +0000 2016 | 7 | 0.0% |
Wed Apr 27 17:18:34 +0000 2016 | 6 | 0.0% |
Mon Apr 25 14:10:27 +0000 2016 | 6 | 0.0% |
Sat Apr 30 16:18:48 +0000 2016 | 5 | 0.0% |
Tue May 03 01:51:52 +0000 2016 | 5 | 0.0% |
Tue Apr 26 15:43:20 +0000 2016 | 5 | 0.0% |
Wed Apr 27 06:56:03 +0000 2016 | 4 | 0.0% |
Sat Apr 23 01:57:42 +0000 2016 | 4 | 0.0% |
Sun Apr 17 20:07:28 +0000 2016 | 4 | 0.0% |
Tue Apr 26 10:15:15 +0000 2016 | 4 | 0.0% |
Fri Apr 22 18:50:23 +0000 2016 | 3 | 0.0% |
Thu Apr 28 12:44:51 +0000 2016 | 3 | 0.0% |
Wed Apr 20 16:11:10 +0000 2016 | 3 | 0.0% |
Sun Apr 24 12:54:34 +0000 2016 | 3 | 0.0% |
Sun Apr 24 01:43:46 +0000 2016 | 3 | 0.0% |
Thu Apr 21 03:59:40 +0000 2016 | 2 | 0.0% |
Tue May 03 15:00:11 +0000 2016 | 2 | 0.0% |
Wed Apr 27 13:40:16 +0000 2016 | 2 | 0.0% |
Tue Apr 19 16:22:07 +0000 2016 | 2 | 0.0% |
Other values (642) | 661 | 0.7% |
(Missing) | 97639 | 99.2% |

quoted_status_entities_hashtags
Categorical

Distinct count | 225
Unique (%) | 30.0%
Missing (%) | 99.2%
Missing (n) | 97642

[] | 499
[{u'indices': [0, 7], u'text': u'python'}, {u'indices': [8, 20], u'text': u'programming'}, {u'indices': [35, 42], u'text': u'coding'}] | 4
[{u'indices': [17, 24], u'text': u'Python'}] | 4
Other values (221) | 244
(Missing) | 97642

Toggle details

Value | Count | Frequency (%) |
[] | 499 | 0.5% |
[{u'indices': [0, 7], u'text': u'python'}, {u'indices': [8, 20], u'text': u'programming'}, {u'indices': [35, 42], u'text': u'coding'}] | 4 | 0.0% |
[{u'indices': [17, 24], u'text': u'Python'}] | 4 | 0.0% |
[{u'indices': [39, 46], u'text': u'Python'}] | 4 | 0.0% |
[{u'indices': [64, 71], u'text': u'rstats'}] | 4 | 0.0% |
[{u'indices': [21, 33], u'text': u'programming'}, {u'indices': [45, 54], u'text': u'benefits'}, {u'indices': [58, 65], u'text': u'python'}] | 3 | 0.0% |
[{u'indices': [31, 38], u'text': u'Python'}] | 3 | 0.0% |
[{u'indices': [75, 82], u'text': u'pydata'}] | 3 | 0.0% |
[{u'indices': [62, 69], u'text': u'Python'}] | 2 | 0.0% |
[{u'indices': [74, 81], u'text': u'python'}] | 2 | 0.0% |
[{u'indices': [11, 19], u'text': u'GraphQL'}] | 2 | 0.0% |
[{u'indices': [8, 15], u'text': u'askSPC'}] | 2 | 0.0% |
[{u'indices': [0, 7], u'text': u'python'}, {u'indices': [71, 79], u'text': u'pyconil'}] | 2 | 0.0% |
[{u'indices': [10, 24], u'text': u'DayAgainstDRM'}] | 2 | 0.0% |
[{u'indices': [122, 128], u'text': u'Cloud'}, {u'indices': [129, 137], u'text': u'Storage'}] | 2 | 0.0% |
[{u'indices': [14, 30], u'text': u'MachineLearning'}, {u'indices': [31, 43], u'text': u'DataScience'}, {u'indices': [44, 55], u'text': u'OpenSource'}, {u'indices': [89, 97], u'text': u'BigData'}, {u'indices': [98, 108], u'text': u'Analytics'}] | 2 | 0.0% |
[{u'indices': [32, 39], u'text': u'Python'}, {u'indices': [62, 74], u'text': u'DataScience'}] | 2 | 0.0% |
[{u'indices': [78, 90], u'text': u'DataScience'}, {u'indices': [91, 107], u'text': u'MachineLearning'}] | 2 | 0.0% |
[{u'indices': [0, 7], u'text': u'python'}] | 2 | 0.0% |
[{u'indices': [82, 88], u'text': u'BASIC'}, {u'indices': [89, 96], u'text': u'Python'}, {u'indices': [97, 109], u'text': u'programming'}] | 1 | 0.0% |
Other values (204) | 204 | 0.2% |
(Missing) | 97642 | 99.2% |

quoted_status_entities_symbols
Categorical

Distinct count | 2
Unique (%) | 0.3%
Missing (%) | 99.2%
Missing (n) | 97639

[] | 754
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
[] | 754 | 0.8% |
(Missing) | 97639 | 99.2% |

quoted_status_entities_urls
Categorical

Distinct count | 190
Unique (%) | 38.0%
Missing (%) | 99.5%
Missing (n) | 97893

[] | 303
[{u'indices': [99, 122], u'url': u'https://t.co/m3SkZoGNUQ', u'expanded_url': u'http://register.automatingosint.com/python-course/', u'display_url': u'register.automatingosint.com/python-course/'}] | 3
[{u'url': u'https://t.co/0gEqu6Q1sP', u'indices': [93, 116], u'expanded_url': u'http://ow.ly/1094pe', u'display_url': u'ow.ly/1094pe'}] | 2
Other values (186) | 192
(Missing) | 97893

Toggle details

Value | Count | Frequency (%) |
[] | 303 | 0.3% |
[{u'indices': [99, 122], u'url': u'https://t.co/m3SkZoGNUQ', u'expanded_url': u'http://register.automatingosint.com/python-course/', u'display_url': u'register.automatingosint.com/python-course/'}] | 3 | 0.0% |
[{u'url': u'https://t.co/0gEqu6Q1sP', u'indices': [93, 116], u'expanded_url': u'http://ow.ly/1094pe', u'display_url': u'ow.ly/1094pe'}] | 2 | 0.0% |
[{u'url': u'https://t.co/8mv1fPZL76', u'indices': [85, 108], u'expanded_url': u'http://buff.ly/1SvZsjr', u'display_url': u'buff.ly/1SvZsjr'}] | 2 | 0.0% |
[{u'url': u'https://t.co/YPYGJjzFUK', u'indices': [84, 107], u'expanded_url': u'http://oreil.ly/DRM-FREE-2016', u'display_url': u'oreil.ly/DRM-FREE-2016'}] | 2 | 0.0% |
[{u'url': u'https://t.co/ALKvFicSyT', u'indices': [65, 88], u'expanded_url': u'http://buff.ly/1SYputP', u'display_url': u'buff.ly/1SYputP'}] | 2 | 0.0% |
[{u'url': u'https://t.co/nupS18Em2B', u'indices': [50, 73], u'expanded_url': u'http://buff.ly/1SvhZL1', u'display_url': u'buff.ly/1SvhZL1'}] | 2 | 0.0% |
[{u'url': u'https://t.co/XM56ubnN99', u'indices': [85, 108], u'expanded_url': u'http://pyddf.de', u'display_url': u'pyddf.de'}] | 2 | 0.0% |
[{u'url': u'https://t.co/YrEJJSfalx', u'indices': [65, 88], u'expanded_url': u'http://bit.ly/1WDB4fl', u'display_url': u'bit.ly/1WDB4fl'}] | 2 | 0.0% |
[{u'url': u'https://t.co/QDMUHWM5YV', u'indices': [46, 69], u'expanded_url': u'http://bit.ly/1SypEKi', u'display_url': u'bit.ly/1SypEKi'}] | 1 | 0.0% |
[{u'url': u'https://t.co/F7mSGDiynz', u'indices': [29, 52], u'expanded_url': u'http://bit.ly/1MXI1Rc', u'display_url': u'bit.ly/1MXI1Rc'}] | 1 | 0.0% |
[{u'url': u'https://t.co/8EhPsCXeAA', u'indices': [72, 95], u'expanded_url': u'http://fb.me/10j8fK9DR', u'display_url': u'fb.me/10j8fK9DR'}] | 1 | 0.0% |
[{u'indices': [67, 90], u'url': u'https://t.co/qTm0yZqFSW', u'expanded_url': u'http://bit.ly/1WzHZ9H', u'display_url': u'bit.ly/1WzHZ9H'}] | 1 | 0.0% |
[{u'indices': [17, 40], u'url': u'https://t.co/ScyD3EkHG7', u'expanded_url': u'http://bit.ly/1PXolOx', u'display_url': u'bit.ly/1PXolOx'}] | 1 | 0.0% |
[{u'url': u'https://t.co/XlzInr9a53', u'indices': [58, 81], u'expanded_url': u'http://buff.ly/23isbrQ', u'display_url': u'buff.ly/23isbrQ'}] | 1 | 0.0% |
[{u'url': u'https://t.co/I0RH4tnkKf', u'indices': [83, 106], u'expanded_url': u'http://bit.ly/1Z3PYdO', u'display_url': u'bit.ly/1Z3PYdO'}] | 1 | 0.0% |
[{u'url': u'https://t.co/BxShhhNVf7', u'indices': [117, 140], u'expanded_url': u'http://meetu.ps/2WsXt7', u'display_url': u'meetu.ps/2WsXt7'}] | 1 | 0.0% |
[{u'indices': [107, 130], u'url': u'https://t.co/14D4FL5JR1', u'expanded_url': u'http://twitter.com/YATSGRANDVIEW/status/723233821668188160/photo/1', u'display_url': u'pic.twitter.com/14D4FL5JR1'}] | 1 | 0.0% |
[{u'url': u'https://t.co/DZfQlS4gwq', u'indices': [103, 126], u'expanded_url': u'https://www.cybrary.it/course/python/', u'display_url': u'cybrary.it/course/python/'}] | 1 | 0.0% |
[{u'url': u'https://t.co/CBhaP6WzR4', u'indices': [39, 62], u'expanded_url': u'http://4.nbcny.com/Gty4WjD', u'display_url': u'4.nbcny.com/Gty4WjD'}] | 1 | 0.0% |
Other values (169) | 169 | 0.2% |
(Missing) | 97893 | 99.5% |

quoted_status_entities_user_mentions
Categorical

Distinct count | 195
Unique (%) | 26.1%
Missing (%) | 99.2%
Missing (n) | 97647

[] | 548
[{u'indices': [75, 84], u'screen_name': u'DataCamp', u'id': 1568606814, u'name': u'DataCamp', u'id_str': u'1568606814'}] | 2
[{u'indices': [38, 49], u'id': 2326251343, u'id_str': u'2326251343', u'name': u'Trey Hunner', u'screen_name': u'treyhunner'}] | 2
Other values (191) | 194
(Missing) | 97647

Toggle details

Value | Count | Frequency (%) |
[] | 548 | 0.6% |
[{u'indices': [75, 84], u'screen_name': u'DataCamp', u'id': 1568606814, u'name': u'DataCamp', u'id_str': u'1568606814'}] | 2 | 0.0% |
[{u'indices': [38, 49], u'id': 2326251343, u'id_str': u'2326251343', u'name': u'Trey Hunner', u'screen_name': u'treyhunner'}] | 2 | 0.0% |
[{u'indices': [50, 62], u'id_str': u'2915491332', u'screen_name': u'ByondTravel', u'name': u'Byond Travel', u'id': 2915491332}] | 2 | 0.0% |
[{u'indices': [0, 7], u'id': 586909317, u'id_str': u'586909317', u'name': u'NWS SPC', u'screen_name': u'NWSSPC'}] | 2 | 0.0% |
[{u'indices': [0, 13], u'screen_name': u'CloudCareers', u'id': 83373746, u'name': u'Cloud Careers', u'id_str': u'83373746'}] | 2 | 0.0% |
[{u'indices': [78, 92], u'id': 3273261744, u'id_str': u'3273261744', u'name': u'Unite Ideas', u'screen_name': u'UN_UniteIdeas'}] | 1 | 0.0% |
[{u'indices': [67, 75], u'screen_name': u'J_Tom70', u'id': 198212918, u'name': u'Tomasz', u'id_str': u'198212918'}] | 1 | 0.0% |
[{u'indices': [64, 80], u'screen_name': u'ServestCatering', u'id': 154569595, u'name': u'Servest Catering', u'id_str': u'154569595'}, {u'indices': [81, 95], u'screen_name': u'victoriabugg1', u'id': 4707441437, u'name': u'Victoria Tomlinson', u'id_str': u'4707441437'}, {u'indices': [96, 111], u'screen_name': u'cruickshanks_t', u'id': 4824293733, u'name': u'Tamara Cruickshanks', u'id_str': u'4824293733'}] | 1 | 0.0% |
[{u'indices': [11, 18], u'id_str': u'80422885', u'screen_name': u'kaggle', u'name': u'Kaggle', u'id': 80422885}] | 1 | 0.0% |
[{u'indices': [0, 16], u'id': 90962704, u'id_str': u'90962704', u'name': u'Reece Shearsmith', u'screen_name': u'ReeceShearsmith'}, {u'indices': [17, 31], u'id': 166966715, u'id_str': u'166966715', u'name': u'Gareth Roberts', u'screen_name': u'OldRoberts953'}, {u'indices': [32, 43], u'id': 164242095, u'id_str': u'164242095', u'name': u'Mark Gatiss', u'screen_name': u'Markgatiss'}] | 1 | 0.0% |
[{u'indices': [76, 82], u'id': 7202792, u'id_str': u'7202792', u'name': u'Zooba', u'screen_name': u'zooba'}] | 1 | 0.0% |
[{u'indices': [0, 8], u'id': 15312928, u'id_str': u'15312928', u'name': u'Interop', u'screen_name': u'interop'}, {u'indices': [17, 27], u'id': 229704742, u'id_str': u'229704742', u'name': u'Kirk Byers', u'screen_name': u'kirkbyers'}] | 1 | 0.0% |
[{u'indices': [28, 38], u'screen_name': u'Cardinals', u'id': 52847728, u'name': u'St. Louis Cardinals', u'id_str': u'52847728'}, {u'indices': [66, 79], u'screen_name': u'JasonHeyward', u'id': 63246225, u'name': u'jheytwotwo', u'id_str': u'63246225'}] | 1 | 0.0% |
[{u'indices': [1, 11], u'id': 175198393, u'id_str': u'175198393', u'name': u'lil boat', u'screen_name': u'lilyachty'}, {u'indices': [29, 44], u'id': 29166305, u'id_str': u'29166305', u'name': u'RiFF RAFF', u'screen_name': u'JODYHiGHROLLER'}] | 1 | 0.0% |
[{u'indices': [29, 41], u'screen_name': u'BaIIPythons', u'id': 3309898397, u'name': u'Ball Pythons', u'id_str': u'3309898397'}] | 1 | 0.0% |
[{u'indices': [22, 34], u'id': 2544208537, u'id_str': u'2544208537', u'name': u'Django Girls', u'screen_name': u'djangogirls'}] | 1 | 0.0% |
[{u'indices': [51, 61], u'screen_name': u'eWEEKNews', u'id': 15856164, u'name': u'eWEEK', u'id_str': u'15856164'}, {u'indices': [86, 93], u'screen_name': u'IBMIoT', u'id': 1953648950, u'name': u'IBM IoT', u'id_str': u'1953648950'}] | 1 | 0.0% |
[{u'indices': [21, 35], u'screen_name': u'ChicagoPython', u'id': 4145734157, u'name': u'ChiPy', u'id_str': u'4145734157'}, {u'indices': [46, 59], u'screen_name': u'SproutSocial', u'id': 42793960, u'name': u'Sprout Social', u'id_str': u'42793960'}] | 1 | 0.0% |
[{u'indices': [50, 61], u'id': 10810102, u'id_str': u'10810102', u'name': u'John Cleese', u'screen_name': u'JohnCleese'}, {u'indices': [62, 71], u'id': 862483279, u'id_str': u'862483279', u'name': u'Eric Idle', u'screen_name': u'EricIdle'}, {u'indices': [72, 85], u'id': 421944319, u'id_str': u'421944319', u'name': u'Terry Gilliam', u'screen_name': u'TerryGilliam'}, {u'indices': [86, 98], u'id': 320134516, u'id_str': u'320134516', u'name': u'Terry Jones', u'screen_name': u'PythonJones'}] | 1 | 0.0% |
Other values (174) | 174 | 0.2% |
(Missing) | 97647 | 99.2% |

quoted_status_favorite_count
Numeric

Distinct count | 159
Unique (%) | 21.1%
Missing (%) | 99.2%
Missing (n) | 97639

Mean | 290.39
Minimum | 0
Maximum | 22699
Zeros (%) | 0.1%

Toggle details

Quantile statistics

Minimum | 0
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 22699
Range | 22699
Interquartile range |

Descriptive statistics

Standard deviation | 1669.7
Coef of variation | 5.7499
Kurtosis | 129.79
Mean | 290.39
MAD | 477.28
Skewness | 10.727
Sum | 218950
Variance | 2787900
Memory size | 768.8 KiB

quoted_status_favorited
Categorical

Distinct count | 2
Unique (%) | 0.3%
Missing (%) | 99.2%
Missing (n) | 97639

False | 754
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
False | 754 | 0.8% |
(Missing) | 97639 | 99.2% |

quoted_status_id
Numeric

Distinct count | 666
Unique (%) | 0.7%
Missing (%) | 1.1%
Missing (n) | 1110

Mean | 5.596e+15
Minimum | -1
Maximum | 7.2752e+17
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | -1
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 7.2752e+17
Range | 7.2752e+17
Interquartile range |

Descriptive statistics

Standard deviation | 6.3368e+16
Coef of variation | 11.324
Kurtosis | 124.31
Mean | 5.596e+15
MAD | 1.1105e+16
Skewness | 11.238
Sum | 5.4439e+2
Variance | 4.0155e+33
Memory size | 768.8 KiB

quoted_status_id_str
Highly correlated

This variable is highly correlated with `quoted_status_id` and should be ignored for analysis

Correlation | 1

quoted_status_is_quote_status
Categorical

Distinct count | 3
Unique (%) | 0.4%
Missing (%) | 99.2%
Missing (n) | 97639

False | 709
True | 45
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
False | 709 | 0.7% |
True | 45 | 0.0% |
(Missing) | 97639 | 99.2% |

quoted_status_lang
Categorical

Distinct count | 16
Unique (%) | 2.1%
Missing (%) | 99.2%
Missing (n) | 97639

en | 704
und | 22
de | 5
Other values (12) | 23
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
en | 704 | 0.7% |
und | 22 | 0.0% |
de | 5 | 0.0% |
es | 4 | 0.0% |
pt | 3 | 0.0% |
fr | 3 | 0.0% |
in | 3 | 0.0% |
cy | 2 | 0.0% |
tl | 2 | 0.0% |
ht | 1 | 0.0% |
zh | 1 | 0.0% |
pl | 1 | 0.0% |
nl | 1 | 0.0% |
uk | 1 | 0.0% |
ro | 1 | 0.0% |
(Missing) | 97639 | 99.2% |

quoted_status_metadata_iso_language_code
Categorical

Distinct count | 2
Unique (%) | 0.3%
Missing (%) | 99.2%
Missing (n) | 97639

en | 754
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
en | 754 | 0.8% |
(Missing) | 97639 | 99.2% |

quoted_status_metadata_result_type
Categorical

Distinct count | 2
Unique (%) | 0.3%
Missing (%) | 99.2%
Missing (n) | 97639

recent | 754
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
recent | 754 | 0.8% |
(Missing) | 97639 | 99.2% |

quoted_status_possibly_sensitive
Categorical

Distinct count | 3
Unique (%) | 0.5%
Missing (%) | 99.4%
Missing (n) | 97807

False | 582
True | 4
(Missing) | 97807

Toggle details

Value | Count | Frequency (%) |
False | 582 | 0.6% |
True | 4 | 0.0% |
(Missing) | 97807 | 99.4% |

quoted_status_retweet_count
Highly correlated

This variable is highly correlated with `quoted_status_favorite_count` and should be ignored for analysis

Correlation | 0.96633

quoted_status_retweeted
Categorical

Distinct count | 2
Unique (%) | 0.3%
Missing (%) | 99.2%
Missing (n) | 97639

False | 754
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
False | 754 | 0.8% |
(Missing) | 97639 | 99.2% |

quoted_status_source
Categorical

Distinct count | 59
Unique (%) | 7.9%
Missing (%) | 99.2%
Missing (n) | 97646

Twitter Web Client | 206
Twitter for iPhone | 166
Twitter for Android | 70
Other values (55) | 305
(Missing) | 97646

Toggle details

Value | Count | Frequency (%) |
Twitter Web Client | 206 | 0.2% |
Twitter for iPhone | 166 | 0.2% |
Twitter for Android | 70 | 0.1% |
TweetDeck | 61 | 0.1% |
Hootsuite | 60 | 0.1% |
Buffer | 50 | 0.1% |
Tweetbot for Mac | 18 | 0.0% |
Twitter Ads | 10 | 0.0% |
Twitter for Mac | 9 | 0.0% |
Twitter for iPad | 8 | 0.0% |
Sprout Social | 7 | 0.0% |
IFTTT | 6 | 0.0% |
twitterfeed | 6 | 0.0% |
SocialFlow | 6 | 0.0% |
Facebook | 4 | 0.0% |
Instagram | 3 | 0.0% |
Echofon | 3 | 0.0% |
Sprinklr | 3 | 0.0% |
LinkedIn | 3 | 0.0% |
WordPress.com | 3 | 0.0% |
Other values (38) | 45 | 0.0% |
(Missing) | 97646 | 99.2% |

quoted_status_text
Categorical

Distinct count | 565
Unique (%) | 86.8%
Missing (%) | 99.3%
Missing (n) | 97742

would you stay in this room for 3 hours straight for 50 billion dollars https://t.co/nFjM5X1Imi | 20
Make a skill that runs on the Amazon Echo with Python in 5 minutes or less https://t.co/nxjwzquJC5 | 7
IITs have been asked to teach Sanskrit: Smriti Irani https://t.co/LYew7hBvJA https://t.co/7eFucdjpmP | 6
Other values (561) | 618
(Missing) | 97742

Toggle details

Value | Count | Frequency (%) |
would you stay in this room for 3 hours straight for 50 billion dollars https://t.co/nFjM5X1Imi | 20 | 0.0% |
Make a skill that runs on the Amazon Echo with Python in 5 minutes or less https://t.co/nxjwzquJC5 | 7 | 0.0% |
IITs have been asked to teach Sanskrit: Smriti Irani https://t.co/LYew7hBvJA https://t.co/7eFucdjpmP | 6 | 0.0% |
New blog post: https://t.co/D8BiNcc9OG | 6 | 0.0% |
Part 6, about data visualization: https://t.co/Zjn0h9cvTy https://t.co/PoDO98Fp8x | 5 | 0.0% |
Intel encourages the OpenStack community to have an open mind and replace Python with Go -- Brave but unfeasible https://t.co/slpYLDyMRA | 5 | 0.0% |
After a year of using NodeJS in production https://t.co/YQ3C1OivjK | 5 | 0.0% |
#python #programming language Easy #coding tips https://t.co/BfpIucjg16 https://t.co/9ZB8VpYFVP | 4 | 0.0% |
I've been trying PyData the last 1-2 years, but will keep using #rstats for a while. https://t.co/MvsN1vwgXC | 4 | 0.0% |
This is what a black anaconda looks like https://t.co/79biQQgtWy | 4 | 0.0% |
One of my best mates at uni had a pet Python. They mad chill https://t.co/iyPVzSWZDk | 4 | 0.0% |
Just released my #Python course. Short, to the point and primes you for learning Python for OSINT: https://t.co/m3SkZoGNUQ | 4 | 0.0% |
Need ideas for the Hermitcraft stream this evening - what'd you guys wanna see? :) | 3 | 0.0% |
New post: "conda-forge and PyData's CentOS moment" https://t.co/zJrYoOTkQx #pydata | 3 | 0.0% |
Python is a powerful #programming language, #benefits of #python https://t.co/TdqwACulT3 https://t.co/SLQqqISsSW | 3 | 0.0% |
Ubuntu 16.04 LTS released with #Python 3.5 as standard, rather than Python 2.7! Progress! https://t.co/0dEyFM6sVd https://t.co/sYkjvn7hzu | 3 | 0.0% |
Writing a line to the end of a file in #Python | 2 | 0.0% |
Which computer programming language is harder: Python or Java? | 2 | 0.0% |
..& I do a lot of functional programming in PHP too with callbacks and closures...that's something JAVA just got now https://t.co/EDmqtlpYdV | 2 | 0.0% |
Learn how to build an IoT-enabled smart parking meter & reserve YOUR own parking space! https://t.co/0gEqu6Q1sP https://t.co/pJ0k6hVKGl | 2 | 0.0% |
Other values (544) | 557 | 0.6% |
(Missing) | 97742 | 99.3% |

quoted_status_truncated
Categorical

Distinct count | 2
Unique (%) | 0.3%
Missing (%) | 99.2%
Missing (n) | 97639

False | 754
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
False | 754 | 0.8% |
(Missing) | 97639 | 99.2% |

quoted_status_user_contributors_enabled
Categorical

Distinct count | 2
Unique (%) | 0.3%
Missing (%) | 99.2%
Missing (n) | 97639

False | 754
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
False | 754 | 0.8% |
(Missing) | 97639 | 99.2% |

quoted_status_user_created_at
Categorical

Distinct count | 587
Unique (%) | 77.9%
Missing (%) | 99.2%
Missing (n) | 97639

Sat Apr 11 01:05:41 +0000 2015 | 20
Wed Mar 19 05:26:29 +0000 2008 | 8
Thu Jul 16 05:05:59 +0000 2015 | 7
Other values (583) | 719
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
Sat Apr 11 01:05:41 +0000 2015 | 20 | 0.0% |
Wed Mar 19 05:26:29 +0000 2008 | 8 | 0.0% |
Thu Jul 16 05:05:59 +0000 2015 | 7 | 0.0% |
Fri Mar 13 00:30:37 +0000 2009 | 7 | 0.0% |
Thu Feb 25 19:06:53 +0000 2016 | 7 | 0.0% |
Tue Sep 11 15:44:20 +0000 2012 | 7 | 0.0% |
Sun Jun 21 20:13:18 +0000 2009 | 7 | 0.0% |
Fri May 01 20:34:48 +0000 2009 | 6 | 0.0% |
Fri Mar 23 16:35:17 +0000 2012 | 6 | 0.0% |
Sun Aug 15 21:28:07 +0000 2010 | 6 | 0.0% |
Mon Aug 11 04:02:18 +0000 2008 | 6 | 0.0% |
Fri Aug 15 19:11:17 +0000 2014 | 6 | 0.0% |
Sun Feb 20 01:07:23 +0000 2011 | 5 | 0.0% |
Tue Feb 20 19:55:29 +0000 2007 | 5 | 0.0% |
Thu Feb 18 21:01:15 +0000 2010 | 4 | 0.0% |
Thu Feb 05 17:37:26 +0000 2009 | 4 | 0.0% |
Thu Nov 19 04:24:29 +0000 2009 | 4 | 0.0% |
Sat Feb 23 00:01:28 +0000 2008 | 4 | 0.0% |
Tue Jan 21 06:25:19 +0000 2014 | 4 | 0.0% |
Sun Feb 15 18:23:03 +0000 2009 | 4 | 0.0% |
Other values (566) | 627 | 0.6% |
(Missing) | 97639 | 99.2% |

quoted_status_user_default_profile
Categorical

Distinct count | 3
Unique (%) | 0.4%
Missing (%) | 99.2%
Missing (n) | 97639

False | 563
True | 191
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
False | 563 | 0.6% |
True | 191 | 0.2% |
(Missing) | 97639 | 99.2% |

quoted_status_user_default_profile_image
Categorical

Distinct count | 3
Unique (%) | 0.4%
Missing (%) | 99.2%
Missing (n) | 97639

False | 753
True | 1
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
False | 753 | 0.8% |
True | 1 | 0.0% |
(Missing) | 97639 | 99.2% |

quoted_status_user_description
Categorical

Distinct count | 496
Unique (%) | 77.4%
Missing (%) | 99.3%
Missing (n) | 97752

only dog can judge me @mia_delrey @ViCXT0RiA @drewftzain | 20
Big data, machine learning, predictive modeling, R, Hadoop, Python, business analytics, data mining, IoT and operations research: resources, tutorials and more. | 8
Itservicestalk brings all the latest news from the IT industry. Explore useful information concerning major IT companies, lesser-known facts & tips on IT | 7
Other values (492) | 606
(Missing) | 97752

Toggle details

Value | Count | Frequency (%) |
only dog can judge me @mia_delrey @ViCXT0RiA @drewftzain | 20 | 0.0% |
Big data, machine learning, predictive modeling, R, Hadoop, Python, business analytics, data mining, IoT and operations research: resources, tutorials and more. | 8 | 0.0% |
Itservicestalk brings all the latest news from the IT industry. Explore useful information concerning major IT companies, lesser-known facts & tips on IT | 7 | 0.0% |
#AI & #MachineLearning researcher. Data tinkerer. Community leader for @DataIsBeautiful. Support my blog: https://t.co/cpRqH03lVP | 7 | 0.0% |
Official Twitter of Amazon Alexa Developers. Follow us for industry insights, voice design tips, inspirational integrations, and more about Amazon #AlexaDev. | 7 | 0.0% |
Data Scientist @MITTERA. Contributor to https://t.co/cAGKd9Kd1W and https://t.co/1M2ranWtjp | 7 | 0.0% |
Creator of @Hunchly. Blogging & training #OSINT techniques. Wrote a couple of @nostarch books. @Bellingcat contributor. Hunter @Arc4dia. | 7 | 0.0% |
Breaking news alerts from India | 6 | 0.0% |
Run @meanmapdotcom, @goodheadsio, @theCodeQuest, @fosslaravel, @justbuildio. Training World Class Developers & Making All Things PHP Fly @Andela | 6 | 0.0% |
Python BDFL. Working at Dropbox. The 'van' has no capital letter! | 6 | 0.0% |
Great coding resources and commentary. Sometimes wise, sometimes ridiculous, always helping you become a better developer. Created by @bendhalpern | 6 | 0.0% |
Tweets about SciPy (Scientific Python) and related topics from @JohnDCook. | 5 | 0.0% |
OpenStack R&D Engineering Manager at Red Hat. Sun alum. GNU maintainer. Former OpenSolaris, GNOME and Cherokee hacker. I void warranties. | 5 | 0.0% |
Data tool maker @cloudera. Creator of pandas, @IbisData. @ApacheArrow @ApacheParquet committer. Wrote Python for Data Analysis. Views are my own | 4 | 0.0% |
Posting mind blowing information. Learn Something daily with us. | 4 | 0.0% |
KDnuggets President, #Analytics, #BigData, #DataMining, #DataScience expert, KDD & SIGKDD co-founder, was Chief Scientist at 2 startups, part-time philosopher. | 4 | 0.0% |
Mr.DRB LasGidi, Oil trader/Sports enthusiast/Artist Management/AR instagram: Teezeedrb . #TrapJungle #TZ11 #MUFC #LAKERNATION #OM bookfreshldrb@gmail.com | 4 | 0.0% |
No Starch Press Founder. We publish books for geeks. I'm probably ranting again. | 4 | 0.0% |
Asst. Prof. CS @txst (tweets my own). Trying to make algorithms better for people. #RecSys, #HCI, @LensKitRS. User-loving zealot. Self-propelled. | 4 | 0.0% |
Software Engineer, Design Enthusiast, Citizen of United States of Strategic Design and Agile Development | 4 | 0.0% |
Other values (475) | 516 | 0.5% |
(Missing) | 97752 | 99.3% |

quoted_status_user_entities_description_urls
Categorical

Distinct count | 63
Unique (%) | 8.5%
Missing (%) | 99.2%
Missing (n) | 97654

[] | 664
[{u'url': u'https://t.co/f4gsbNc00C', u'indices': [118, 141], u'expanded_url': u'http://rocketdatascience.org/', u'display_url': u'rocketdatascience.org'}] | 5
[{u'indices': [106, 129], u'url': u'https://t.co/cpRqH03lVP', u'expanded_url': u'http://patreon.com/randal_olson', u'display_url': u'patreon.com/randal_olson'}] | 4
Other values (59) | 66
(Missing) | 97654

Toggle details

Value | Count | Frequency (%) |
[] | 664 | 0.7% |
[{u'url': u'https://t.co/f4gsbNc00C', u'indices': [118, 141], u'expanded_url': u'http://rocketdatascience.org/', u'display_url': u'rocketdatascience.org'}] | 5 | 0.0% |
[{u'indices': [106, 129], u'url': u'https://t.co/cpRqH03lVP', u'expanded_url': u'http://patreon.com/randal_olson', u'display_url': u'patreon.com/randal_olson'}] | 4 | 0.0% |
[{u'url': u'https://t.co/cpRqH03lVP', u'indices': [106, 129], u'expanded_url': u'http://patreon.com/randal_olson', u'display_url': u'patreon.com/randal_olson'}] | 3 | 0.0% |
[{u'url': u'https://t.co/1ENL6YPAhA', u'indices': [39, 62], u'expanded_url': u'http://twitch.tv/falsesymmetry', u'display_url': u'twitch.tv/falsesymmetry'}] | 3 | 0.0% |
[{u'url': u'https://t.co/wzKnd3knrD', u'indices': [41, 64], u'expanded_url': u'http://www.facebook.com/pyconisrael', u'display_url': u'facebook.com/pyconisrael'}] | 2 | 0.0% |
[{u'url': u'https://t.co/84fK7grnxc', u'indices': [60, 83], u'expanded_url': u'https://bandcamp.com/tl80ssynthwaves', u'display_url': u'bandcamp.com/tl80ssynthwaves'}, {u'url': u'https://t.co/K0DkVgYiGm', u'indices': [86, 109], u'expanded_url': u'https://soundcloud.com/tl80ssynthwaves', u'display_url': u'soundcloud.com/tl80ssynthwaves'}, {u'url': u'https://t.co/2oNmzJqA5d', u'indices': [112, 135], u'expanded_url': u'http://www.synthwave.de/impressum', u'display_url': u'synthwave.de/impressum'}] | 2 | 0.0% |
[{u'url': u'http://t.co/olzt8M25oa', u'indices': [43, 65], u'expanded_url': u'http://opensource.com', u'display_url': u'opensource.com'}] | 2 | 0.0% |
[{u'indices': [27, 50], u'url': u'https://t.co/JxvvUj0nHJ', u'expanded_url': u'http://www.creditsafe.com', u'display_url': u'creditsafe.com'}] | 1 | 0.0% |
[{u'indices': [43, 65], u'url': u'http://t.co/S3kDr8reJY', u'expanded_url': u'http://sonypictur.es/4VBchk', u'display_url': u'sonypictur.es/4VBchk'}, {u'indices': [79, 101], u'url': u'http://t.co/iUQ7YiCKPv', u'expanded_url': u'http://sonypictur.es/XZPhwR', u'display_url': u'sonypictur.es/XZPhwR'}] | 1 | 0.0% |
[{u'indices': [118, 141], u'url': u'https://t.co/f4gsbNc00C', u'expanded_url': u'http://rocketdatascience.org/', u'display_url': u'rocketdatascience.org'}] | 1 | 0.0% |
[{u'url': u'http://t.co/XP4czzYyQQ', u'indices': [120, 142], u'expanded_url': u'http://www.instant.ly/s/j3vqM', u'display_url': u'instant.ly/s/j3vqM'}] | 1 | 0.0% |
[{u'url': u'https://t.co/VeIliBW1Jd', u'indices': [77, 100], u'expanded_url': u'http://au.linkedin.com/in/tomdlee', u'display_url': u'au.linkedin.com/in/tomdlee'}] | 1 | 0.0% |
[{u'indices': [97, 119], u'url': u'http://t.co/16QGv879Ew', u'expanded_url': u'http://www.thesillywalk.com', u'display_url': u'thesillywalk.com'}] | 1 | 0.0% |
[{u'url': u'https://t.co/4j2O6aU8j1', u'indices': [70, 93], u'expanded_url': u'http://www.ufora.com', u'display_url': u'ufora.com'}] | 1 | 0.0% |
[{u'url': u'https://t.co/KyBOVaX2i1', u'indices': [117, 140], u'expanded_url': u'http://kck.st/1poiVFx', u'display_url': u'kck.st/1poiVFx'}] | 1 | 0.0% |
[{u'url': u'https://t.co/lojGiEmNH9', u'indices': [125, 148], u'expanded_url': u'http://www.dataelixir.com', u'display_url': u'dataelixir.com'}] | 1 | 0.0% |
[{u'url': u'http://t.co/mmcKkfCb7x', u'indices': [14, 36], u'expanded_url': u'http://www.buybea.com', u'display_url': u'buybea.com'}] | 1 | 0.0% |
[{u'url': u'http://t.co/Zx3lvZgNso', u'indices': [137, 159], u'expanded_url': u'http://www.bosch-si.com', u'display_url': u'bosch-si.com'}] | 1 | 0.0% |
[{u'url': u'https://t.co/HAjJQFN4qJ', u'indices': [0, 23], u'expanded_url': u'http://Learnetto.com', u'display_url': u'Learnetto.com'}] | 1 | 0.0% |
Other values (42) | 42 | 0.0% |
(Missing) | 97654 | 99.2% |

quoted_status_user_entities_url_urls
Categorical

Distinct count | 413
Unique (%) | 78.2%
Missing (%) | 99.5%
Missing (n) | 97865

[{u'url': u'https://t.co/kfeNXk1ZvC', u'indices': [0, 23], u'expanded_url': u'http://www.itservicestalk.com/', u'display_url': u'itservicestalk.com'}] | 7
[{u'url': u'http://t.co/jujQDNMiBP', u'indices': [0, 22], u'expanded_url': u'http://python.org/~guido/', u'display_url': u'python.org/~guido/'}] | 6
[{u'url': u'https://t.co/UBss2WoE0c', u'indices': [0, 23], u'expanded_url': u'http://developer.amazon.com/alexa', u'display_url': u'developer.amazon.com/alexa'}] | 6
Other values (409) | 509
(Missing) | 97865

Toggle details

Value | Count | Frequency (%) |
[{u'url': u'https://t.co/kfeNXk1ZvC', u'indices': [0, 23], u'expanded_url': u'http://www.itservicestalk.com/', u'display_url': u'itservicestalk.com'}] | 7 | 0.0% |
[{u'url': u'http://t.co/jujQDNMiBP', u'indices': [0, 22], u'expanded_url': u'http://python.org/~guido/', u'display_url': u'python.org/~guido/'}] | 6 | 0.0% |
[{u'url': u'https://t.co/UBss2WoE0c', u'indices': [0, 23], u'expanded_url': u'http://developer.amazon.com/alexa', u'display_url': u'developer.amazon.com/alexa'}] | 6 | 0.0% |
[{u'url': u'https://t.co/lhcCPP1ReQ', u'indices': [0, 23], u'expanded_url': u'http://dev.to', u'display_url': u'dev.to'}] | 6 | 0.0% |
[{u'url': u'http://t.co/Z4M89fs6mB', u'indices': [0, 22], u'expanded_url': u'http://www.ndtv.com/', u'display_url': u'ndtv.com'}] | 6 | 0.0% |
[{u'url': u'http://t.co/h5mIushJhB', u'indices': [0, 22], u'expanded_url': u'http://tomaugspurger.github.io', u'display_url': u'tomaugspurger.github.io'}] | 6 | 0.0% |
[{u'indices': [0, 23], u'url': u'https://t.co/YrHZxRzBPT', u'expanded_url': u'https://github.com/unicodeveloper', u'display_url': u'github.com/unicodeveloper'}] | 6 | 0.0% |
[{u'url': u'http://t.co/QqJhW1XwJF', u'indices': [0, 22], u'expanded_url': u'http://www.alobbs.com/', u'display_url': u'alobbs.com'}] | 5 | 0.0% |
[{u'url': u'https://t.co/tWlmeuTlR7', u'indices': [0, 23], u'expanded_url': u'http://www.linkedin.com/in/kirkdborne', u'display_url': u'linkedin.com/in/kirkdborne'}] | 5 | 0.0% |
[{u'url': u'http://t.co/XRCViJsjmi', u'indices': [0, 22], u'expanded_url': u'http://automatingosint.com/blog', u'display_url': u'automatingosint.com/blog'}] | 4 | 0.0% |
[{u'url': u'https://t.co/VvIeqSfR6L', u'indices': [0, 23], u'expanded_url': u'http://Drblasgidi.tumblr.com', u'display_url': u'Drblasgidi.tumblr.com'}] | 4 | 0.0% |
[{u'url': u'https://t.co/Jk2xlYsQJr', u'indices': [0, 23], u'expanded_url': u'http://nostarch.com/', u'display_url': u'nostarch.com'}] | 4 | 0.0% |
[{u'indices': [0, 23], u'url': u'https://t.co/tpzAYxx9cq', u'expanded_url': u'http://www.randalolson.com', u'display_url': u'randalolson.com'}] | 4 | 0.0% |
[{u'url': u'http://t.co/aWUY84onbG', u'indices': [0, 22], u'expanded_url': u'http://www.kdnuggets.com/', u'display_url': u'kdnuggets.com'}] | 4 | 0.0% |
[{u'indices': [0, 22], u'url': u'http://t.co/Sn7I2XUnjf', u'expanded_url': u'http://md.ekstrandom.net', u'display_url': u'md.ekstrandom.net'}] | 4 | 0.0% |
[{u'url': u'https://t.co/vtMHCfZpoO', u'indices': [0, 23], u'expanded_url': u'http://JohnDCook.com', u'display_url': u'JohnDCook.com'}] | 4 | 0.0% |
[{u'url': u'https://t.co/qJQDLJwSjr', u'indices': [0, 23], u'expanded_url': u'http://wesmckinney.com', u'display_url': u'wesmckinney.com'}] | 3 | 0.0% |
[{u'url': u'https://t.co/r5ifYKcnD3', u'indices': [0, 23], u'expanded_url': u'https://rhettinger.wordpress.com', u'display_url': u'rhettinger.wordpress.com'}] | 3 | 0.0% |
[{u'indices': [0, 22], u'url': u'http://t.co/XRCViJsjmi', u'expanded_url': u'http://automatingosint.com/blog', u'display_url': u'automatingosint.com/blog'}] | 3 | 0.0% |
[{u'url': u'https://t.co/LNOBuM5l6N', u'indices': [0, 23], u'expanded_url': u'http://youtube.com/falsesymmetry', u'display_url': u'youtube.com/falsesymmetry'}] | 3 | 0.0% |
Other values (392) | 435 | 0.4% |
(Missing) | 97865 | 99.5% |

quoted_status_user_favourites_count
Numeric

Distinct count | 513
Unique (%) | 68.0%
Missing (%) | 99.2%
Missing (n) | 97639

Mean | 8663.2
Minimum | 0
Maximum | 269480
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 0
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 269480
Range | 269480
Interquartile range |

Descriptive statistics

Standard deviation | 24786
Coef of variation | 2.861
Kurtosis | 34.35
Mean | 8663.2
MAD | 12416
Skewness | 5.1277
Sum | 6532100
Variance | 614340000
Memory size | 768.8 KiB

quoted_status_user_followers_count
Numeric

Distinct count | 594
Unique (%) | 78.8%
Missing (%) | 99.2%
Missing (n) | 97639

Mean | 234270
Minimum | 12
Maximum | 38507000
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 12
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 38507000
Range | 38507000
Interquartile range |

Descriptive statistics

Standard deviation | 1687800
Coef of variation | 7.2048
Kurtosis | 359.49
Mean | 234270
MAD | 400850
Skewness | 16.974
Sum | 176640000
Variance | 2.8488e+12
Memory size | 768.8 KiB

quoted_status_user_friends_count
Numeric

Distinct count | 499
Unique (%) | 66.2%
Missing (%) | 99.2%
Missing (n) | 97639

Mean | 3775.8
Minimum | 0
Maximum | 181260
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 0
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 181260
Range | 181260
Interquartile range |

Descriptive statistics

Standard deviation | 14529
Coef of variation | 3.8479
Kurtosis | 50.503
Mean | 3775.8
MAD | 5404.8
Skewness | 6.5349
Sum | 2847000
Variance | 211090000
Memory size | 768.8 KiB

quoted_status_user_geo_enabled
Categorical

Distinct count | 3
Unique (%) | 0.4%
Missing (%) | 99.2%
Missing (n) | 97639

False | 419
True | 335
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
False | 419 | 0.4% |
True | 335 | 0.3% |
(Missing) | 97639 | 99.2% |

quoted_status_user_has_extended_profile
Categorical

Distinct count | 3
Unique (%) | 0.4%
Missing (%) | 99.2%
Missing (n) | 97639

False | 626
True | 128
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
False | 626 | 0.6% |
True | 128 | 0.1% |
(Missing) | 97639 | 99.2% |

quoted_status_user_id
Numeric

Distinct count | 587
Unique (%) | 77.9%
Missing (%) | 99.2%
Missing (n) | 97639

Mean | 2.5451e+16
Minimum | 4816
Maximum | 7.2683e+17
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 4816
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 7.2683e+17
Range | 7.2683e+17
Interquartile range |

Descriptive statistics

Standard deviation | 1.3217e+17
Coef of variation | 5.1929
Kurtosis | 23.142
Mean | 2.5451e+16
MAD | 4.908e+16
Skewness | 5.0076
Sum | 1.919e+19
Variance | 1.7468e+34
Memory size | 768.8 KiB

quoted_status_user_id_str
Highly correlated

This variable is highly correlated with `quoted_status_user_id` and should be ignored for analysis

Correlation | 1

quoted_status_user_is_translation_enabled
Categorical

Distinct count | 3
Unique (%) | 0.4%
Missing (%) | 99.2%
Missing (n) | 97639

False | 727
True | 27
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
False | 727 | 0.7% |
True | 27 | 0.0% |
(Missing) | 97639 | 99.2% |

quoted_status_user_is_translator
Categorical

Distinct count | 2
Unique (%) | 0.3%
Missing (%) | 99.2%
Missing (n) | 97639

False | 754
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
False | 754 | 0.8% |
(Missing) | 97639 | 99.2% |

quoted_status_user_lang
Categorical

Distinct count | 14
Unique (%) | 1.9%
Missing (%) | 99.2%
Missing (n) | 97639

en | 706
es | 11
de | 10
Other values (10) | 27
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
en | 706 | 0.7% |
es | 11 | 0.0% |
de | 10 | 0.0% |
fr | 8 | 0.0% |
en-gb | 6 | 0.0% |
pt | 3 | 0.0% |
en-GB | 3 | 0.0% |
it | 2 | 0.0% |
pl | 1 | 0.0% |
nl | 1 | 0.0% |
uk | 1 | 0.0% |
sv | 1 | 0.0% |
ru | 1 | 0.0% |
(Missing) | 97639 | 99.2% |

quoted_status_user_listed_count
Highly correlated

This variable is highly correlated with `quoted_status_user_followers_count` and should be ignored for analysis

Correlation | 0.91088

quoted_status_user_location
Categorical

Distinct count | 343
Unique (%) | 59.1%
Missing (%) | 99.4%
Missing (n) | 97813

Seattle, WA | 23
slytherin | 20
San Francisco, CA | 16
Other values (339) | 521
(Missing) | 97813

Toggle details

Value | Count | Frequency (%) |
Seattle, WA | 23 | 0.0% |
slytherin | 20 | 0.0% |
San Francisco, CA | 16 | 0.0% |
London | 14 | 0.0% |
New York, NY | 11 | 0.0% |
UK | 8 | 0.0% |
Saskatoon, Saskatchewan | 7 | 0.0% |
San Francisco Bay Area | 7 | 0.0% |
Philadelphia, PA | 7 | 0.0% |
Des Moines, IA | 7 | 0.0% |
Portland, OR | 6 | 0.0% |
India | 6 | 0.0% |
Lagos, Nigeria | 6 | 0.0% |
Booz Allen Hamilton | 6 | 0.0% |
United Kingdom | 5 | 0.0% |
Madrid, Spain | 5 | 0.0% |
Houston | 5 | 0.0% |
London, England | 5 | 0.0% |
Los Angeles, CA | 5 | 0.0% |
Berlin | 4 | 0.0% |
Other values (322) | 407 | 0.4% |
(Missing) | 97813 | 99.4% |

quoted_status_user_name
Categorical

Distinct count | 558
Unique (%) | 77.0%
Missing (%) | 99.3%
Missing (n) | 97668

moana lisa | 20
Big Data Science | 8
IT Services talk | 7
Other values (554) | 690
(Missing) | 97668

Toggle details

Value | Count | Frequency (%) |
moana lisa | 20 | 0.0% |
Big Data Science | 8 | 0.0% |
IT Services talk | 7 | 0.0% |
Randy Olson | 7 | 0.0% |
Alexa Developers | 7 | 0.0% |
Tom Augspurger | 7 | 0.0% |
Justin Seitz | 7 | 0.0% |
Kirk Borne | 6 | 0.0% |
NDTV | 6 | 0.0% |
Guido van Rossum | 6 | 0.0% |
Practical Developer | 6 | 0.0% |
Prosper Otemuyiwa | 6 | 0.0% |
Alvaro Lopez Ortega | 5 | 0.0% |
Scientific Python | 5 | 0.0% |
Wes McKinney | 4 | 0.0% |
Michael Ekstrand | 4 | 0.0% |
Learn Something | 4 | 0.0% |
Bill Pollock | 4 | 0.0% |
Gregory Piatetsky | 4 | 0.0% |
FreshPrinceOfLasGidi | 4 | 0.0% |
Other values (537) | 598 | 0.6% |
(Missing) | 97668 | 99.3% |

quoted_status_user_profile_background_color
Categorical

Distinct count | 119
Unique (%) | 15.8%
Missing (%) | 99.2%
Missing (n) | 97639

C0DEED | 235
000000 | 151
131516 | 65
Other values (115) | 303
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
C0DEED | 235 | 0.2% |
000000 | 151 | 0.2% |
131516 | 65 | 0.1% |
FFFFFF | 36 | 0.0% |
F5F8FA | 29 | 0.0% |
1A1B1F | 29 | 0.0% |
9AE4E8 | 17 | 0.0% |
0099B9 | 14 | 0.0% |
022330 | 13 | 0.0% |
352726 | 11 | 0.0% |
709397 | 8 | 0.0% |
EDECE9 | 7 | 0.0% |
BADFCD | 6 | 0.0% |
642D8B | 6 | 0.0% |
8B542B | 4 | 0.0% |
ABB8C2 | 4 | 0.0% |
C6E2EE | 4 | 0.0% |
FF6699 | 3 | 0.0% |
F2F2F2 | 3 | 0.0% |
ACDED6 | 3 | 0.0% |
Other values (98) | 106 | 0.1% |
(Missing) | 97639 | 99.2% |

quoted_status_user_profile_background_image_url
Categorical

Distinct count | 252
Unique (%) | 34.7%
Missing (%) | 99.3%
Missing (n) | 97666

http://abs.twimg.com/images/themes/theme1/bg.png | 304
http://abs.twimg.com/images/themes/theme14/bg.gif | 51
http://abs.twimg.com/images/themes/theme9/bg.gif | 16
Other values (248) | 356
(Missing) | 97666

Toggle details

Value | Count | Frequency (%) |
http://abs.twimg.com/images/themes/theme1/bg.png | 304 | 0.3% |
http://abs.twimg.com/images/themes/theme14/bg.gif | 51 | 0.1% |
http://abs.twimg.com/images/themes/theme9/bg.gif | 16 | 0.0% |
http://abs.twimg.com/images/themes/theme15/bg.png | 11 | 0.0% |
http://abs.twimg.com/images/themes/theme4/bg.gif | 10 | 0.0% |
http://pbs.twimg.com/profile_background_images/33516583/water10x.gif | 8 | 0.0% |
http://abs.twimg.com/images/themes/theme6/bg.gif | 8 | 0.0% |
http://pbs.twimg.com/profile_background_images/457629516702035968/lKWBWYYG.jpeg | 7 | 0.0% |
http://pbs.twimg.com/profile_background_images/601385812760993793/2pxLSwZZ.jpg | 6 | 0.0% |
http://pbs.twimg.com/profile_background_images/632438131657084928/plbkTCb0.png | 6 | 0.0% |
http://pbs.twimg.com/profile_background_images/378800000110442114/094a0b4d38b70e3871a1bda7d7fe2341.jpeg | 6 | 0.0% |
http://abs.twimg.com/images/themes/theme16/bg.gif | 5 | 0.0% |
http://abs.twimg.com/images/themes/theme10/bg.gif | 5 | 0.0% |
http://abs.twimg.com/images/themes/theme18/bg.gif | 5 | 0.0% |
http://abs.twimg.com/images/themes/theme19/bg.gif | 4 | 0.0% |
http://pbs.twimg.com/profile_background_images/378800000050609482/c32d3d654da4eb7c0518e7bba2609522.jpeg | 4 | 0.0% |
http://pbs.twimg.com/profile_background_images/408567408/tumblr_lbqemyjIh71qc2pt6.jpg | 4 | 0.0% |
http://abs.twimg.com/images/themes/theme5/bg.gif | 4 | 0.0% |
http://abs.twimg.com/images/themes/theme17/bg.gif | 3 | 0.0% |
http://pbs.twimg.com/profile_background_images/495761070208712704/haezvpDK.jpeg | 3 | 0.0% |
Other values (231) | 257 | 0.3% |
(Missing) | 97666 | 99.3% |

quoted_status_user_profile_background_image_url_https
Categorical

Distinct count | 252
Unique (%) | 34.7%
Missing (%) | 99.3%
Missing (n) | 97666

https://abs.twimg.com/images/themes/theme1/bg.png | 304
https://abs.twimg.com/images/themes/theme14/bg.gif | 51
https://abs.twimg.com/images/themes/theme9/bg.gif | 16
Other values (248) | 356
(Missing) | 97666

Toggle details

Value | Count | Frequency (%) |
https://abs.twimg.com/images/themes/theme1/bg.png | 304 | 0.3% |
https://abs.twimg.com/images/themes/theme14/bg.gif | 51 | 0.1% |
https://abs.twimg.com/images/themes/theme9/bg.gif | 16 | 0.0% |
https://abs.twimg.com/images/themes/theme15/bg.png | 11 | 0.0% |
https://abs.twimg.com/images/themes/theme4/bg.gif | 10 | 0.0% |
https://pbs.twimg.com/profile_background_images/33516583/water10x.gif | 8 | 0.0% |
https://abs.twimg.com/images/themes/theme6/bg.gif | 8 | 0.0% |
https://pbs.twimg.com/profile_background_images/457629516702035968/lKWBWYYG.jpeg | 7 | 0.0% |
https://pbs.twimg.com/profile_background_images/378800000110442114/094a0b4d38b70e3871a1bda7d7fe2341.jpeg | 6 | 0.0% |
https://pbs.twimg.com/profile_background_images/601385812760993793/2pxLSwZZ.jpg | 6 | 0.0% |
https://pbs.twimg.com/profile_background_images/632438131657084928/plbkTCb0.png | 6 | 0.0% |
https://abs.twimg.com/images/themes/theme16/bg.gif | 5 | 0.0% |
https://abs.twimg.com/images/themes/theme10/bg.gif | 5 | 0.0% |
https://abs.twimg.com/images/themes/theme18/bg.gif | 5 | 0.0% |
https://pbs.twimg.com/profile_background_images/378800000050609482/c32d3d654da4eb7c0518e7bba2609522.jpeg | 4 | 0.0% |
https://abs.twimg.com/images/themes/theme19/bg.gif | 4 | 0.0% |
https://pbs.twimg.com/profile_background_images/408567408/tumblr_lbqemyjIh71qc2pt6.jpg | 4 | 0.0% |
https://abs.twimg.com/images/themes/theme5/bg.gif | 4 | 0.0% |
https://abs.twimg.com/images/themes/theme3/bg.gif | 3 | 0.0% |
https://abs.twimg.com/images/themes/theme2/bg.gif | 3 | 0.0% |
Other values (231) | 257 | 0.3% |
(Missing) | 97666 | 99.3% |

quoted_status_user_profile_background_tile
Categorical

Distinct count | 3
Unique (%) | 0.4%
Missing (%) | 99.2%
Missing (n) | 97639

False | 547
True | 207
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
False | 547 | 0.6% |
True | 207 | 0.2% |
(Missing) | 97639 | 99.2% |

quoted_status_user_profile_banner_url
Categorical

Distinct count | 483
Unique (%) | 77.7%
Missing (%) | 99.4%
Missing (n) | 97771

https://pbs.twimg.com/profile_banners/3148778196/1462202808 | 20
https://pbs.twimg.com/profile_banners/14174897/1401028953 | 8
https://pbs.twimg.com/profile_banners/817668451/1414765536 | 7
Other values (479) | 587
(Missing) | 97771

Toggle details

Value | Count | Frequency (%) |
https://pbs.twimg.com/profile_banners/3148778196/1462202808 | 20 | 0.0% |
https://pbs.twimg.com/profile_banners/14174897/1401028953 | 8 | 0.0% |
https://pbs.twimg.com/profile_banners/817668451/1414765536 | 7 | 0.0% |
https://pbs.twimg.com/profile_banners/24083751/1433991225 | 7 | 0.0% |
https://pbs.twimg.com/profile_banners/3281317123/1458886264 | 7 | 0.0% |
https://pbs.twimg.com/profile_banners/702932794947694592/1457126887 | 7 | 0.0% |
https://pbs.twimg.com/profile_banners/49413866/1439914461 | 7 | 0.0% |
https://pbs.twimg.com/profile_banners/178849006/1458109168 | 6 | 0.0% |
https://pbs.twimg.com/profile_banners/37034483/1461332995 | 6 | 0.0% |
https://pbs.twimg.com/profile_banners/15804774/1400086274 | 6 | 0.0% |
https://pbs.twimg.com/profile_banners/2735246778/1458157262 | 6 | 0.0% |
https://pbs.twimg.com/profile_banners/534563976/1450104430 | 6 | 0.0% |
https://pbs.twimg.com/profile_banners/784165/1401132904 | 5 | 0.0% |
https://pbs.twimg.com/profile_banners/254791849/1458355479 | 5 | 0.0% |
https://pbs.twimg.com/profile_banners/91035113/1450193006 | 4 | 0.0% |
https://pbs.twimg.com/profile_banners/2655830472/1461341507 | 4 | 0.0% |
https://pbs.twimg.com/profile_banners/20926161/1398526085 | 4 | 0.0% |
https://pbs.twimg.com/profile_banners/20167623/1367620090 | 4 | 0.0% |
https://pbs.twimg.com/profile_banners/8358082/1460691946 | 3 | 0.0% |
https://pbs.twimg.com/profile_banners/50478950/1455266718 | 3 | 0.0% |
Other values (462) | 497 | 0.5% |
(Missing) | 97771 | 99.4% |

quoted_status_user_profile_image_url
Categorical

Distinct count | 587
Unique (%) | 77.9%
Missing (%) | 99.2%
Missing (n) | 97639

http://pbs.twimg.com/profile_images/726421042223177728/XcNr9rza_normal.jpg | 20
http://pbs.twimg.com/profile_images/1198161733/analitycbridge_normal.png | 8
http://pbs.twimg.com/profile_images/378800000074463006/88c66064eedf00848c22485cf9465e96_normal.jpeg | 7
Other values (583) | 719
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
http://pbs.twimg.com/profile_images/726421042223177728/XcNr9rza_normal.jpg | 20 | 0.0% |
http://pbs.twimg.com/profile_images/1198161733/analitycbridge_normal.png | 8 | 0.0% |
http://pbs.twimg.com/profile_images/378800000074463006/88c66064eedf00848c22485cf9465e96_normal.jpeg | 7 | 0.0% |
http://pbs.twimg.com/profile_images/621549782759112704/SU7K19H__normal.png | 7 | 0.0% |
http://pbs.twimg.com/profile_images/705107002431660032/xk0QHcLw_normal.jpg | 7 | 0.0% |
http://pbs.twimg.com/profile_images/592336066167767040/NjGKEtLR_normal.png | 7 | 0.0% |
http://pbs.twimg.com/profile_images/618964235779862528/nLQhBWfq_normal.jpg | 7 | 0.0% |
http://pbs.twimg.com/profile_images/720903526088589312/HYFkTf4Q_normal.jpg | 6 | 0.0% |
http://pbs.twimg.com/profile_images/570440108424171520/QuGYd7jH_normal.png | 6 | 0.0% |
http://pbs.twimg.com/profile_images/680246148762828801/flXTNSKT_normal.jpg | 6 | 0.0% |
http://pbs.twimg.com/profile_images/424495004/GuidoAvatar_normal.jpg | 6 | 0.0% |
http://pbs.twimg.com/profile_images/715680713073418240/36RwCsKt_normal.jpg | 6 | 0.0% |
http://pbs.twimg.com/profile_images/459258467258101760/CwfDmVyy_normal.png | 5 | 0.0% |
http://pbs.twimg.com/profile_images/710923156655984640/8Z95ugd__normal.jpg | 5 | 0.0% |
http://pbs.twimg.com/profile_images/2994096439/5113c1ba8e33ca2d6dd0da6d6d265d44_normal.jpeg | 4 | 0.0% |
http://pbs.twimg.com/profile_images/425528953302831104/k1qS0M6N_normal.png | 4 | 0.0% |
http://pbs.twimg.com/profile_images/519558322010062850/d5hcqWGt_normal.jpeg | 4 | 0.0% |
http://pbs.twimg.com/profile_images/725452455564218372/exJ9ziAR_normal.jpg | 4 | 0.0% |
http://pbs.twimg.com/profile_images/723543157896523783/xEpshVEN_normal.jpg | 4 | 0.0% |
http://pbs.twimg.com/profile_images/655452837757882368/ioLet7Dm_normal.jpg | 4 | 0.0% |
Other values (566) | 627 | 0.6% |
(Missing) | 97639 | 99.2% |

quoted_status_user_profile_image_url_https
Categorical

Distinct count | 587
Unique (%) | 77.9%
Missing (%) | 99.2%
Missing (n) | 97639

https://pbs.twimg.com/profile_images/726421042223177728/XcNr9rza_normal.jpg | 20
https://pbs.twimg.com/profile_images/1198161733/analitycbridge_normal.png | 8
https://pbs.twimg.com/profile_images/618964235779862528/nLQhBWfq_normal.jpg | 7
Other values (583) | 719
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
https://pbs.twimg.com/profile_images/726421042223177728/XcNr9rza_normal.jpg | 20 | 0.0% |
https://pbs.twimg.com/profile_images/1198161733/analitycbridge_normal.png | 8 | 0.0% |
https://pbs.twimg.com/profile_images/618964235779862528/nLQhBWfq_normal.jpg | 7 | 0.0% |
https://pbs.twimg.com/profile_images/621549782759112704/SU7K19H__normal.png | 7 | 0.0% |
https://pbs.twimg.com/profile_images/705107002431660032/xk0QHcLw_normal.jpg | 7 | 0.0% |
https://pbs.twimg.com/profile_images/378800000074463006/88c66064eedf00848c22485cf9465e96_normal.jpeg | 7 | 0.0% |
https://pbs.twimg.com/profile_images/592336066167767040/NjGKEtLR_normal.png | 7 | 0.0% |
https://pbs.twimg.com/profile_images/570440108424171520/QuGYd7jH_normal.png | 6 | 0.0% |
https://pbs.twimg.com/profile_images/720903526088589312/HYFkTf4Q_normal.jpg | 6 | 0.0% |
https://pbs.twimg.com/profile_images/424495004/GuidoAvatar_normal.jpg | 6 | 0.0% |
https://pbs.twimg.com/profile_images/680246148762828801/flXTNSKT_normal.jpg | 6 | 0.0% |
https://pbs.twimg.com/profile_images/715680713073418240/36RwCsKt_normal.jpg | 6 | 0.0% |
https://pbs.twimg.com/profile_images/710923156655984640/8Z95ugd__normal.jpg | 5 | 0.0% |
https://pbs.twimg.com/profile_images/459258467258101760/CwfDmVyy_normal.png | 5 | 0.0% |
https://pbs.twimg.com/profile_images/725452455564218372/exJ9ziAR_normal.jpg | 4 | 0.0% |
https://pbs.twimg.com/profile_images/723543157896523783/xEpshVEN_normal.jpg | 4 | 0.0% |
https://pbs.twimg.com/profile_images/2994096439/5113c1ba8e33ca2d6dd0da6d6d265d44_normal.jpeg | 4 | 0.0% |
https://pbs.twimg.com/profile_images/655452837757882368/ioLet7Dm_normal.jpg | 4 | 0.0% |
https://pbs.twimg.com/profile_images/519558322010062850/d5hcqWGt_normal.jpeg | 4 | 0.0% |
https://pbs.twimg.com/profile_images/425528953302831104/k1qS0M6N_normal.png | 4 | 0.0% |
Other values (566) | 627 | 0.6% |
(Missing) | 97639 | 99.2% |

quoted_status_user_profile_link_color
Categorical

Distinct count | 196
Unique (%) | 26.0%
Missing (%) | 99.2%
Missing (n) | 97639

0084B4 | 250
3B94D9 | 45
9266CC | 33
Other values (192) | 426
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
0084B4 | 250 | 0.3% |
3B94D9 | 45 | 0.0% |
9266CC | 33 | 0.0% |
009999 | 28 | 0.0% |
2B7BB9 | 27 | 0.0% |
2FC2EF | 18 | 0.0% |
000000 | 16 | 0.0% |
0099B9 | 13 | 0.0% |
1B95E0 | 13 | 0.0% |
DD2E44 | 13 | 0.0% |
ABB8C2 | 11 | 0.0% |
4A913C | 11 | 0.0% |
080808 | 8 | 0.0% |
0000FF | 7 | 0.0% |
89C9FA | 7 | 0.0% |
FF0000 | 7 | 0.0% |
FF3300 | 6 | 0.0% |
004899 | 6 | 0.0% |
14BD7B | 6 | 0.0% |
94D487 | 6 | 0.0% |
Other values (175) | 223 | 0.2% |
(Missing) | 97639 | 99.2% |

quoted_status_user_profile_sidebar_border_color
Categorical

Distinct count | 45
Unique (%) | 6.0%
Missing (%) | 99.2%
Missing (n) | 97639

C0DEED | 227
000000 | 197
FFFFFF | 159
Other values (41) | 171
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
C0DEED | 227 | 0.2% |
000000 | 197 | 0.2% |
FFFFFF | 159 | 0.2% |
EEEEEE | 44 | 0.0% |
181A1E | 16 | 0.0% |
BDDCAD | 13 | 0.0% |
A8C7F7 | 13 | 0.0% |
829D5E | 11 | 0.0% |
5ED4DC | 11 | 0.0% |
87BC44 | 10 | 0.0% |
86A4A6 | 7 | 0.0% |
D9B17E | 5 | 0.0% |
D3D2CF | 4 | 0.0% |
DDDDDD | 3 | 0.0% |
65B0DA | 3 | 0.0% |
FDFFC4 | 2 | 0.0% |
F2E195 | 2 | 0.0% |
FFA200 | 1 | 0.0% |
0B6900 | 1 | 0.0% |
DADADA | 1 | 0.0% |
Other values (24) | 24 | 0.0% |
(Missing) | 97639 | 99.2% |

quoted_status_user_profile_sidebar_fill_color
Categorical

Distinct count | 85
Unique (%) | 11.3%
Missing (%) | 99.2%
Missing (n) | 97639

DDEEF6 | 314
000000 | 149
EFEFEF | 60
Other values (81) | 231
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
DDEEF6 | 314 | 0.3% |
000000 | 149 | 0.2% |
EFEFEF | 60 | 0.1% |
252429 | 33 | 0.0% |
DDFFCC | 17 | 0.0% |
C0DFEC | 14 | 0.0% |
95E8EC | 13 | 0.0% |
E0FF92 | 13 | 0.0% |
FFFFFF | 10 | 0.0% |
A0C5C7 | 9 | 0.0% |
CAD9D8 | 8 | 0.0% |
7AC3EE | 8 | 0.0% |
E3E2DE | 6 | 0.0% |
EADEAA | 6 | 0.0% |
FFF7CC | 5 | 0.0% |
F6F6F6 | 5 | 0.0% |
99CC33 | 4 | 0.0% |
EEEEEE | 3 | 0.0% |
E5507E | 3 | 0.0% |
C2FF66 | 2 | 0.0% |
Other values (64) | 72 | 0.1% |
(Missing) | 97639 | 99.2% |

quoted_status_user_profile_text_color
Categorical

Distinct count | 52
Unique (%) | 6.9%
Missing (%) | 99.2%
Missing (n) | 97639

333333 | 435
000000 | 187
666666 | 35
Other values (48) | 97
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
333333 | 435 | 0.4% |
000000 | 187 | 0.2% |
666666 | 35 | 0.0% |
3C3940 | 15 | 0.0% |
3E4415 | 12 | 0.0% |
3D1957 | 7 | 0.0% |
0C3E53 | 5 | 0.0% |
634047 | 4 | 0.0% |
474747 | 4 | 0.0% |
444444 | 3 | 0.0% |
362720 | 3 | 0.0% |
977C61 | 2 | 0.0% |
0ACC82 | 2 | 0.0% |
663B12 | 2 | 0.0% |
58514B | 2 | 0.0% |
EBE4EB | 1 | 0.0% |
615F61 | 1 | 0.0% |
000408 | 1 | 0.0% |
1F1F1F | 1 | 0.0% |
BDBDBD | 1 | 0.0% |
Other values (31) | 31 | 0.0% |
(Missing) | 97639 | 99.2% |

quoted_status_user_profile_use_background_image
Categorical

Distinct count | 3
Unique (%) | 0.4%
Missing (%) | 99.2%
Missing (n) | 97639

True | 560
False | 194
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
True | 560 | 0.6% |
False | 194 | 0.2% |
(Missing) | 97639 | 99.2% |

quoted_status_user_protected
Categorical

Distinct count | 2
Unique (%) | 0.3%
Missing (%) | 99.2%
Missing (n) | 97639

False | 754
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
False | 754 | 0.8% |
(Missing) | 97639 | 99.2% |

quoted_status_user_screen_name
Categorical

Distinct count | 587
Unique (%) | 77.9%
Missing (%) | 99.2%
Missing (n) | 97639

hoeroins | 20
analyticbridge | 8
alexadevs | 7
Other values (583) | 719
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
hoeroins | 20 | 0.0% |
analyticbridge | 8 | 0.0% |
alexadevs | 7 | 0.0% |
IT_ServicesTalk | 7 | 0.0% |
jms_dot_py | 7 | 0.0% |
TomAugspurger | 7 | 0.0% |
randal_olson | 7 | 0.0% |
ndtv | 6 | 0.0% |
unicodeveloper | 6 | 0.0% |
gvanrossum | 6 | 0.0% |
KirkDBorne | 6 | 0.0% |
ThePracticalDev | 6 | 0.0% |
SciPyTip | 5 | 0.0% |
alobbs | 5 | 0.0% |
mdekstrand | 4 | 0.0% |
smhayg | 4 | 0.0% |
wesmckinn | 4 | 0.0% |
kdnuggets | 4 | 0.0% |
TeezeeDRB | 4 | 0.0% |
CoolestLifeHack | 4 | 0.0% |
Other values (566) | 627 | 0.6% |
(Missing) | 97639 | 99.2% |

quoted_status_user_statuses_count
Numeric

Distinct count | 602
Unique (%) | 79.8%
Missing (%) | 99.2%
Missing (n) | 97639

Mean | 25135
Minimum | 4
Maximum | 354750
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 4
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 354750
Range | 354740
Interquartile range |

Descriptive statistics

Standard deviation | 49857
Coef of variation | 1.9836
Kurtosis | 16.351
Mean | 25135
MAD | 29673
Skewness | 3.7092
Sum | 18952000
Variance | 2485800000
Memory size | 768.8 KiB

quoted_status_user_time_zone
Categorical

Distinct count | 61
Unique (%) | 9.8%
Missing (%) | 99.4%
Missing (n) | 97770

Pacific Time (US & Canada) | 167
Eastern Time (US & Canada) | 125
London | 62
Other values (57) | 269
(Missing) | 97770

Toggle details

Value | Count | Frequency (%) |
Pacific Time (US & Canada) | 167 | 0.2% |
Eastern Time (US & Canada) | 125 | 0.1% |
London | 62 | 0.1% |
Central Time (US & Canada) | 35 | 0.0% |
Darwin | 23 | 0.0% |
Amsterdam | 20 | 0.0% |
New Delhi | 19 | 0.0% |
Mountain Time (US & Canada) | 17 | 0.0% |
Madrid | 13 | 0.0% |
Hawaii | 10 | 0.0% |
Atlantic Time (Canada) | 9 | 0.0% |
Arizona | 8 | 0.0% |
Berlin | 7 | 0.0% |
Sydney | 7 | 0.0% |
Quito | 6 | 0.0% |
Paris | 5 | 0.0% |
Alaska | 5 | 0.0% |
Athens | 5 | 0.0% |
Brasilia | 4 | 0.0% |
Jerusalem | 4 | 0.0% |
Other values (40) | 72 | 0.1% |
(Missing) | 97770 | 99.4% |

quoted_status_user_url
Categorical

Distinct count | 433
Unique (%) | 75.4%
Missing (%) | 99.4%
Missing (n) | 97819

http://t.co/43tj0Ez1jT | 8
http://t.co/h5mIushJhB | 7
https://t.co/kfeNXk1ZvC | 7
Other values (429) | 552
(Missing) | 97819

Toggle details

Value | Count | Frequency (%) |
http://t.co/43tj0Ez1jT | 8 | 0.0% |
http://t.co/h5mIushJhB | 7 | 0.0% |
https://t.co/kfeNXk1ZvC | 7 | 0.0% |
https://t.co/tpzAYxx9cq | 7 | 0.0% |
http://t.co/XRCViJsjmi | 7 | 0.0% |
https://t.co/UBss2WoE0c | 7 | 0.0% |
http://t.co/jujQDNMiBP | 6 | 0.0% |
http://t.co/Z4M89fs6mB | 6 | 0.0% |
https://t.co/tWlmeuTlR7 | 6 | 0.0% |
https://t.co/YrHZxRzBPT | 6 | 0.0% |
https://t.co/lhcCPP1ReQ | 6 | 0.0% |
https://t.co/vtMHCfZpoO | 5 | 0.0% |
http://t.co/QqJhW1XwJF | 5 | 0.0% |
http://t.co/aWUY84onbG | 4 | 0.0% |
http://t.co/Sn7I2XUnjf | 4 | 0.0% |
https://t.co/Jk2xlYsQJr | 4 | 0.0% |
https://t.co/VvIeqSfR6L | 4 | 0.0% |
http://t.co/nPiNwcE5ry | 4 | 0.0% |
https://t.co/qJQDLJwSjr | 4 | 0.0% |
https://t.co/Q7wF918Ot4 | 3 | 0.0% |
Other values (412) | 464 | 0.5% |
(Missing) | 97819 | 99.4% |

quoted_status_user_utc_offset
Numeric

Distinct count | 22
Unique (%) | 3.5%
Missing (%) | 99.4%
Missing (n) | 97770

Mean | -8774.6
Minimum | -39600
Maximum | 43200
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | -39600
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 43200
Range | 82800
Interquartile range |

Descriptive statistics

Standard deviation | 17871
Coef of variation | -2.0367
Kurtosis | -0.041128
Mean | -8774.6
MAD | 15168
Skewness | 0.8906
Sum | -5466600
Variance | 319390000
Memory size | 768.8 KiB

quoted_status_user_verified
Categorical

Distinct count | 3
Unique (%) | 0.4%
Missing (%) | 99.2%
Missing (n) | 97639

False | 661
True | 93
(Missing) | 97639

Toggle details

Value | Count | Frequency (%) |
False | 661 | 0.7% |
True | 93 | 0.1% |
(Missing) | 97639 | 99.2% |

retweet_count
Numeric

Distinct count | 470
Unique (%) | 0.5%
Missing (%) | 0.0%
Missing (n) | 0

Mean | 56.845
Minimum | 0
Maximum | 166650
Zeros (%) | 49.4%

Toggle details

Quantile statistics

Minimum | 0
5-th percentile | 0
Q1 | 0
Median | 1
Q3 | 4
95-th percentile | 104
Maximum | 166650
Range | 166650
Interquartile range | 4

Descriptive statistics

Standard deviation | 965.51
Coef of variation | 16.985
Kurtosis | 14119
Mean | 56.845
MAD | 98.937
Skewness | 101.75
Sum | 5593100
Variance | 932210
Memory size | 768.8 KiB

retweeted
Constant

This variable is constant and should be ignored for analysis

Constant value | False

retweeted_status_created_at
Categorical

Distinct count | 11461
Unique (%) | 33.2%
Missing (%) | 64.9%
Missing (n) | 63829

Tue Apr 26 00:43:42 +0000 2016 | 944
Tue Apr 26 00:46:25 +0000 2016 | 865
Fri Apr 22 16:05:16 +0000 2016 | 308
Other values (11457) | 32447
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
Tue Apr 26 00:43:42 +0000 2016 | 944 | 1.0% |
Tue Apr 26 00:46:25 +0000 2016 | 865 | 0.9% |
Fri Apr 22 16:05:16 +0000 2016 | 308 | 0.3% |
Sat Apr 16 13:10:09 +0000 2016 | 290 | 0.3% |
Sat Apr 30 22:50:40 +0000 2016 | 263 | 0.3% |
Fri Apr 15 02:11:02 +0000 2016 | 220 | 0.2% |
Fri Apr 22 18:50:23 +0000 2016 | 171 | 0.2% |
Sun Apr 24 18:24:09 +0000 2016 | 150 | 0.2% |
Mon May 02 22:16:57 +0000 2016 | 145 | 0.1% |
Tue Apr 26 15:45:27 +0000 2016 | 139 | 0.1% |
Sun Apr 17 22:00:47 +0000 2016 | 133 | 0.1% |
Thu Apr 28 13:23:51 +0000 2016 | 125 | 0.1% |
Sat Apr 30 02:01:04 +0000 2016 | 116 | 0.1% |
Mon Apr 18 04:50:29 +0000 2016 | 111 | 0.1% |
Sat Apr 23 15:42:06 +0000 2016 | 105 | 0.1% |
Mon Apr 25 14:25:34 +0000 2016 | 97 | 0.1% |
Tue Apr 19 14:39:05 +0000 2016 | 96 | 0.1% |
Sun May 01 05:30:02 +0000 2016 | 95 | 0.1% |
Sat Apr 23 21:50:15 +0000 2016 | 93 | 0.1% |
Sun May 01 17:08:16 +0000 2016 | 92 | 0.1% |
Other values (11440) | 30006 | 30.5% |
(Missing) | 63829 | 64.9% |

retweeted_status_entities_hashtags
Categorical

Distinct count | 4833
Unique (%) | 14.0%
Missing (%) | 64.9%
Missing (n) | 63876

[] | 15190
[{u'indices': [0, 7], u'text': u'python'}] | 364
[{u'indices': [89, 103], u'text': u'CallOfTheWild'}, {u'indices': [104, 116], u'text': u'SaveTheWild'}] | 308
Other values (4829) | 18655
(Missing) | 63876

Toggle details

Value | Count | Frequency (%) |
[] | 15190 | 15.4% |
[{u'indices': [0, 7], u'text': u'python'}] | 364 | 0.4% |
[{u'indices': [89, 103], u'text': u'CallOfTheWild'}, {u'indices': [104, 116], u'text': u'SaveTheWild'}] | 308 | 0.3% |
[{u'indices': [0, 7], u'text': u'Google'}, {u'indices': [26, 33], u'text': u'Python'}, {u'indices': [34, 50], u'text': u'MachineLearning'}, {u'indices': [70, 78], u'text': u'sklearn'}] | 290 | 0.3% |
[{u'indices': [5, 9], u'text': u'TWD'}, {u'indices': [99, 114], u'text': u'TheWalkingDead'}] | 263 | 0.3% |
[{u'indices': [31, 38], u'text': u'Python'}] | 177 | 0.2% |
[{u'indices': [4, 20], u'text': u'MachineLearning'}, {u'indices': [26, 33], u'text': u'Python'}, {u'indices': [83, 89], u'text': u'abdsc'}, {u'indices': [90, 98], u'text': u'BigData'}, {u'indices': [99, 111], u'text': u'DataScience'}] | 148 | 0.2% |
[{u'indices': [40, 47], u'text': u'DevOps'}, {u'indices': [48, 52], u'text': u'IoT'}, {u'indices': [53, 67], u'text': u'Microservices'}, {u'indices': [92, 98], u'text': u'Cloud'}] | 145 | 0.1% |
[{u'indices': [0, 7], u'text': u'Python'}] | 120 | 0.1% |
[{u'indices': [0, 7], u'text': u'Python'}, {u'indices': [31, 43], u'text': u'programming'}] | 100 | 0.1% |
[{u'indices': [11, 18], u'text': u'Python'}, {u'indices': [33, 45], u'text': u'programming'}] | 99 | 0.1% |
[{u'indices': [80, 86], u'text': u'Opera'}, {u'indices': [87, 91], u'text': u'VPN'}] | 97 | 0.1% |
[{u'indices': [8, 22], u'text': u'coloroftheday'}, {u'indices': [41, 55], u'text': u'TravelTuesday'}] | 96 | 0.1% |
[{u'indices': [47, 63], u'text': u'Electricity4All'}] | 95 | 0.1% |
[{u'indices': [33, 45], u'text': u'DataScience'}] | 94 | 0.1% |
[{u'indices': [22, 29], u'text': u'Python'}, {u'indices': [30, 41], u'text': u'Psychology'}] | 92 | 0.1% |
[{u'indices': [85, 101], u'text': u'MachineLearning'}, {u'indices': [102, 114], u'text': u'DataScience'}] | 90 | 0.1% |
[{u'indices': [97, 100], u'text': u'ai'}] | 87 | 0.1% |
[{u'indices': [7, 19], u'text': u'programming'}, {u'indices': [44, 51], u'text': u'Python'}] | 84 | 0.1% |
[{u'indices': [0, 7], u'text': u'python'}, {u'indices': [72, 75], u'text': u'IT'}, {u'indices': [76, 87], u'text': u'Developers'}] | 82 | 0.1% |
Other values (4812) | 16496 | 16.8% |
(Missing) | 63876 | 64.9% |

retweeted_status_entities_media
Categorical

Distinct count | 3617
Unique (%) | 27.2%
Missing (%) | 86.5%
Missing (n) | 85101

[{u'expanded_url': u'http://twitter.com/Delilah_Alvares/status/723543199315300352/photo/1', u'display_url': u'pic.twitter.com/uMhFFIHrbo', u'url': u'https://t.co/uMhFFIHrbo', u'media_url_https': u'https://pbs.twimg.com/media/CgqKrq8XEAI0ZPo.jpg', u'id_str': u'723543173012852738', u'sizes': {u'small': {u'h': 512, u'resize': u'fit', u'w': 340}, u'large': {u'h': 960, u'resize': u'fit', u'w': 638}, u'medium': {u'h': 903, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'indices': [117, 140], u'type': u'photo', u'id': 723543173012852738, u'media_url': u'http://pbs.twimg.com/media/CgqKrq8XEAI0ZPo.jpg'}] | 308
[{u'expanded_url': u'http://twitter.com/FTWDFans/status/726544327824957440/photo/1', u'display_url': u'pic.twitter.com/RyxstTwr5I', u'url': u'https://t.co/RyxstTwr5I', u'media_url_https': u'https://pbs.twimg.com/media/ChU0L7FUcAAwfgD.jpg', u'id_str': u'726544294333411328', u'sizes': {u'small': {u'h': 434, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 1307, u'w': 1024, u'resize': u'fit'}, u'medium': {u'h': 766, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [115, 138], u'type': u'photo', u'id': 726544294333411328, u'media_url': u'http://pbs.twimg.com/media/ChU0L7FUcAAwfgD.jpg'}] | 263
[{u'expanded_url': u'http://twitter.com/randal_olson/status/721324803207131136/photo/1', u'display_url': u'pic.twitter.com/aoMntyJudr', u'url': u'https://t.co/aoMntyJudr', u'media_url_https': u'https://pbs.twimg.com/media/CgKpFXQUEAEk-d6.jpg', u'id_str': u'721324799939579905', u'sizes': {u'large': {u'h': 515, u'resize': u'fit', u'w': 1024}, u'small': {u'h': 171, u'resize': u'fit', u'w': 340}, u'medium': {u'h': 302, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'indices': [104, 127], u'type': u'photo', u'id': 721324799939579905, u'media_url': u'http://pbs.twimg.com/media/CgKpFXQUEAEk-d6.jpg'}] | 239
Other values (3613) | 12482
(Missing) | 85101

Toggle details

Value | Count | Frequency (%) |
[{u'expanded_url': u'http://twitter.com/Delilah_Alvares/status/723543199315300352/photo/1', u'display_url': u'pic.twitter.com/uMhFFIHrbo', u'url': u'https://t.co/uMhFFIHrbo', u'media_url_https': u'https://pbs.twimg.com/media/CgqKrq8XEAI0ZPo.jpg', u'id_str': u'723543173012852738', u'sizes': {u'small': {u'h': 512, u'resize': u'fit', u'w': 340}, u'large': {u'h': 960, u'resize': u'fit', u'w': 638}, u'medium': {u'h': 903, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'indices': [117, 140], u'type': u'photo', u'id': 723543173012852738, u'media_url': u'http://pbs.twimg.com/media/CgqKrq8XEAI0ZPo.jpg'}] | 308 | 0.3% |
[{u'expanded_url': u'http://twitter.com/FTWDFans/status/726544327824957440/photo/1', u'display_url': u'pic.twitter.com/RyxstTwr5I', u'url': u'https://t.co/RyxstTwr5I', u'media_url_https': u'https://pbs.twimg.com/media/ChU0L7FUcAAwfgD.jpg', u'id_str': u'726544294333411328', u'sizes': {u'small': {u'h': 434, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 1307, u'w': 1024, u'resize': u'fit'}, u'medium': {u'h': 766, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [115, 138], u'type': u'photo', u'id': 726544294333411328, u'media_url': u'http://pbs.twimg.com/media/ChU0L7FUcAAwfgD.jpg'}] | 263 | 0.3% |
[{u'expanded_url': u'http://twitter.com/randal_olson/status/721324803207131136/photo/1', u'display_url': u'pic.twitter.com/aoMntyJudr', u'url': u'https://t.co/aoMntyJudr', u'media_url_https': u'https://pbs.twimg.com/media/CgKpFXQUEAEk-d6.jpg', u'id_str': u'721324799939579905', u'sizes': {u'large': {u'h': 515, u'resize': u'fit', u'w': 1024}, u'small': {u'h': 171, u'resize': u'fit', u'w': 340}, u'medium': {u'h': 302, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'indices': [104, 127], u'type': u'photo', u'id': 721324799939579905, u'media_url': u'http://pbs.twimg.com/media/CgKpFXQUEAEk-d6.jpg'}] | 239 | 0.2% |
[{u'expanded_url': u'http://twitter.com/SneakerPics23/status/724302929285505026/photo/1', u'display_url': u'pic.twitter.com/qpdP0DUKAu', u'url': u'https://t.co/qpdP0DUKAu', u'media_url_https': u'https://pbs.twimg.com/media/Cg09p_JUUAEu3vh.jpg', u'id_str': u'724302906610962433', u'sizes': {u'small': {u'h': 323, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 713, u'w': 750, u'resize': u'fit'}, u'medium': {u'h': 570, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [31, 54], u'type': u'photo', u'id': 724302906610962433, u'media_url': u'http://pbs.twimg.com/media/Cg09p_JUUAEu3vh.jpg'}] | 150 | 0.2% |
[{u'expanded_url': u'http://twitter.com/randal_olson/status/723584753597878272/photo/1', u'display_url': u'pic.twitter.com/sYkjvn7hzu', u'url': u'https://t.co/sYkjvn7hzu', u'media_url_https': u'https://pbs.twimg.com/media/Cgqwf7uW0AIvENf.jpg', u'id_str': u'723584752800944130', u'sizes': {u'small': {u'h': 113, u'resize': u'fit', u'w': 340}, u'large': {u'h': 340, u'resize': u'fit', u'w': 1024}, u'medium': {u'h': 199, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'indices': [115, 138], u'type': u'photo', u'id': 723584752800944130, u'media_url': u'http://pbs.twimg.com/media/Cgqwf7uW0AIvENf.jpg'}] | 146 | 0.1% |
[{u'expanded_url': u'http://twitter.com/fashionkiIIas/status/724987767000801280/photo/1', u'display_url': u'pic.twitter.com/bmzH4MVi94', u'url': u'https://t.co/bmzH4MVi94', u'media_url_https': u'https://pbs.twimg.com/media/Cg-sh87WgAEPoHS.jpg', u'id_str': u'724987764320665601', u'sizes': {u'small': {u'h': 254, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 560, u'w': 750, u'resize': u'fit'}, u'medium': {u'h': 448, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [50, 73], u'type': u'photo', u'id': 724987764320665601, u'media_url': u'http://pbs.twimg.com/media/Cg-sh87WgAEPoHS.jpg'}] | 139 | 0.1% |
[{u'source_user_id': 2892560250, u'source_status_id_str': u'653947766473949184', u'expanded_url': u'http://twitter.com/BigAssAddicted/status/653947766473949184/video/1', u'sizes': {u'small': {u'h': 187, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 396, u'w': 720, u'resize': u'fit'}, u'medium': {u'h': 330, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'url': u'https://t.co/jbLCwPRmqI', u'media_url_https': u'https://pbs.twimg.com/ext_tw_video_thumb/653947265200033792/pu/img/WZ19nUbaGWtnsW93.jpg', u'source_user_id_str': u'2892560250', u'source_status_id': 653947766473949184, u'display_url': u'pic.twitter.com/jbLCwPRmqI', u'id_str': u'653947265200033792', u'indices': [28, 51], u'type': u'photo', u'id': 653947265200033792, u'media_url': u'http://pbs.twimg.com/ext_tw_video_thumb/653947265200033792/pu/img/WZ19nUbaGWtnsW93.jpg'}] | 116 | 0.1% |
[{u'expanded_url': u'http://twitter.com/spazef0rze/status/724605272560377856/photo/1', u'display_url': u'pic.twitter.com/y8YXIvM57S', u'url': u'https://t.co/y8YXIvM57S', u'media_url_https': u'https://pbs.twimg.com/media/Cg5QbymU0AEv7V0.jpg', u'id_str': u'724605028422438913', u'sizes': {u'small': {u'h': 255, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 375, u'w': 500, u'resize': u'fit'}, u'medium': {u'h': 375, u'w': 500, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [116, 139], u'type': u'photo', u'id': 724605028422438913, u'media_url': u'http://pbs.twimg.com/media/Cg5QbymU0AEv7V0.jpg'}] | 97 | 0.1% |
[{u'expanded_url': u'http://twitter.com/UN/status/726644827769593858/photo/1', u'display_url': u'pic.twitter.com/Tn9trH2Nih', u'url': u'https://t.co/Tn9trH2Nih', u'media_url_https': u'https://pbs.twimg.com/media/Cg0B8UwUYAE5Cw4.jpg', u'id_str': u'724237250951667713', u'sizes': {u'small': {u'h': 170, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 220, u'w': 440, u'resize': u'fit'}, u'medium': {u'h': 220, u'w': 440, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [117, 140], u'type': u'photo', u'id': 724237250951667713, u'media_url': u'http://pbs.twimg.com/media/Cg0B8UwUYAE5Cw4.jpg'}] | 95 | 0.1% |
[{u'expanded_url': u'http://twitter.com/500px/status/722434350298591232/photo/1', u'display_url': u'pic.twitter.com/BjAO7UXyj2', u'url': u'https://t.co/BjAO7UXyj2', u'media_url_https': u'https://pbs.twimg.com/media/CgaaNm6UMAEYpkq.jpg', u'id_str': u'722434348813660161', u'sizes': {u'large': {u'h': 628, u'resize': u'fit', u'w': 900}, u'small': {u'h': 237, u'resize': u'fit', u'w': 340}, u'medium': {u'h': 419, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'indices': [112, 135], u'type': u'photo', u'id': 722434348813660161, u'media_url': u'http://pbs.twimg.com/media/CgaaNm6UMAEYpkq.jpg'}] | 94 | 0.1% |
[{u'expanded_url': u'http://twitter.com/KirkDBorne/status/725455009626886144/photo/1', u'display_url': u'pic.twitter.com/TK8DqOw04E', u'url': u'https://t.co/TK8DqOw04E', u'media_url_https': u'https://pbs.twimg.com/media/ChFVfIqU0AEsnTl.png', u'id_str': u'725455008372674561', u'sizes': {u'small': {u'h': 189, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 568, u'w': 1024, u'resize': u'fit'}, u'medium': {u'h': 333, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [112, 135], u'type': u'photo', u'id': 725455008372674561, u'media_url': u'http://pbs.twimg.com/media/ChFVfIqU0AEsnTl.png'}] | 89 | 0.1% |
[{u'expanded_url': u'http://twitter.com/randal_olson/status/726798373639077888/photo/1', u'display_url': u'pic.twitter.com/IO7RTTiqWB', u'url': u'https://t.co/IO7RTTiqWB', u'media_url_https': u'https://pbs.twimg.com/media/ChYbRQ0WUAA5E0U.png', u'id_str': u'726798373253173248', u'sizes': {u'small': {u'h': 469, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 577, u'w': 418, u'resize': u'fit'}, u'medium': {u'h': 577, u'w': 418, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [90, 113], u'type': u'photo', u'id': 726798373253173248, u'media_url': u'http://pbs.twimg.com/media/ChYbRQ0WUAA5E0U.png'}] | 84 | 0.1% |
[{u'expanded_url': u'http://twitter.com/preregrintook/status/726953811953094656/photo/1', u'display_url': u'pic.twitter.com/7q8Brq9igj', u'url': u'https://t.co/7q8Brq9igj', u'media_url_https': u'https://pbs.twimg.com/media/ChaooqTVEAABD8N.jpg', u'id_str': u'726953806370508800', u'sizes': {u'small': {u'h': 414, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 1248, u'w': 1024, u'resize': u'fit'}, u'medium': {u'h': 731, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [114, 137], u'type': u'photo', u'id': 726953806370508800, u'media_url': u'http://pbs.twimg.com/media/ChaooqTVEAABD8N.jpg'}] | 78 | 0.1% |
[{u'expanded_url': u'http://twitter.com/mwrlabs/status/722397141499539456/photo/1', u'display_url': u'pic.twitter.com/8pcxzepzJX', u'url': u'https://t.co/8pcxzepzJX', u'media_url_https': u'https://pbs.twimg.com/media/CgZ4XzlWsAA_jBi.jpg', u'id_str': u'722397140618752000', u'sizes': {u'small': {u'h': 57, u'resize': u'fit', u'w': 340}, u'large': {u'h': 101, u'resize': u'fit', u'w': 600}, u'medium': {u'h': 101, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 101, u'resize': u'crop', u'w': 101}}, u'indices': [104, 127], u'type': u'photo', u'id': 722397140618752000, u'media_url': u'http://pbs.twimg.com/media/CgZ4XzlWsAA_jBi.jpg'}] | 74 | 0.1% |
[{u'expanded_url': u'http://twitter.com/Ronald_vanLoon/status/724481351701921792/photo/1', u'display_url': u'pic.twitter.com/ZQ0lvCJvlZ', u'url': u'https://t.co/ZQ0lvCJvlZ', u'media_url_https': u'https://pbs.twimg.com/media/Cg3f8ynWkAAuQ_m.jpg', u'id_str': u'724481350548492288', u'sizes': {u'small': {u'h': 276, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 831, u'w': 1024, u'resize': u'fit'}, u'medium': {u'h': 487, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [117, 140], u'type': u'photo', u'id': 724481350548492288, u'media_url': u'http://pbs.twimg.com/media/Cg3f8ynWkAAuQ_m.jpg'}] | 70 | 0.1% |
[{u'expanded_url': u'http://twitter.com/UN/status/724675621318578177/photo/1', u'display_url': u'pic.twitter.com/ARQDomg4GO', u'url': u'https://t.co/ARQDomg4GO', u'media_url_https': u'https://pbs.twimg.com/media/Cg0BjMLU4AUZT3_.jpg', u'id_str': u'724236819152297989', u'sizes': {u'small': {u'h': 170, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 220, u'w': 440, u'resize': u'fit'}, u'medium': {u'h': 220, u'w': 440, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [117, 140], u'type': u'photo', u'id': 724236819152297989, u'media_url': u'http://pbs.twimg.com/media/Cg0BjMLU4AUZT3_.jpg'}] | 69 | 0.1% |
[{u'expanded_url': u'http://twitter.com/RickKing16/status/724118258232754176/photo/1', u'sizes': {u'small': {u'h': 190, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 280, u'w': 500, u'resize': u'fit'}, u'medium': {u'h': 280, u'w': 500, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'url': u'https://t.co/hYIdiAMTrD', u'media_url_https': u'https://pbs.twimg.com/media/CgyVuBUWsAAErbP.jpg', u'display_url': u'pic.twitter.com/hYIdiAMTrD', u'id_str': u'724118257960136704', u'indices': [101, 124], u'type': u'photo', u'id': 724118257960136704, u'media_url': u'http://pbs.twimg.com/media/CgyVuBUWsAAErbP.jpg'}] | 67 | 0.1% |
[{u'expanded_url': u'http://twitter.com/KyleHanslovan/status/726407560874582018/photo/1', u'display_url': u'pic.twitter.com/u1mj8MwTR8', u'url': u'https://t.co/u1mj8MwTR8', u'media_url_https': u'https://pbs.twimg.com/media/ChS3ymUWUAAmdt2.jpg', u'id_str': u'726407519820730368', u'sizes': {u'small': {u'h': 142, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 246, u'w': 591, u'resize': u'fit'}, u'medium': {u'h': 246, u'w': 591, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [103, 126], u'type': u'photo', u'id': 726407519820730368, u'media_url': u'http://pbs.twimg.com/media/ChS3ymUWUAAmdt2.jpg'}] | 67 | 0.1% |
[{u'expanded_url': u'http://twitter.com/analyticbridge/status/723208994769096706/photo/1', u'display_url': u'pic.twitter.com/wbI1IzvEdZ', u'url': u'https://t.co/wbI1IzvEdZ', u'media_url_https': u'https://pbs.twimg.com/media/Cglav58U4AAz10D.jpg', u'id_str': u'723208994223874048', u'sizes': {u'small': {u'h': 176, u'resize': u'fit', u'w': 340}, u'large': {u'h': 254, u'resize': u'fit', u'w': 490}, u'medium': {u'h': 254, u'resize': u'fit', u'w': 490}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'indices': [70, 93], u'type': u'photo', u'id': 723208994223874048, u'media_url': u'http://pbs.twimg.com/media/Cglav58U4AAz10D.jpg'}] | 63 | 0.1% |
[{u'expanded_url': u'http://twitter.com/kdnuggets/status/726051946973507584/photo/1', u'display_url': u'pic.twitter.com/JUe30cDjoI', u'url': u'https://t.co/JUe30cDjoI', u'media_url_https': u'https://pbs.twimg.com/media/ChN0ZhJW0AA1qc_.jpg', u'id_str': u'726051946679947264', u'sizes': {u'small': {u'h': 343, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 408, u'w': 404, u'resize': u'fit'}, u'medium': {u'h': 408, u'w': 404, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [94, 117], u'type': u'photo', u'id': 726051946679947264, u'media_url': u'http://pbs.twimg.com/media/ChN0ZhJW0AA1qc_.jpg'}] | 61 | 0.1% |
Other values (3596) | 10923 | 11.1% |
(Missing) | 85101 | 86.5% |

retweeted_status_entities_symbols
Categorical

Distinct count | 5
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

[] | 34561
[{u'indices': [88, 92], u'text': u'SPY'}] | 1
[{u'indices': [0, 4], u'text': u'USD'}] | 1
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
[] | 34561 | 35.1% |
[{u'indices': [88, 92], u'text': u'SPY'}] | 1 | 0.0% |
[{u'indices': [0, 4], u'text': u'USD'}] | 1 | 0.0% |
[{u'indices': [118, 120], u'text': u's'}] | 1 | 0.0% |
(Missing) | 63829 | 64.9% |

retweeted_status_entities_urls
Categorical

Distinct count | 7892
Unique (%) | 22.8%
Missing (%) | 64.9%
Missing (n) | 63829

[] | 8864
[{u'url': u'https://t.co/QhYq3PcuZy', u'indices': [116, 139], u'expanded_url': u'https://twitter.com/ndtv/status/724601469408796673', u'display_url': u'twitter.com/ndtv/status/72\xe2\x80\xa6'}] | 944
[{u'url': u'https://t.co/WDFEUdyrbS', u'indices': [80, 103], u'expanded_url': u'https://www.youtube.com/watch?v=cKxRvEZd3Mw', u'display_url': u'youtube.com/watch?v=cKxRvE\xe2\x80\xa6'}] | 254
Other values (7888) | 24502
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
[] | 8864 | 9.0% |
[{u'url': u'https://t.co/QhYq3PcuZy', u'indices': [116, 139], u'expanded_url': u'https://twitter.com/ndtv/status/724601469408796673', u'display_url': u'twitter.com/ndtv/status/72\xe2\x80\xa6'}] | 944 | 1.0% |
[{u'url': u'https://t.co/WDFEUdyrbS', u'indices': [80, 103], u'expanded_url': u'https://www.youtube.com/watch?v=cKxRvEZd3Mw', u'display_url': u'youtube.com/watch?v=cKxRvE\xe2\x80\xa6'}] | 254 | 0.3% |
[{u'indices': [91, 114], u'url': u'https://t.co/0dEyFM6sVd', u'expanded_url': u'http://www.ubuntu.com/desktop/developers', u'display_url': u'ubuntu.com/desktop/develo\xe2\x80\xa6'}] | 146 | 0.1% |
[{u'url': u'https://t.co/99ttVa37RC', u'indices': [68, 91], u'expanded_url': u'http://bit.ly/1rrY3i3', u'display_url': u'bit.ly/1rrY3i3'}] | 145 | 0.1% |
[{u'url': u'https://t.co/m4576sRH5a', u'indices': [71, 94], u'expanded_url': u'http://youtu.be/ys8fyr_hxws?a', u'display_url': u'youtu.be/ys8fyr_hxws?a'}] | 129 | 0.1% |
[{u'url': u'https://t.co/hOdcRLTG0k', u'indices': [59, 82], u'expanded_url': u'http://bit.ly/1NUIT9t', u'display_url': u'bit.ly/1NUIT9t'}] | 126 | 0.1% |
[{u'url': u'https://t.co/5mCv2YPZPT', u'indices': [81, 104], u'expanded_url': u'http://www.analyticbridge.com/profiles/blogs/machine-learning-with-python-why-do-they-form-the-best', u'display_url': u'analyticbridge.com/profiles/blogs\xe2\x80\xa6'}, {u'url': u'https://t.co/AeaCnTTV7M', u'indices': [115, 138], u'expanded_url': u'http://tweetedtimes.com/craigbrownphd?s=tnp', u'display_url': u'tweetedtimes.com/craigbrownphd?\xe2\x80\xa6'}] | 125 | 0.1% |
[{u'url': u'https://t.co/qhwzvuhl1t', u'indices': [98, 121], u'expanded_url': u'http://tinyurl.com/gr89wcl', u'display_url': u'tinyurl.com/gr89wcl'}] | 107 | 0.1% |
[{u'url': u'https://t.co/Xe205pWGuq', u'indices': [24, 47], u'expanded_url': u'http://bit.ly/20gNQir', u'display_url': u'bit.ly/20gNQir'}] | 97 | 0.1% |
[{u'url': u'https://t.co/1kG77yMvJ2', u'indices': [92, 115], u'expanded_url': u'https://github.com/spaze/oprah-proxy', u'display_url': u'github.com/spaze/oprah-pr\xe2\x80\xa6'}] | 97 | 0.1% |
[{u'url': u'https://t.co/TLsTPzBGel', u'indices': [74, 97], u'expanded_url': u'http://bit.ly/electricity4all', u'display_url': u'bit.ly/electricity4all'}] | 95 | 0.1% |
[{u'url': u'https://t.co/i019MUteJw', u'indices': [93, 116], u'expanded_url': u'http://bit.ly/1U9mRni', u'display_url': u'bit.ly/1U9mRni'}] | 93 | 0.1% |
[{u'url': u'https://t.co/lVK5ggmUG4', u'indices': [37, 60], u'expanded_url': u'http://bit.ly/1UUgu9Q', u'display_url': u'bit.ly/1UUgu9Q'}] | 92 | 0.1% |
[{u'url': u'https://t.co/afz3mNeaif', u'indices': [42, 65], u'expanded_url': u'https://psychopyrate.tumblr.com/post/143670852984/some-of-my-favorite-sites', u'display_url': u'psychopyrate.tumblr.com/post/143670852\xe2\x80\xa6'}] | 92 | 0.1% |
[{u'indices': [71, 94], u'url': u'https://t.co/m4576sRH5a', u'expanded_url': u'http://youtu.be/ys8fyr_hxws?a', u'display_url': u'youtu.be/ys8fyr_hxws?a'}] | 91 | 0.1% |
[{u'url': u'https://t.co/mO4MqPAzTX', u'indices': [88, 111], u'expanded_url': u'https://goo.gl/mbRBdI', u'display_url': u'goo.gl/mbRBdI'}] | 90 | 0.1% |
[{u'url': u'https://t.co/rXlDQJBdmz', u'indices': [61, 84], u'expanded_url': u'http://bit.ly/22h94TK', u'display_url': u'bit.ly/22h94TK'}] | 88 | 0.1% |
[{u'url': u'https://t.co/elmV7H8Hm8', u'indices': [66, 89], u'expanded_url': u'https://blog.ionelmc.ro/2015/02/09/understanding-python-metaclasses/', u'display_url': u'blog.ionelmc.ro/2015/02/09/und\xe2\x80\xa6'}] | 84 | 0.1% |
[{u'url': u'https://t.co/F9WgHsGkgm', u'indices': [98, 121], u'expanded_url': u'http://bit.ly/HBHacking', u'display_url': u'bit.ly/HBHacking'}] | 84 | 0.1% |
Other values (7871) | 22721 | 23.1% |
(Missing) | 63829 | 64.9% |

retweeted_status_entities_user_mentions
Categorical

Distinct count | 2882
Unique (%) | 8.4%
Missing (%) | 65.2%
Missing (n) | 64135

[] | 26814
[{u'indices': [102, 116], u'id': 3273261744, u'id_str': u'3273261744', u'name': u'Unite Ideas', u'screen_name': u'UN_UniteIdeas'}] | 95
[{u'indices': [27, 40], u'id': 18903165, u'id_str': u'18903165', u'name': u'DevOps Summit', u'screen_name': u'DevOpsSummit'}] | 88
Other values (2878) | 7261
(Missing) | 64135

Toggle details

Value | Count | Frequency (%) |
[] | 26814 | 27.3% |
[{u'indices': [102, 116], u'id': 3273261744, u'id_str': u'3273261744', u'name': u'Unite Ideas', u'screen_name': u'UN_UniteIdeas'}] | 95 | 0.1% |
[{u'indices': [27, 40], u'id': 18903165, u'id_str': u'18903165', u'name': u'DevOps Summit', u'screen_name': u'DevOpsSummit'}] | 88 | 0.1% |
[{u'indices': [14, 22], u'screen_name': u'_samdb_', u'id': 285147437, u'name': u'Sam Brown', u'id_str': u'285147437'}] | 73 | 0.1% |
[{u'indices': [63, 69], u'id': 865622395, u'id_str': u'865622395', u'name': u'Sebastian Raschka', u'screen_name': u'rasbt'}] | 71 | 0.1% |
[{u'indices': [78, 92], u'id': 3273261744, u'id_str': u'3273261744', u'name': u'Unite Ideas', u'screen_name': u'UN_UniteIdeas'}] | 69 | 0.1% |
[{u'indices': [50, 62], u'id_str': u'2915491332', u'screen_name': u'ByondTravel', u'name': u'Byond Travel', u'id': 2915491332}] | 65 | 0.1% |
[{u'indices': [27, 38], u'id': 20572070, u'id_str': u'20572070', u'name': u'Jacob Ferrato', u'screen_name': u'JBFcustoms'}] | 55 | 0.1% |
[{u'indices': [27, 36], u'id': 1568606814, u'id_str': u'1568606814', u'name': u'DataCamp', u'screen_name': u'DataCamp'}] | 50 | 0.1% |
[{u'indices': [1, 17], u'id': 20348431, u'id_str': u'20348431', u'name': u'adidas Originals', u'screen_name': u'adidasoriginals'}] | 43 | 0.0% |
[{u'indices': [64, 70], u'screen_name': u'udemy', u'id': 70266297, u'name': u'Udemy', u'id_str': u'70266297'}] | 42 | 0.0% |
[{u'indices': [82, 88], u'screen_name': u'rasbt', u'id': 865622395, u'name': u'Sebastian Raschka', u'id_str': u'865622395'}] | 40 | 0.0% |
[{u'indices': [58, 71], u'screen_name': u'videoboyblog', u'id': 29581654, u'name': u'DawgPoundUSA', u'id_str': u'29581654'}] | 38 | 0.0% |
[{u'indices': [26, 33], u'screen_name': u'docker', u'id': 1138959692, u'name': u'Docker', u'id_str': u'1138959692'}, {u'indices': [94, 105], u'screen_name': u'RealPython', u'id': 745911914, u'name': u'RealPython.com', u'id_str': u'745911914'}, {u'indices': [106, 120], u'screen_name': u'djangoproject', u'id': 191225303, u'name': u'Django', u'id_str': u'191225303'}] | 38 | 0.0% |
[{u'indices': [73, 86], u'id': 586410081, u'id_str': u'586410081', u'name': u'Developer Economics', u'screen_name': u'DevEconomics'}] | 38 | 0.0% |
[{u'indices': [1, 13], u'id': 27241881, u'id_str': u'27241881', u'name': u'Ben Nuttall', u'screen_name': u'ben_nuttall'}] | 37 | 0.0% |
[{u'indices': [51, 66], u'screen_name': u'brandon_rhodes', u'id': 15366875, u'name': u'Brandon Rhodes', u'id_str': u'15366875'}] | 37 | 0.0% |
[{u'indices': [90, 100], u'id': 2677694917, u'id_str': u'2677694917', u'name': u'Cybrary', u'screen_name': u'cybraryIT'}] | 33 | 0.0% |
[{u'indices': [74, 90], u'id': 393033324, u'id_str': u'393033324', u'name': u'Data Science Central', u'screen_name': u'DataScienceCtrl'}] | 30 | 0.0% |
[{u'indices': [26, 39], u'id': 29581654, u'id_str': u'29581654', u'name': u'DawgPoundUSA', u'screen_name': u'videoboyblog'}] | 28 | 0.0% |
Other values (2861) | 6474 | 6.6% |
(Missing) | 64135 | 65.2% |

retweeted_status_favorite_count
Highly correlated

This variable is highly correlated with `retweet_count` and should be ignored for analysis

Correlation | 0.95171

retweeted_status_favorited
Categorical

Distinct count | 2
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

False | 34564
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
False | 34564 | 35.1% |
(Missing) | 63829 | 64.9% |

retweeted_status_id
Numeric

Distinct count | 11610
Unique (%) | 33.6%
Missing (%) | 64.9%
Missing (n) | 63829

Mean | 7.2119e+17
Minimum | 3613600000
Maximum | 7.2753e+17
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 3613600000
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 7.2753e+17
Range | 7.2753e+17
Interquartile range |

Descriptive statistics

Standard deviation | 3.1095e+16
Coef of variation | 0.043117
Kurtosis | 301.72
Mean | 7.2119e+17
MAD | 5.7308e+15
Skewness | -16.496
Sum | 2.4927e+22
Variance | 9.6692e+32
Memory size | 768.8 KiB

retweeted_status_id_str
Highly correlated

This variable is highly correlated with `retweeted_status_id` and should be ignored for analysis

Correlation | 1

retweeted_status_in_reply_to_screen_name
Categorical

Distinct count | 878
Unique (%) | 63.0%
Missing (%) | 98.6%
Missing (n) | 97000

randal_olson | 44
FVMISO | 27
KirkDBorne | 19
Other values (874) | 1303
(Missing) | 97000

Toggle details

Value | Count | Frequency (%) |
randal_olson | 44 | 0.0% |
FVMISO | 27 | 0.0% |
KirkDBorne | 19 | 0.0% |
alicegoldfuss | 17 | 0.0% |
pybcn | 13 | 0.0% |
mariofusco | 12 | 0.0% |
Gurmeetramrahim | 11 | 0.0% |
AricToler | 10 | 0.0% |
bigapplepyinc | 9 | 0.0% |
JaredEYoung | 8 | 0.0% |
fred_SSC | 8 | 0.0% |
lynlinking | 8 | 0.0% |
unicodeveloper | 7 | 0.0% |
mikegrimshaw2 | 7 | 0.0% |
drchuck | 7 | 0.0% |
PaideiaSS | 7 | 0.0% |
BSidesCleveland | 6 | 0.0% |
volcan01010 | 6 | 0.0% |
williballenthin | 6 | 0.0% |
ramez | 6 | 0.0% |
Other values (857) | 1155 | 1.2% |
(Missing) | 97000 | 98.6% |

retweeted_status_in_reply_to_status_id
Highly correlated

This variable is highly correlated with `retweeted_status_id_str` and should be ignored for analysis

Correlation | 0.98947

retweeted_status_in_reply_to_status_id_str
Highly correlated

This variable is highly correlated with `retweeted_status_in_reply_to_status_id` and should be ignored for analysis

Correlation | 1

retweeted_status_in_reply_to_user_id
Numeric

Distinct count | 878
Unique (%) | 63.0%
Missing (%) | 98.6%
Missing (n) | 97000

Mean | 1.4383e+16
Minimum | 5339
Maximum | 7.2344e+17
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 5339
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 7.2344e+17
Range | 7.2344e+17
Interquartile range |

Descriptive statistics

Standard deviation | 1.0046e+17
Coef of variation | 6.985
Kurtosis | 44.957
Mean | 1.4383e+16
MAD | 2.8187e+16
Skewness | 6.8474
Sum | 2.0035e+19
Variance | 1.0093e+34
Memory size | 768.8 KiB

retweeted_status_in_reply_to_user_id_str
Highly correlated

This variable is highly correlated with `retweeted_status_in_reply_to_user_id` and should be ignored for analysis

Correlation | 1

retweeted_status_is_quote_status
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

False | 33135
True | 1429
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
False | 33135 | 33.7% |
True | 1429 | 1.5% |
(Missing) | 63829 | 64.9% |

retweeted_status_lang
Categorical

Distinct count | 2
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

en | 34564
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
en | 34564 | 35.1% |
(Missing) | 63829 | 64.9% |

retweeted_status_metadata_iso_language_code
Categorical

Distinct count | 2
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

en | 34564
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
en | 34564 | 35.1% |
(Missing) | 63829 | 64.9% |

retweeted_status_metadata_result_type
Categorical

Distinct count | 2
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

recent | 34564
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
recent | 34564 | 35.1% |
(Missing) | 63829 | 64.9% |

retweeted_status_place_bounding_box_coordinates
Categorical

Distinct count | 239
Unique (%) | 18.9%
Missing (%) | 98.7%
Missing (n) | 97129

[[[-79.487651, 37.886607], [-74.986286, 37.886607], [-74.986286, 39.723622], [-79.487651, 39.723622]]] | 231
[[[-77.02294335, 38.9041435719], [-77.02294335, 38.9041435719], [-77.02294335, 38.9041435719], [-77.02294335, 38.9041435719]]] | 58
[[[13.3657388, 52.504089], [13.429441, 52.504089], [13.429441, 52.540159], [13.3657388, 52.540159]]] | 53
Other values (235) | 922
(Missing) | 97129

Toggle details

Value | Count | Frequency (%) |
[[[-79.487651, 37.886607], [-74.986286, 37.886607], [-74.986286, 39.723622], [-79.487651, 39.723622]]] | 231 | 0.2% |
[[[-77.02294335, 38.9041435719], [-77.02294335, 38.9041435719], [-77.02294335, 38.9041435719], [-77.02294335, 38.9041435719]]] | 58 | 0.1% |
[[[13.3657388, 52.504089], [13.429441, 52.504089], [13.429441, 52.540159], [13.3657388, 52.540159]]] | 53 | 0.1% |
[[[-1.372296, 54.538762], [-1.2717038, 54.538762], [-1.2717038, 54.600693], [-1.372296, 54.600693]]] | 44 | 0.0% |
[[[-77.485561, 38.840172], [-77.364749, 38.840172], [-77.364749, 38.917243], [-77.485561, 38.917243]]] | 43 | 0.0% |
[[[-122.077393234, 37.414524681], [-122.077393234, 37.414524681], [-122.077393234, 37.414524681], [-122.077393234, 37.414524681]]] | 37 | 0.0% |
[[[-84.576827, 33.6475029], [-84.289385, 33.6475029], [-84.289385, 33.8868859], [-84.576827, 33.8868859]]] | 35 | 0.0% |
[[[22.1357201, 44.386383], [40.227172, 44.386383], [40.227172, 52.379475], [22.1357201, 52.379475]]] | 33 | 0.0% |
[[[-118.668404, 33.704538], [-118.155409, 33.704538], [-118.155409, 34.337041], [-118.668404, 34.337041]]] | 31 | 0.0% |
[[[-97.131525, 47.86007], [-96.999601, 47.86007], [-96.999601, 47.954924], [-97.131525, 47.954924]]] | 30 | 0.0% |
[[[-80.147162, 25.7613083], [-80.1187628, 25.7613083], [-80.1187628, 25.872623], [-80.147162, 25.872623]]] | 29 | 0.0% |
[[[-117.282538, 32.53962], [-116.9274403, 32.53962], [-116.9274403, 33.0804044], [-117.282538, 33.0804044]]] | 27 | 0.0% |
[[[-73.933612, 40.785365], [-73.765271, 40.785365], [-73.765271, 40.91533], [-73.933612, 40.91533]]] | 21 | 0.0% |
[[[-97.740086, 30.263577], [-97.740086, 30.263577], [-97.740086, 30.263577], [-97.740086, 30.263577]]] | 20 | 0.0% |
[[[-0.112442, 51.5068], [-0.0733794, 51.5068], [-0.0733794, 51.522161], [-0.112442, 51.522161]]] | 16 | 0.0% |
[[[-78.201069, 39.13086], [-78.1376541, 39.13086], [-78.1376541, 39.204922], [-78.201069, 39.204922]]] | 16 | 0.0% |
[[[-46.108612, -23.306164], [-45.7262721, -23.306164], [-45.7262721, -22.816672], [-46.108612, -22.816672]]] | 14 | 0.0% |
[[[-96.903853, 46.787881], [-96.756332, 46.787881], [-96.756332, 46.941884], [-96.903853, 46.941884]]] | 11 | 0.0% |
[[[-82.48315, 28.851867], [-82.386033, 28.851867], [-82.386033, 28.900198], [-82.48315, 28.900198]]] | 11 | 0.0% |
[[[2.0524766, 41.3170475], [2.2299781, 41.3170475], [2.2299781, 41.4682658], [2.0524766, 41.4682658]]] | 11 | 0.0% |
Other values (218) | 493 | 0.5% |
(Missing) | 97129 | 98.7% |

retweeted_status_place_bounding_box_type
Categorical

Distinct count | 2
Unique (%) | 0.2%
Missing (%) | 98.7%
Missing (n) | 97129

Polygon | 1264
(Missing) | 97129

Toggle details

Value | Count | Frequency (%) |
Polygon | 1264 | 1.3% |
(Missing) | 97129 | 98.7% |

retweeted_status_place_contained_within
Categorical

Distinct count | 2
Unique (%) | 0.2%
Missing (%) | 98.7%
Missing (n) | 97129

[] | 1264
(Missing) | 97129

Toggle details

Value | Count | Frequency (%) |
[] | 1264 | 1.3% |
(Missing) | 97129 | 98.7% |

retweeted_status_place_country
Categorical

Distinct count | 27
Unique (%) | 2.3%
Missing (%) | 98.8%
Missing (n) | 97223

United States | 793
United Kingdom | 124
Deutschland | 72
Other values (23) | 181
(Missing) | 97223

Toggle details

Value | Count | Frequency (%) |
United States | 793 | 0.8% |
United Kingdom | 124 | 0.1% |
Deutschland | 72 | 0.1% |
Australia | 39 | 0.0% |
Brasil | 21 | 0.0% |
Italia | 20 | 0.0% |
Canada | 17 | 0.0% |
Ireland | 17 | 0.0% |
Malaysia | 14 | 0.0% |
Kenya | 10 | 0.0% |
Polska | 8 | 0.0% |
Nederland | 6 | 0.0% |
Schweiz | 6 | 0.0% |
Sverige | 4 | 0.0% |
South Africa | 4 | 0.0% |
France | 3 | 0.0% |
Bolivia | 2 | 0.0% |
Bermuda | 2 | 0.0% |
Danmark | 1 | 0.0% |
Indonesia | 1 | 0.0% |
Other values (6) | 6 | 0.0% |
(Missing) | 97223 | 98.8% |

retweeted_status_place_country_code
Categorical

Distinct count | 39
Unique (%) | 3.1%
Missing (%) | 98.7%
Missing (n) | 97131

US | 793
GB | 124
DE | 72
Other values (35) | 273
(Missing) | 97131

Toggle details

Value | Count | Frequency (%) |
US | 793 | 0.8% |
GB | 124 | 0.1% |
DE | 72 | 0.1% |
AU | 39 | 0.0% |
UA | 33 | 0.0% |
BR | 21 | 0.0% |
IT | 20 | 0.0% |
IE | 17 | 0.0% |
CA | 17 | 0.0% |
MY | 14 | 0.0% |
RU | 14 | 0.0% |
ES | 12 | 0.0% |
IN | 11 | 0.0% |
KE | 10 | 0.0% |
PL | 8 | 0.0% |
CH | 6 | 0.0% |
DZ | 6 | 0.0% |
NL | 6 | 0.0% |
ZA | 4 | 0.0% |
SG | 4 | 0.0% |
Other values (18) | 31 | 0.0% |
(Missing) | 97131 | 98.7% |

retweeted_status_place_full_name
Categorical

Distinct count | 230
Unique (%) | 18.6%
Missing (%) | 98.7%
Missing (n) | 97157

Maryland, USA | 231
Walter E. Washington Convention Center | 58
City Centre, Berlin | 53
Other values (226) | 894
(Missing) | 97157

Toggle details

Value | Count | Frequency (%) |
Maryland, USA | 231 | 0.2% |
Walter E. Washington Convention Center | 58 | 0.1% |
City Centre, Berlin | 53 | 0.1% |
Stockton-on-Tees, England | 44 | 0.0% |
Chantilly, VA | 43 | 0.0% |
Computer History Museum | 37 | 0.0% |
Atlanta, GA | 35 | 0.0% |
Ukraine | 33 | 0.0% |
Los Angeles, CA | 31 | 0.0% |
Grand Forks, ND | 30 | 0.0% |
Miami Beach, FL | 29 | 0.0% |
San Diego, CA | 27 | 0.0% |
Bronx, NY | 21 | 0.0% |
Austin Convention Center | 20 | 0.0% |
Winchester, VA | 16 | 0.0% |
City of London, London | 16 | 0.0% |
Barcelona, Spain | 11 | 0.0% |
Fargo, ND | 11 | 0.0% |
Citrus Hills, FL | 11 | 0.0% |
Fingal, Ireland | 10 | 0.0% |
Other values (209) | 469 | 0.5% |
(Missing) | 97157 | 98.7% |

retweeted_status_place_id
Categorical

Distinct count | 239
Unique (%) | 18.9%
Missing (%) | 98.7%
Missing (n) | 97129

dea1eac2d7ef8878 | 231
07d9e3a18b488000 | 58
2825830a11306ae1 | 53
Other values (235) | 922
(Missing) | 97129

Toggle details

Value | Count | Frequency (%) |
dea1eac2d7ef8878 | 231 | 0.2% |
07d9e3a18b488000 | 58 | 0.1% |
2825830a11306ae1 | 53 | 0.1% |
3e20eaf0dc70acfe | 44 | 0.0% |
353916ce76086be6 | 43 | 0.0% |
07d9c9346c081000 | 37 | 0.0% |
8173485c72e78ca5 | 35 | 0.0% |
084d0d0155787e9d | 33 | 0.0% |
3b77caf94bfc81fe | 31 | 0.0% |
da0b409f35f780db | 30 | 0.0% |
0121b92345f0e2b4 | 29 | 0.0% |
a592bd6ceb1319f7 | 27 | 0.0% |
002e24c6736f069d | 21 | 0.0% |
07d9e38710082001 | 20 | 0.0% |
3eb2c704fe8a50cb | 16 | 0.0% |
b4add85f41a3e371 | 16 | 0.0% |
ad8a3318a4317a03 | 14 | 0.0% |
5c8fea63bc3faa5b | 11 | 0.0% |
2f42eb84fa19ab47 | 11 | 0.0% |
1a27537478dd8e38 | 11 | 0.0% |
Other values (218) | 493 | 0.5% |
(Missing) | 97129 | 98.7% |

retweeted_status_place_name
Categorical

Distinct count | 229
Unique (%) | 18.5%
Missing (%) | 98.7%
Missing (n) | 97156

Maryland | 231
Walter E. Washington Convention Center | 58
City Centre | 53
Other values (225) | 895
(Missing) | 97156

Toggle details

Value | Count | Frequency (%) |
Maryland | 231 | 0.2% |
Walter E. Washington Convention Center | 58 | 0.1% |
City Centre | 53 | 0.1% |
Stockton-on-Tees | 44 | 0.0% |
Chantilly | 43 | 0.0% |
Computer History Museum | 37 | 0.0% |
Atlanta | 35 | 0.0% |
Ukraine | 33 | 0.0% |
Los Angeles | 31 | 0.0% |
Grand Forks | 30 | 0.0% |
Miami Beach | 29 | 0.0% |
San Diego | 27 | 0.0% |
Bronx | 21 | 0.0% |
Austin Convention Center | 20 | 0.0% |
Winchester | 16 | 0.0% |
City of London | 16 | 0.0% |
Fargo | 11 | 0.0% |
Citrus Hills | 11 | 0.0% |
Barcelona | 11 | 0.0% |
Brisbane | 10 | 0.0% |
Other values (208) | 470 | 0.5% |
(Missing) | 97156 | 98.7% |

retweeted_status_place_place_type
Categorical

Distinct count | 6
Unique (%) | 0.5%
Missing (%) | 98.7%
Missing (n) | 97129

city | 735
admin | 282
poi | 126
Other values (2) | 121
(Missing) | 97129

Toggle details

Value | Count | Frequency (%) |
city | 735 | 0.7% |
admin | 282 | 0.3% |
poi | 126 | 0.1% |
neighborhood | 67 | 0.1% |
country | 54 | 0.1% |
(Missing) | 97129 | 98.7% |

retweeted_status_place_url
Categorical

Distinct count | 239
Unique (%) | 18.9%
Missing (%) | 98.7%
Missing (n) | 97129

https://api.twitter.com/1.1/geo/id/dea1eac2d7ef8878.json | 231
https://api.twitter.com/1.1/geo/id/07d9e3a18b488000.json | 58
https://api.twitter.com/1.1/geo/id/2825830a11306ae1.json | 53
Other values (235) | 922
(Missing) | 97129

Toggle details

Value | Count | Frequency (%) |
https://api.twitter.com/1.1/geo/id/dea1eac2d7ef8878.json | 231 | 0.2% |
https://api.twitter.com/1.1/geo/id/07d9e3a18b488000.json | 58 | 0.1% |
https://api.twitter.com/1.1/geo/id/2825830a11306ae1.json | 53 | 0.1% |
https://api.twitter.com/1.1/geo/id/3e20eaf0dc70acfe.json | 44 | 0.0% |
https://api.twitter.com/1.1/geo/id/353916ce76086be6.json | 43 | 0.0% |
https://api.twitter.com/1.1/geo/id/07d9c9346c081000.json | 37 | 0.0% |
https://api.twitter.com/1.1/geo/id/8173485c72e78ca5.json | 35 | 0.0% |
https://api.twitter.com/1.1/geo/id/084d0d0155787e9d.json | 33 | 0.0% |
https://api.twitter.com/1.1/geo/id/3b77caf94bfc81fe.json | 31 | 0.0% |
https://api.twitter.com/1.1/geo/id/da0b409f35f780db.json | 30 | 0.0% |
https://api.twitter.com/1.1/geo/id/0121b92345f0e2b4.json | 29 | 0.0% |
https://api.twitter.com/1.1/geo/id/a592bd6ceb1319f7.json | 27 | 0.0% |
https://api.twitter.com/1.1/geo/id/002e24c6736f069d.json | 21 | 0.0% |
https://api.twitter.com/1.1/geo/id/07d9e38710082001.json | 20 | 0.0% |
https://api.twitter.com/1.1/geo/id/b4add85f41a3e371.json | 16 | 0.0% |
https://api.twitter.com/1.1/geo/id/3eb2c704fe8a50cb.json | 16 | 0.0% |
https://api.twitter.com/1.1/geo/id/ad8a3318a4317a03.json | 14 | 0.0% |
https://api.twitter.com/1.1/geo/id/1a27537478dd8e38.json | 11 | 0.0% |
https://api.twitter.com/1.1/geo/id/2f42eb84fa19ab47.json | 11 | 0.0% |
https://api.twitter.com/1.1/geo/id/5c8fea63bc3faa5b.json | 11 | 0.0% |
Other values (218) | 493 | 0.5% |
(Missing) | 97129 | 98.7% |

retweeted_status_possibly_sensitive
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 70.4%
Missing (n) | 69243

False | 28792
True | 358
(Missing) | 69243

Toggle details

Value | Count | Frequency (%) |
False | 28792 | 29.3% |
True | 358 | 0.4% |
(Missing) | 69243 | 70.4% |

retweeted_status_quoted_status_created_at
Categorical

Distinct count | 217
Unique (%) | 15.4%
Missing (%) | 98.6%
Missing (n) | 96981

Mon Apr 25 14:10:27 +0000 2016 | 947
Sat Apr 30 16:18:48 +0000 2016 | 21
Tue Jan 26 22:44:10 +0000 2016 | 21
Other values (213) | 423
(Missing) | 96981

Toggle details

Value | Count | Frequency (%) |
Mon Apr 25 14:10:27 +0000 2016 | 947 | 1.0% |
Sat Apr 30 16:18:48 +0000 2016 | 21 | 0.0% |
Tue Jan 26 22:44:10 +0000 2016 | 21 | 0.0% |
Tue Apr 26 10:15:15 +0000 2016 | 16 | 0.0% |
Tue May 03 11:01:51 +0000 2016 | 11 | 0.0% |
Wed Apr 20 16:11:10 +0000 2016 | 11 | 0.0% |
Sat Apr 23 01:57:42 +0000 2016 | 10 | 0.0% |
Tue Apr 12 09:49:06 +0000 2016 | 7 | 0.0% |
Tue Apr 26 19:07:08 +0000 2016 | 7 | 0.0% |
Tue May 03 01:57:17 +0000 2016 | 6 | 0.0% |
Thu Mar 24 15:02:20 +0000 2016 | 6 | 0.0% |
Fri Apr 22 12:46:46 +0000 2016 | 6 | 0.0% |
Tue May 03 01:51:52 +0000 2016 | 6 | 0.0% |
Mon Apr 18 20:28:09 +0000 2016 | 6 | 0.0% |
Mon May 02 15:57:40 +0000 2016 | 6 | 0.0% |
Sun Apr 24 01:43:46 +0000 2016 | 6 | 0.0% |
Mon Apr 25 21:30:06 +0000 2016 | 5 | 0.0% |
Mon Apr 18 14:40:10 +0000 2016 | 5 | 0.0% |
Fri Apr 15 19:33:09 +0000 2016 | 5 | 0.0% |
Mon Apr 25 15:11:18 +0000 2016 | 5 | 0.0% |
Other values (196) | 299 | 0.3% |
(Missing) | 96981 | 98.6% |

retweeted_status_quoted_status_entities_hashtags
Categorical

Distinct count | 88
Unique (%) | 6.2%
Missing (%) | 98.6%
Missing (n) | 96981

[] | 1220
[{u'indices': [75, 82], u'text': u'pydata'}] | 11
[{u'indices': [10, 24], u'text': u'DayAgainstDRM'}] | 11
Other values (84) | 170
(Missing) | 96981

Toggle details

Value | Count | Frequency (%) |
[] | 1220 | 1.2% |
[{u'indices': [75, 82], u'text': u'pydata'}] | 11 | 0.0% |
[{u'indices': [10, 24], u'text': u'DayAgainstDRM'}] | 11 | 0.0% |
[{u'indices': [64, 71], u'text': u'rstats'}] | 10 | 0.0% |
[{u'indices': [17, 24], u'text': u'Python'}] | 9 | 0.0% |
[{u'indices': [8, 15], u'text': u'askSPC'}] | 7 | 0.0% |
[{u'indices': [14, 19], u'text': u'HTML'}, {u'indices': [20, 24], u'text': u'CSS'}, {u'indices': [31, 38], u'text': u'Python'}] | 7 | 0.0% |
[{u'indices': [39, 46], u'text': u'Python'}] | 6 | 0.0% |
[{u'indices': [51, 63], u'text': u'datascience'}, {u'indices': [64, 69], u'text': u'data'}] | 6 | 0.0% |
[{u'indices': [25, 32], u'text': u'Hadoop'}, {u'indices': [101, 109], u'text': u'bigdata'}] | 5 | 0.0% |
[{u'indices': [0, 15], u'text': u'2131wetandwild'}] | 5 | 0.0% |
[{u'indices': [25, 45], u'text': u'AutomationFramework'}] | 4 | 0.0% |
[{u'indices': [14, 30], u'text': u'MachineLearning'}, {u'indices': [31, 43], u'text': u'DataScience'}, {u'indices': [44, 55], u'text': u'OpenSource'}, {u'indices': [89, 97], u'text': u'BigData'}, {u'indices': [98, 108], u'text': u'Analytics'}] | 4 | 0.0% |
[{u'indices': [116, 128], u'text': u'djangogirls'}, {u'indices': [129, 140], u'text': u'learn2code'}] | 4 | 0.0% |
[{u'indices': [29, 36], u'text': u'Python'}, {u'indices': [37, 45], u'text': u'DataViz'}] | 4 | 0.0% |
[{u'indices': [31, 39], u'text': u'SciFest'}] | 3 | 0.0% |
[{u'indices': [41, 57], u'text': u'machinelearning'}] | 3 | 0.0% |
[{u'indices': [59, 64], u'text': u'RJam'}] | 3 | 0.0% |
[{u'indices': [36, 43], u'text': u'Ubuntu'}] | 2 | 0.0% |
[{u'indices': [78, 90], u'text': u'DataScience'}, {u'indices': [91, 107], u'text': u'MachineLearning'}] | 2 | 0.0% |
Other values (67) | 86 | 0.1% |
(Missing) | 96981 | 98.6% |

retweeted_status_quoted_status_entities_media
Categorical

Distinct count | 79
Unique (%) | 7.1%
Missing (%) | 98.9%
Missing (n) | 97278

[{u'expanded_url': u'http://twitter.com/ndtv/status/724601469408796673/photo/1', u'sizes': {u'small': {u'h': 209, u'resize': u'fit', u'w': 340}, u'large': {u'h': 400, u'resize': u'fit', u'w': 650}, u'medium': {u'h': 369, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/7eFucdjpmP', u'media_url_https': u'https://pbs.twimg.com/media/Cg5NMhUU4AAq5ig.jpg', u'id_str': u'724601467550621696', u'indices': [77, 100], u'media_url': u'http://pbs.twimg.com/media/Cg5NMhUU4AAq5ig.jpg', u'type': u'photo', u'id': 724601467550621696, u'display_url': u'pic.twitter.com/7eFucdjpmP'}] | 947
[{u'expanded_url': u'http://twitter.com/TomAugspurger/status/726445711202484224/photo/1', u'sizes': {u'small': {u'h': 170, u'resize': u'fit', u'w': 340}, u'large': {u'h': 432, u'resize': u'fit', u'w': 864}, u'medium': {u'h': 300, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/PoDO98Fp8x', u'media_url_https': u'https://pbs.twimg.com/media/ChTahiWU0AAmFuU.jpg', u'id_str': u'726445709604474880', u'indices': [58, 81], u'media_url': u'http://pbs.twimg.com/media/ChTahiWU0AAmFuU.jpg', u'type': u'photo', u'id': 726445709604474880, u'display_url': u'pic.twitter.com/PoDO98Fp8x'}] | 21
[{u'expanded_url': u'http://twitter.com/TeezeeDRB/status/724904667696746497/photo/1', u'sizes': {u'small': {u'h': 453, u'resize': u'fit', u'w': 340}, u'large': {u'h': 1365, u'resize': u'fit', u'w': 1024}, u'medium': {u'h': 800, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/iyPVzSWZDk', u'media_url_https': u'https://pbs.twimg.com/media/Cg9g7vOWwAEyFUG.jpg', u'id_str': u'724904644435165185', u'indices': [61, 84], u'media_url': u'http://pbs.twimg.com/media/Cg9g7vOWwAEyFUG.jpg', u'type': u'photo', u'id': 724904644435165185, u'display_url': u'pic.twitter.com/iyPVzSWZDk'}] | 16
Other values (75) | 131
(Missing) | 97278

Toggle details

Value | Count | Frequency (%) |
[{u'expanded_url': u'http://twitter.com/ndtv/status/724601469408796673/photo/1', u'sizes': {u'small': {u'h': 209, u'resize': u'fit', u'w': 340}, u'large': {u'h': 400, u'resize': u'fit', u'w': 650}, u'medium': {u'h': 369, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/7eFucdjpmP', u'media_url_https': u'https://pbs.twimg.com/media/Cg5NMhUU4AAq5ig.jpg', u'id_str': u'724601467550621696', u'indices': [77, 100], u'media_url': u'http://pbs.twimg.com/media/Cg5NMhUU4AAq5ig.jpg', u'type': u'photo', u'id': 724601467550621696, u'display_url': u'pic.twitter.com/7eFucdjpmP'}] | 947 | 1.0% |
[{u'expanded_url': u'http://twitter.com/TomAugspurger/status/726445711202484224/photo/1', u'sizes': {u'small': {u'h': 170, u'resize': u'fit', u'w': 340}, u'large': {u'h': 432, u'resize': u'fit', u'w': 864}, u'medium': {u'h': 300, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/PoDO98Fp8x', u'media_url_https': u'https://pbs.twimg.com/media/ChTahiWU0AAmFuU.jpg', u'id_str': u'726445709604474880', u'indices': [58, 81], u'media_url': u'http://pbs.twimg.com/media/ChTahiWU0AAmFuU.jpg', u'type': u'photo', u'id': 726445709604474880, u'display_url': u'pic.twitter.com/PoDO98Fp8x'}] | 21 | 0.0% |
[{u'expanded_url': u'http://twitter.com/TeezeeDRB/status/724904667696746497/photo/1', u'sizes': {u'small': {u'h': 453, u'resize': u'fit', u'w': 340}, u'large': {u'h': 1365, u'resize': u'fit', u'w': 1024}, u'medium': {u'h': 800, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/iyPVzSWZDk', u'media_url_https': u'https://pbs.twimg.com/media/Cg9g7vOWwAEyFUG.jpg', u'id_str': u'724904644435165185', u'indices': [61, 84], u'media_url': u'http://pbs.twimg.com/media/Cg9g7vOWwAEyFUG.jpg', u'type': u'photo', u'id': 724904644435165185, u'display_url': u'pic.twitter.com/iyPVzSWZDk'}] | 16 | 0.0% |
[{u'expanded_url': u'http://twitter.com/OReillyMedia/status/727453108490637312/photo/1', u'sizes': {u'small': {u'h': 192, u'resize': u'fit', u'w': 340}, u'large': {u'h': 512, u'resize': u'fit', u'w': 908}, u'medium': {u'h': 338, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/RHONj9PXGw', u'media_url_https': u'https://pbs.twimg.com/media/Chhuv1zUkAEENxz.jpg', u'id_str': u'727453107995578369', u'indices': [120, 143], u'media_url': u'http://pbs.twimg.com/media/Chhuv1zUkAEENxz.jpg', u'type': u'photo', u'id': 727453107995578369, u'display_url': u'pic.twitter.com/RHONj9PXGw'}] | 11 | 0.0% |
[{u'expanded_url': u'http://twitter.com/CodeFirstGirls/status/719824658560905216/photo/1', u'sizes': {u'small': {u'h': 268, u'resize': u'fit', u'w': 340}, u'large': {u'h': 808, u'resize': u'fit', u'w': 1024}, u'medium': {u'h': 473, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/0DanixM4FH', u'media_url_https': u'https://pbs.twimg.com/media/Cf1UtkeUkAAsSAG.jpg', u'id_str': u'719824657310846976', u'indices': [119, 142], u'media_url': u'http://pbs.twimg.com/media/Cf1UtkeUkAAsSAG.jpg', u'type': u'photo', u'id': 719824657310846976, u'display_url': u'pic.twitter.com/0DanixM4FH'}] | 7 | 0.0% |
[{u'expanded_url': u'http://twitter.com/welchlabs/status/721058802062266368/photo/1', u'sizes': {u'small': {u'h': 191, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 577, u'w': 1024, u'resize': u'fit'}, u'medium': {u'h': 338, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'url': u'https://t.co/HOenulFPUi', u'media_url_https': u'https://pbs.twimg.com/media/CgG3KMlWQAAkQPQ.jpg', u'id_str': u'721058801160437760', u'indices': [68, 91], u'media_url': u'http://pbs.twimg.com/media/CgG3KMlWQAAkQPQ.jpg', u'type': u'photo', u'id': 721058801160437760, u'display_url': u'pic.twitter.com/HOenulFPUi'}] | 5 | 0.0% |
[{u'expanded_url': u'http://twitter.com/joy2131_/status/722072235272482816/photo/1', u'sizes': {u'large': {u'h': 1024, u'w': 696, u'resize': u'fit'}, u'small': {u'h': 500, u'w': 340, u'resize': u'fit'}, u'medium': {u'h': 883, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'url': u'https://t.co/dduSMWoMyR', u'media_url_https': u'https://pbs.twimg.com/media/CgVQzmTXEAEMIJu.jpg', u'id_str': u'722072162648133633', u'indices': [106, 129], u'media_url': u'http://pbs.twimg.com/media/CgVQzmTXEAEMIJu.jpg', u'type': u'photo', u'id': 722072162648133633, u'display_url': u'pic.twitter.com/dduSMWoMyR'}] | 5 | 0.0% |
[{u'source_user_id': 816825631, u'source_status_id_str': u'690261906226020352', u'expanded_url': u'http://twitter.com/dataiku/status/690261906226020352/photo/1', u'sizes': {u'small': {u'h': 271, u'resize': u'fit', u'w': 340}, u'large': {u'h': 395, u'resize': u'fit', u'w': 495}, u'medium': {u'h': 395, u'resize': u'fit', u'w': 495}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/s9xk7ZjBVt', u'media_url_https': u'https://pbs.twimg.com/media/CZRNi-dWkAAy4r-.jpg', u'source_user_id_str': u'816825631', u'source_status_id': 690261906226020352, u'id_str': u'690261906171531264', u'indices': [109, 132], u'media_url': u'http://pbs.twimg.com/media/CZRNi-dWkAAy4r-.jpg', u'type': u'photo', u'id': 690261906171531264, u'display_url': u'pic.twitter.com/s9xk7ZjBVt'}] | 4 | 0.0% |
[{u'expanded_url': u'http://twitter.com/hoeroins/status/724213928100659200/photo/1', u'sizes': {u'small': {u'h': 453, u'resize': u'fit', u'w': 340}, u'large': {u'h': 960, u'resize': u'fit', u'w': 720}, u'medium': {u'h': 800, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/nFjM5X1Imi', u'media_url_https': u'https://pbs.twimg.com/media/Cgzst6eUkAAgkXS.jpg', u'id_str': u'724213913634508800', u'indices': [72, 95], u'media_url': u'http://pbs.twimg.com/media/Cgzst6eUkAAgkXS.jpg', u'type': u'photo', u'id': 724213913634508800, u'display_url': u'pic.twitter.com/nFjM5X1Imi'}] | 4 | 0.0% |
[{u'expanded_url': u'http://twitter.com/alobbs/status/724987233019654144/photo/1', u'sizes': {u'small': {u'h': 191, u'resize': u'fit', u'w': 340}, u'large': {u'h': 576, u'resize': u'fit', u'w': 1024}, u'medium': {u'h': 338, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/slpYLDyMRA', u'media_url_https': u'https://pbs.twimg.com/media/Cg-sCTGUYAENGba.jpg', u'id_str': u'724987220516429825', u'indices': [113, 136], u'media_url': u'http://pbs.twimg.com/media/Cg-sCTGUYAENGba.jpg', u'type': u'photo', u'id': 724987220516429825, u'display_url': u'pic.twitter.com/slpYLDyMRA'}] | 4 | 0.0% |
[{u'expanded_url': u'http://twitter.com/FlippinKath/status/726428505630756864/photo/1', u'sizes': {u'small': {u'h': 254, u'resize': u'fit', u'w': 340}, u'large': {u'h': 273, u'resize': u'fit', u'w': 365}, u'medium': {u'h': 273, u'resize': u'fit', u'w': 365}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/X8IRRmQPgT', u'media_url_https': u'https://pbs.twimg.com/media/ChTK3erW0AAap29.jpg', u'id_str': u'726428494390022144', u'indices': [18, 41], u'media_url': u'http://pbs.twimg.com/media/ChTK3erW0AAap29.jpg', u'type': u'photo', u'id': 726428494390022144, u'display_url': u'pic.twitter.com/X8IRRmQPgT'}] | 4 | 0.0% |
[{u'expanded_url': u'http://twitter.com/jcolantonio/status/725349529562787840/photo/1', u'sizes': {u'small': {u'h': 169, u'resize': u'fit', u'w': 340}, u'large': {u'h': 292, u'resize': u'fit', u'w': 588}, u'medium': {u'h': 292, u'resize': u'fit', u'w': 588}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/AJFrJoA4YZ', u'media_url_https': u'https://pbs.twimg.com/media/ChD1jahUgAIsx6I.jpg', u'id_str': u'725349528769953794', u'indices': [116, 139], u'media_url': u'http://pbs.twimg.com/media/ChD1jahUgAIsx6I.jpg', u'type': u'photo', u'id': 725349528769953794, u'display_url': u'pic.twitter.com/AJFrJoA4YZ'}] | 4 | 0.0% |
[{u'expanded_url': u'http://twitter.com/clxrityy/status/723834428032733184/photo/1', u'sizes': {u'large': {u'h': 960, u'w': 720, u'resize': u'fit'}, u'small': {u'h': 453, u'w': 340, u'resize': u'fit'}, u'medium': {u'h': 800, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'url': u'https://t.co/2HE2kCs4jV', u'media_url_https': u'https://pbs.twimg.com/media/CguTjsBWYAAGqnH.jpg', u'id_str': u'723834406444621824', u'indices': [99, 122], u'media_url': u'http://pbs.twimg.com/media/CguTjsBWYAAGqnH.jpg', u'type': u'photo', u'id': 723834406444621824, u'display_url': u'pic.twitter.com/2HE2kCs4jV'}] | 3 | 0.0% |
[{u'expanded_url': u'http://twitter.com/Raspberry_Pi/status/721738973668843524/photo/1', u'sizes': {u'large': {u'h': 768, u'w': 1024, u'resize': u'fit'}, u'small': {u'h': 255, u'w': 340, u'resize': u'fit'}, u'medium': {u'h': 450, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'url': u'https://t.co/gWszyMYMvC', u'media_url_https': u'https://pbs.twimg.com/media/CgQhu84WcAEBfhC.jpg', u'id_str': u'721738930786299905', u'indices': [106, 129], u'media_url': u'http://pbs.twimg.com/media/CgQhu84WcAEBfhC.jpg', u'type': u'photo', u'id': 721738930786299905, u'display_url': u'pic.twitter.com/gWszyMYMvC'}] | 3 | 0.0% |
[{u'expanded_url': u'http://twitter.com/SchoolPiClub/status/727204341501857794/photo/1', u'sizes': {u'small': {u'h': 255, u'resize': u'fit', u'w': 340}, u'large': {u'h': 768, u'resize': u'fit', u'w': 1024}, u'medium': {u'h': 450, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/XPBcemXbVP', u'media_url_https': u'https://pbs.twimg.com/media/CheMe1HWwAAbIzc.jpg', u'id_str': u'727204326125518848', u'indices': [65, 88], u'media_url': u'http://pbs.twimg.com/media/CheMe1HWwAAbIzc.jpg', u'type': u'photo', u'id': 727204326125518848, u'display_url': u'pic.twitter.com/XPBcemXbVP'}] | 3 | 0.0% |
[{u'source_user_id': 18406335, u'source_status_id_str': u'692714858467426304', u'expanded_url': u'http://twitter.com/dogvile/status/692714858467426304/photo/1', u'display_url': u'pic.twitter.com/wHhbsHvl6O', u'url': u'https://t.co/wHhbsHvl6O', u'media_url_https': u'https://pbs.twimg.com/media/CZ0EfecXEAAucil.jpg', u'source_user_id_str': u'18406335', u'source_status_id': 692714858467426304, u'id_str': u'692714856479395840', u'sizes': {u'small': {u'h': 255, u'w': 340, u'resize': u'fit'}, u'large': {u'h': 465, u'w': 620, u'resize': u'fit'}, u'medium': {u'h': 450, u'w': 600, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'indices': [97, 120], u'type': u'photo', u'id': 692714856479395840, u'media_url': u'http://pbs.twimg.com/media/CZ0EfecXEAAucil.jpg'}] | 3 | 0.0% |
[{u'expanded_url': u'http://twitter.com/circuitStatic/status/725713767498043392/photo/1', u'sizes': {u'small': {u'h': 103, u'resize': u'fit', u'w': 340}, u'large': {u'h': 122, u'resize': u'fit', u'w': 401}, u'medium': {u'h': 122, u'resize': u'fit', u'w': 401}, u'thumb': {u'h': 122, u'resize': u'crop', u'w': 122}}, u'url': u'https://t.co/YKcqLeYpL8', u'media_url_https': u'https://pbs.twimg.com/media/ChJAy_2VEAEmjEI.jpg', u'id_str': u'725713734837014529', u'indices': [111, 134], u'media_url': u'http://pbs.twimg.com/media/ChJAy_2VEAEmjEI.jpg', u'type': u'photo', u'id': 725713734837014529, u'display_url': u'pic.twitter.com/YKcqLeYpL8'}] | 2 | 0.0% |
[{u'expanded_url': u'http://twitter.com/moTik/status/725217117822279680/photo/1', u'sizes': {u'small': {u'h': 255, u'resize': u'fit', u'w': 340}, u'large': {u'h': 768, u'resize': u'fit', u'w': 1024}, u'medium': {u'h': 450, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/IaDgSxgNpq', u'media_url_https': u'https://pbs.twimg.com/media/ChB9HJwUUAA4r52.jpg', u'id_str': u'725217101837783040', u'indices': [125, 148], u'media_url': u'http://pbs.twimg.com/media/ChB9HJwUUAA4r52.jpg', u'type': u'photo', u'id': 725217101837783040, u'display_url': u'pic.twitter.com/IaDgSxgNpq'}] | 2 | 0.0% |
[{u'expanded_url': u'http://twitter.com/Perez_Elem_Lib/status/725722005639585792/photo/1', u'sizes': {u'small': {u'h': 255, u'resize': u'fit', u'w': 340}, u'large': {u'h': 480, u'resize': u'fit', u'w': 640}, u'medium': {u'h': 450, u'resize': u'fit', u'w': 600}, u'thumb': {u'h': 150, u'resize': u'crop', u'w': 150}}, u'url': u'https://t.co/qSsAQXMo1l', u'media_url_https': u'https://pbs.twimg.com/media/ChJIUYwU4AEdFor.jpg', u'id_str': u'725722005039800321', u'indices': [113, 136], u'media_url': u'http://pbs.twimg.com/media/ChJIUYwU4AEdFor.jpg', u'type': u'photo', u'id': 725722005039800321, u'display_url': u'pic.twitter.com/qSsAQXMo1l'}] | 2 | 0.0% |
[{u'expanded_url': u'http://twitter.com/ubuntu/status/723187759616237568/photo/1', u'sizes': {u'large': {u'h': 310, u'w': 300, u'resize': u'fit'}, u'small': {u'h': 310, u'w': 300, u'resize': u'fit'}, u'medium': {u'h': 310, u'w': 300, u'resize': u'fit'}, u'thumb': {u'h': 150, u'w': 150, u'resize': u'crop'}}, u'url': u'https://t.co/gKCYTcgY3P', u'media_url_https': u'https://pbs.twimg.com/media/CglHb1HWkAA7aOD.png', u'id_str': u'723187758609633280', u'indices': [116, 139], u'media_url': u'http://pbs.twimg.com/media/CglHb1HWkAA7aOD.png', u'type': u'photo', u'id': 723187758609633280, u'display_url': u'pic.twitter.com/gKCYTcgY3P'}] | 2 | 0.0% |
Other values (58) | 63 | 0.1% |
(Missing) | 97278 | 98.9% |

retweeted_status_quoted_status_entities_symbols
Categorical

Distinct count | 2
Unique (%) | 0.1%
Missing (%) | 98.6%
Missing (n) | 96981

[] | 1412
(Missing) | 96981

Toggle details

Value | Count | Frequency (%) |
[] | 1412 | 1.4% |
(Missing) | 96981 | 98.6% |

retweeted_status_quoted_status_entities_urls
Categorical

Distinct count | 123
Unique (%) | 8.7%
Missing (%) | 98.6%
Missing (n) | 96981

[{u'url': u'https://t.co/LYew7hBvJA', u'indices': [53, 76], u'expanded_url': u'http://www.ndtv.com/india-news/iits-have-been-asked-to-teach-sanskrit-smriti-irani-1399289', u'display_url': u'ndtv.com/india-news/iit\xe2\x80\xa6'}] | 947
[] | 199
[{u'url': u'https://t.co/Zjn0h9cvTy', u'indices': [34, 57], u'expanded_url': u'http://tomaugspurger.github.io/modern-6-visualization.html', u'display_url': u'tomaugspurger.github.io/modern-6-visua\xe2\x80\xa6'}] | 21
Other values (119) | 245
(Missing) | 96981

Toggle details

Value | Count | Frequency (%) |
[{u'url': u'https://t.co/LYew7hBvJA', u'indices': [53, 76], u'expanded_url': u'http://www.ndtv.com/india-news/iits-have-been-asked-to-teach-sanskrit-smriti-irani-1399289', u'display_url': u'ndtv.com/india-news/iit\xe2\x80\xa6'}] | 947 | 1.0% |
[] | 199 | 0.2% |
[{u'url': u'https://t.co/Zjn0h9cvTy', u'indices': [34, 57], u'expanded_url': u'http://tomaugspurger.github.io/modern-6-visualization.html', u'display_url': u'tomaugspurger.github.io/modern-6-visua\xe2\x80\xa6'}] | 21 | 0.0% |
[{u'url': u'https://t.co/YPYGJjzFUK', u'indices': [84, 107], u'expanded_url': u'http://oreil.ly/DRM-FREE-2016', u'display_url': u'oreil.ly/DRM-FREE-2016'}] | 11 | 0.0% |
[{u'indices': [85, 108], u'url': u'https://t.co/MvsN1vwgXC', u'expanded_url': u'http://md.ekstrandom.net/blog/2016/04/using-r/', u'display_url': u'md.ekstrandom.net/blog/2016/04/u\xe2\x80\xa6'}] | 9 | 0.0% |
[{u'url': u'https://t.co/zJrYoOTkQx', u'indices': [51, 74], u'expanded_url': u'http://wesmckinney.com/blog/conda-forge-centos-moment/', u'display_url': u'wesmckinney.com/blog/conda-for\xe2\x80\xa6'}] | 9 | 0.0% |
[{u'indices': [99, 122], u'url': u'https://t.co/m3SkZoGNUQ', u'expanded_url': u'http://register.automatingosint.com/python-course/', u'display_url': u'register.automatingosint.com/python-course/'}] | 8 | 0.0% |
[{u'url': u'https://t.co/mIbtYxQ7Sq', u'indices': [95, 118], u'expanded_url': u'http://bit.ly/1SvvXIp', u'display_url': u'bit.ly/1SvvXIp'}] | 7 | 0.0% |
[{u'url': u'https://t.co/YrEJJSfalx', u'indices': [65, 88], u'expanded_url': u'http://bit.ly/1WDB4fl', u'display_url': u'bit.ly/1WDB4fl'}] | 6 | 0.0% |
[{u'url': u'https://t.co/VhPK7UrA3Y', u'indices': [105, 128], u'expanded_url': u'https://training.talkpython.fm/courses/details/python-language-jumpstart-building-10-apps', u'display_url': u'training.talkpython.fm/courses/detail\xe2\x80\xa6'}] | 6 | 0.0% |
[{u'url': u'https://t.co/vyzhKgcXG6', u'indices': [70, 93], u'expanded_url': u'http://www.computerworld.com/article/3047642/big-data/hottest-job-data-scientists-say-theyre-still-mostly-digital-janitors.html', u'display_url': u'computerworld.com/article/304764\xe2\x80\xa6'}] | 6 | 0.0% |
[{u'url': u'https://t.co/YQ3C1OivjK', u'indices': [43, 66], u'expanded_url': u'http://geekforbrains.com/post/after-a-year-of-nodejs-in-production', u'display_url': u'geekforbrains.com/post/after-a-y\xe2\x80\xa6'}] | 6 | 0.0% |
[{u'url': u'https://t.co/4Tdagcszbx', u'indices': [117, 140], u'expanded_url': u'http://j.mp/1YQKhQi', u'display_url': u'j.mp/1YQKhQi'}] | 5 | 0.0% |
[{u'url': u'https://t.co/6Em1jt1r4u', u'indices': [37, 60], u'expanded_url': u'http://nbviewer.jupyter.org/url/norvig.com/ipython/WWW.ipynb', u'display_url': u'nbviewer.jupyter.org/url/norvig.com\xe2\x80\xa6'}] | 5 | 0.0% |
[{u'url': u'https://t.co/k9FFfIMZBN', u'indices': [105, 128], u'expanded_url': u'https://lab.beakernotebook.com', u'display_url': u'lab.beakernotebook.com'}] | 5 | 0.0% |
[{u'url': u'https://t.co/ALKvFicSyT', u'indices': [65, 88], u'expanded_url': u'http://buff.ly/1SYputP', u'display_url': u'buff.ly/1SYputP'}] | 4 | 0.0% |
[{u'url': u'https://t.co/nAqfmbGLjY', u'indices': [77, 100], u'expanded_url': u'http://bit.ly/243dSwT', u'display_url': u'bit.ly/243dSwT'}] | 4 | 0.0% |
[{u'url': u'https://t.co/OTvZ3nS9E0', u'indices': [46, 69], u'expanded_url': u'http://www.thedevmasters.com/data-visualization-python/', u'display_url': u'thedevmasters.com/data-visualiza\xe2\x80\xa6'}] | 4 | 0.0% |
[{u'indices': [27, 50], u'url': u'https://t.co/svG21njHVx', u'expanded_url': u'http://www.gnu.org/software/8sync/news/8sync-01-released.html', u'display_url': u'gnu.org/software/8sync\xe2\x80\xa6'}, {u'indices': [66, 89], u'url': u'https://t.co/CklifL1LYN', u'expanded_url': u'http://www.gnu.org/software/8sync/news/hello-world.html', u'display_url': u'gnu.org/software/8sync\xe2\x80\xa6'}] | 4 | 0.0% |
[{u'url': u'https://t.co/enZjJ3RCvN', u'indices': [71, 94], u'expanded_url': u'https://www.linkedin.com/pulse/keras-neural-networks-win-nvidia-titan-x-abhishek-thakur', u'display_url': u'linkedin.com/pulse/keras-ne\xe2\x80\xa6'}] | 4 | 0.0% |
Other values (102) | 142 | 0.1% |
(Missing) | 96981 | 98.6% |

retweeted_status_quoted_status_entities_user_mentions
Categorical

Distinct count | 73
Unique (%) | 5.2%
Missing (%) | 98.6%
Missing (n) | 96983

[] | 1283
[{u'indices': [0, 7], u'screen_name': u'NWSSPC', u'id': 586909317, u'name': u'NWS SPC', u'id_str': u'586909317'}] | 7
[{u'indices': [18, 27], u'screen_name': u'PyGotham', u'id': 339550132, u'name': u'PyGotham', u'id_str': u'339550132'}] | 6
Other values (69) | 114
(Missing) | 96983

Toggle details

Value | Count | Frequency (%) |
[] | 1283 | 1.3% |
[{u'indices': [0, 7], u'screen_name': u'NWSSPC', u'id': 586909317, u'name': u'NWS SPC', u'id_str': u'586909317'}] | 7 | 0.0% |
[{u'indices': [18, 27], u'screen_name': u'PyGotham', u'id': 339550132, u'name': u'PyGotham', u'id_str': u'339550132'}] | 6 | 0.0% |
[{u'indices': [0, 14], u'id': 203332110, u'id_str': u'203332110', u'name': u'World Bank Data', u'screen_name': u'worldbankdata'}] | 6 | 0.0% |
[{u'indices': [10, 22], u'screen_name': u'tom_e_white', u'id': 28835645, u'name': u'Tom White', u'id_str': u'28835645'}] | 5 | 0.0% |
[{u'indices': [53, 68], u'id_str': u'38420029', u'screen_name': u'ruudGyaLouLou_', u'name': u'LouLou Davids2131', u'id': 38420029}, {u'indices': [69, 82], u'id_str': u'378627265', u'screen_name': u'official2131', u'name': u'#TOTOGEAR', u'id': 378627265}, {u'indices': [83, 95], u'id_str': u'599240412', u'screen_name': u'warninokine', u'name': u'Warnin Gee', u'id': 599240412}, {u'indices': [96, 105], u'id_str': u'1153684752', u'screen_name': u'sai_mary', u'name': u'troublesome _2131', u'id': 1153684752}] | 5 | 0.0% |
[{u'indices': [64, 80], u'id_str': u'2303751216', u'screen_name': u'FiveThirtyEight', u'name': u'FiveThirtyEight', u'id': 2303751216}, {u'indices': [81, 91], u'id_str': u'19434396', u'screen_name': u'docrostov', u'name': u'Aaron McGuire', u'id': 19434396}, {u'indices': [92, 101], u'id_str': u'77810367', u'screen_name': u'octonion', u'name': u'Christopher D. Long', u'id': 77810367}, {u'indices': [102, 113], u'id_str': u'237254045', u'screen_name': u'treycausey', u'name': u'Trey Causey', u'id': 237254045}] | 5 | 0.0% |
[{u'indices': [101, 115], u'screen_name': u'TechBeaconCom', u'id': 3014369394, u'name': u'TechBeacon', u'id_str': u'3014369394'}] | 4 | 0.0% |
[{u'indices': [0, 9], u'id_str': u'12953262', u'screen_name': u'mkennedy', u'name': u'Michael Kennedy', u'id': 12953262}] | 4 | 0.0% |
[{u'indices': [0, 15], u'screen_name': u'all_about_code', u'id': 2859474053, u'name': u'All About Code', u'id_str': u'2859474053'}] | 3 | 0.0% |
[{u'indices': [0, 11], u'screen_name': u'iMargo_CEO', u'id': 25163104, u'name': u'Gladiator Goldwyn', u'id_str': u'25163104'}] | 3 | 0.0% |
[{u'indices': [3, 11], u'id_str': u'18406335', u'screen_name': u'dogvile', u'name': u'dogvile', u'id': 18406335}, {u'indices': [86, 96], u'id_str': u'15426758', u'screen_name': u'infoworld', u'name': u'InfoWorld', u'id': 15426758}] | 3 | 0.0% |
[{u'indices': [5, 17], u'screen_name': u'TheIronYard', u'id': 576311383, u'name': u'The Iron Yard', u'id_str': u'576311383'}] | 3 | 0.0% |
[{u'indices': [43, 49], u'screen_name': u'nylas', u'id': 1380814200, u'name': u'Nylas', u'id_str': u'1380814200'}] | 3 | 0.0% |
[{u'indices': [71, 83], u'id_str': u'112464786', u'screen_name': u'SASsoftware', u'name': u'SAS Software', u'id': 112464786}, {u'indices': [84, 97], u'id_str': u'103667704', u'screen_name': u'SASanalytics', u'name': u'SASanalytics', u'id': 103667704}, {u'indices': [98, 113], u'id_str': u'2460368252', u'screen_name': u'ProjectJupyter', u'name': u'Project Jupyter', u'id': 2460368252}] | 2 | 0.0% |
[{u'indices': [77, 84], u'screen_name': u'KSiutz', u'id': 2865036593, u'name': u'Kiya Siutz', u'id_str': u'2865036593'}, {u'indices': [91, 103], u'screen_name': u'_michael_av', u'id': 929055372, u'name': u'Michael', u'id_str': u'929055372'}] | 2 | 0.0% |
[{u'indices': [0, 15], u'screen_name': u'dominicfelix10', u'id': 594845061, u'name': u'Dominic Felix', u'id_str': u'594845061'}, {u'indices': [38, 53], u'screen_name': u'Abraham_Habtom', u'id': 1357774098, u'name': u'King TROUP', u'id_str': u'1357774098'}] | 2 | 0.0% |
[{u'indices': [20, 27], u'screen_name': u'MLconf', u'id': 544916703, u'name': u'MLconf', u'id_str': u'544916703'}] | 2 | 0.0% |
[{u'indices': [51, 64], u'screen_name': u'plotlygraphs', u'id': 1392826357, u'name': u'plotly', u'id_str': u'1392826357'}] | 2 | 0.0% |
[{u'indices': [0, 12], u'id_str': u'42499983', u'screen_name': u'AnneBillson', u'name': u'Anne Billson', u'id': 42499983}] | 2 | 0.0% |
Other values (52) | 58 | 0.1% |
(Missing) | 96983 | 98.6% |

retweeted_status_quoted_status_favorite_count
Numeric

Distinct count | 75
Unique (%) | 5.3%
Missing (%) | 98.6%
Missing (n) | 96981

Mean | 128.68
Minimum | 0
Maximum | 22699
Zeros (%) | 0.1%

Toggle details

Quantile statistics

Minimum | 0
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 22699
Range | 22699
Interquartile range |

Descriptive statistics

Standard deviation | 641.99
Coef of variation | 4.9892
Kurtosis | 1088.9
Mean | 128.68
MAD | 81.047
Skewness | 31.483
Sum | 181690
Variance | 412150
Memory size | 768.8 KiB

retweeted_status_quoted_status_favorited
Categorical

Distinct count | 2
Unique (%) | 0.1%
Missing (%) | 98.6%
Missing (n) | 96981

False | 1412
(Missing) | 96981

Toggle details

Value | Count | Frequency (%) |
False | 1412 | 1.4% |
(Missing) | 96981 | 98.6% |

retweeted_status_quoted_status_id
Numeric

Distinct count | 220
Unique (%) | 0.2%
Missing (%) | 1.1%
Missing (n) | 1110

Mean | 1.055e+16
Minimum | -1
Maximum | 7.2751e+17
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | -1
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 7.2751e+17
Range | 7.2751e+17
Interquartile range |

Descriptive statistics

Standard deviation | 8.6744e+16
Coef of variation | 8.2225
Kurtosis | 63.637
Mean | 1.055e+16
MAD | 2.0792e+16
Skewness | 8.1014
Sum | 1.0263e+21
Variance | 7.5246e+33
Memory size | 768.8 KiB

retweeted_status_quoted_status_id_str
Highly correlated

This variable is highly correlated with `retweeted_status_quoted_status_id` and should be ignored for analysis

Correlation | 1

retweeted_status_quoted_status_is_quote_status
Categorical

Distinct count | 3
Unique (%) | 0.2%
Missing (%) | 98.6%
Missing (n) | 96981

False | 1400
True | 12
(Missing) | 96981

Toggle details

Value | Count | Frequency (%) |
False | 1400 | 1.4% |
True | 12 | 0.0% |
(Missing) | 96981 | 98.6% |

retweeted_status_quoted_status_lang
Categorical

Distinct count | 7
Unique (%) | 0.5%
Missing (%) | 98.6%
Missing (n) | 96981

en | 1396
und | 7
ro | 4
Other values (3) | 5
(Missing) | 96981

Toggle details

Value | Count | Frequency (%) |
en | 1396 | 1.4% |
und | 7 | 0.0% |
ro | 4 | 0.0% |
tl | 2 | 0.0% |
in | 2 | 0.0% |
uk | 1 | 0.0% |
(Missing) | 96981 | 98.6% |

retweeted_status_quoted_status_metadata_iso_language_code
Categorical

Distinct count | 2
Unique (%) | 0.1%
Missing (%) | 98.6%
Missing (n) | 96981

en | 1412
(Missing) | 96981

Toggle details

Value | Count | Frequency (%) |
en | 1412 | 1.4% |
(Missing) | 96981 | 98.6% |

retweeted_status_quoted_status_metadata_result_type
Categorical

Distinct count | 2
Unique (%) | 0.1%
Missing (%) | 98.6%
Missing (n) | 96981

recent | 1412
(Missing) | 96981

Toggle details

Value | Count | Frequency (%) |
recent | 1412 | 1.4% |
(Missing) | 96981 | 98.6% |

retweeted_status_quoted_status_place_bounding_box_coordinates
Categorical

Distinct count | 12
Unique (%) | 1.2%
Missing (%) | 99.0%
Missing (n) | 97425

[[[76.84252, 28.397657], [77.347652, 28.397657], [77.347652, 28.879322], [76.84252, 28.879322]]] | 947
[[[-46.702073, -23.626481], [-46.6686213, -23.626481], [-46.6686213, -23.576938], [-46.702073, -23.576938]]] | 5
[[[-97.740086, 30.263577], [-97.740086, 30.263577], [-97.740086, 30.263577], [-97.740086, 30.263577]]] | 4
Other values (8) | 12
(Missing) | 97425

Toggle details

Value | Count | Frequency (%) |
[[[76.84252, 28.397657], [77.347652, 28.397657], [77.347652, 28.879322], [76.84252, 28.879322]]] | 947 | 1.0% |
[[[-46.702073, -23.626481], [-46.6686213, -23.626481], [-46.6686213, -23.576938], [-46.702073, -23.576938]]] | 5 | 0.0% |
[[[-97.740086, 30.263577], [-97.740086, 30.263577], [-97.740086, 30.263577], [-97.740086, 30.263577]]] | 4 | 0.0% |
[[[-77.02294335, 38.9041435719], [-77.02294335, 38.9041435719], [-77.02294335, 38.9041435719], [-77.02294335, 38.9041435719]]] | 3 | 0.0% |
[[[101.7311096, 3.1498865], [101.8491089, 3.1498865], [101.8491089, 3.2976676], [101.7311096, 3.2976676]]] | 2 | 0.0% |
[[[151.20053784, -33.84515403], [151.21862784, -33.84515403], [151.21862784, -33.82808004], [151.20053784, -33.82808004]]] | 2 | 0.0% |
[[[-80.297165, 25.627038], [-80.245009, 25.627038], [-80.245009, 25.771859], [-80.297165, 25.771859]]] | 1 | 0.0% |
[[[-122.077393234, 37.414524681], [-122.077393234, 37.414524681], [-122.077393234, 37.414524681], [-122.077393234, 37.414524681]]] | 1 | 0.0% |
[[[-95.608956, 33.626723], [-95.487483, 33.626723], [-95.487483, 33.701138], [-95.608956, 33.701138]]] | 1 | 0.0% |
[[[-122.7900653, 45.421863], [-122.471751, 45.421863], [-122.471751, 45.6509405], [-122.7900653, 45.6509405]]] | 1 | 0.0% |
[[[22.1357201, 44.386383], [40.227172, 44.386383], [40.227172, 52.379475], [22.1357201, 52.379475]]] | 1 | 0.0% |
(Missing) | 97425 | 99.0% |

retweeted_status_quoted_status_place_bounding_box_type
Categorical

Distinct count | 2
Unique (%) | 0.2%
Missing (%) | 99.0%
Missing (n) | 97425

Polygon | 968
(Missing) | 97425

Toggle details

Value | Count | Frequency (%) |
Polygon | 968 | 1.0% |
(Missing) | 97425 | 99.0% |

retweeted_status_quoted_status_place_contained_within
Categorical

Distinct count | 2
Unique (%) | 0.2%
Missing (%) | 99.0%
Missing (n) | 97425

[] | 968
(Missing) | 97425

Toggle details

Value | Count | Frequency (%) |
[] | 968 | 1.0% |
(Missing) | 97425 | 99.0% |

retweeted_status_quoted_status_place_country
Categorical

Distinct count | 7
Unique (%) | 0.7%
Missing (%) | 99.0%
Missing (n) | 97425

'\xe0\xa4\xad\xe0\xa4\xbe\xe0\xa4\xb0\xe0\xa4\xa4' | 947
United States | 11
Brasil | 5
Other values (3) | 5
(Missing) | 97425

Toggle details

Value | Count | Frequency (%) |
'\xe0\xa4\xad\xe0\xa4\xbe\xe0\xa4\xb0\xe0\xa4\xa4' | 947 | 1.0% |
United States | 11 | 0.0% |
Brasil | 5 | 0.0% |
Malaysia | 2 | 0.0% |
Australia | 2 | 0.0% |
'\xd0\xa3\xd0\xba\xd1\x80\xd0\xb0\xd1\x97\xd0\xbd\xd0\xb0' | 1 | 0.0% |
(Missing) | 97425 | 99.0% |

retweeted_status_quoted_status_place_country_code
Categorical

Distinct count | 7
Unique (%) | 0.7%
Missing (%) | 99.0%
Missing (n) | 97425

IN | 947
US | 11
BR | 5
Other values (3) | 5
(Missing) | 97425

Toggle details

Value | Count | Frequency (%) |
IN | 947 | 1.0% |
US | 11 | 0.0% |
BR | 5 | 0.0% |
AU | 2 | 0.0% |
MY | 2 | 0.0% |
UA | 1 | 0.0% |
(Missing) | 97425 | 99.0% |

retweeted_status_quoted_status_place_full_name
Categorical

Distinct count | 11
Unique (%) | 1.1%
Missing (%) | 99.0%
Missing (n) | 97430

New Delhi, India | 947
Austin Convention Center | 4
Walter E. Washington Convention Center | 3
Other values (7) | 9
(Missing) | 97430

Toggle details

Value | Count | Frequency (%) |
New Delhi, India | 947 | 1.0% |
Austin Convention Center | 4 | 0.0% |
Walter E. Washington Convention Center | 3 | 0.0% |
North Sydney, Sydney | 2 | 0.0% |
Ulu Kelang, Selangor | 2 | 0.0% |
Portland, OR | 1 | 0.0% |
Coral Gables, FL | 1 | 0.0% |
Paris, TX | 1 | 0.0% |
Ukraine | 1 | 0.0% |
Computer History Museum | 1 | 0.0% |
(Missing) | 97430 | 99.0% |

retweeted_status_quoted_status_place_id
Categorical

Distinct count | 12
Unique (%) | 1.2%
Missing (%) | 99.0%
Missing (n) | 97425

317fcc4b21a604d5 | 947
5e6560355f7dfe0d | 5
07d9e38710082001 | 4
Other values (8) | 12
(Missing) | 97425

Toggle details

Value | Count | Frequency (%) |
317fcc4b21a604d5 | 947 | 1.0% |
5e6560355f7dfe0d | 5 | 0.0% |
07d9e38710082001 | 4 | 0.0% |
07d9e3a18b488000 | 3 | 0.0% |
cb6912ca33266c43 | 2 | 0.0% |
1f7cbf27412413af | 2 | 0.0% |
603d21ec6e733f7f | 1 | 0.0% |
084d0d0155787e9d | 1 | 0.0% |
07d9c9346c081000 | 1 | 0.0% |
ac88a4f17a51c7fc | 1 | 0.0% |
778af41ffb719450 | 1 | 0.0% |
(Missing) | 97425 | 99.0% |

retweeted_status_quoted_status_place_name
Categorical

Distinct count | 12
Unique (%) | 1.2%
Missing (%) | 99.0%
Missing (n) | 97425

New Delhi | 947
Itaim Bibi | 5
Austin Convention Center | 4
Other values (8) | 12
(Missing) | 97425

Toggle details

Value | Count | Frequency (%) |
New Delhi | 947 | 1.0% |
Itaim Bibi | 5 | 0.0% |
Austin Convention Center | 4 | 0.0% |
Walter E. Washington Convention Center | 3 | 0.0% |
Ulu Kelang | 2 | 0.0% |
North Sydney | 2 | 0.0% |
Portland | 1 | 0.0% |
Paris | 1 | 0.0% |
Ukraine | 1 | 0.0% |
Coral Gables | 1 | 0.0% |
Computer History Museum | 1 | 0.0% |
(Missing) | 97425 | 99.0% |

retweeted_status_quoted_status_place_place_type
Categorical

Distinct count | 5
Unique (%) | 0.5%
Missing (%) | 99.0%
Missing (n) | 97425

city | 952
poi | 8
neighborhood | 7
(Missing) | 97425

Toggle details

Value | Count | Frequency (%) |
city | 952 | 1.0% |
poi | 8 | 0.0% |
neighborhood | 7 | 0.0% |
country | 1 | 0.0% |
(Missing) | 97425 | 99.0% |

retweeted_status_quoted_status_place_url
Categorical

Distinct count | 12
Unique (%) | 1.2%
Missing (%) | 99.0%
Missing (n) | 97425

https://api.twitter.com/1.1/geo/id/317fcc4b21a604d5.json | 947
https://api.twitter.com/1.1/geo/id/5e6560355f7dfe0d.json | 5
https://api.twitter.com/1.1/geo/id/07d9e38710082001.json | 4
Other values (8) | 12
(Missing) | 97425

Toggle details

Value | Count | Frequency (%) |
https://api.twitter.com/1.1/geo/id/317fcc4b21a604d5.json | 947 | 1.0% |
https://api.twitter.com/1.1/geo/id/5e6560355f7dfe0d.json | 5 | 0.0% |
https://api.twitter.com/1.1/geo/id/07d9e38710082001.json | 4 | 0.0% |
https://api.twitter.com/1.1/geo/id/07d9e3a18b488000.json | 3 | 0.0% |
https://api.twitter.com/1.1/geo/id/cb6912ca33266c43.json | 2 | 0.0% |
https://api.twitter.com/1.1/geo/id/1f7cbf27412413af.json | 2 | 0.0% |
https://api.twitter.com/1.1/geo/id/603d21ec6e733f7f.json | 1 | 0.0% |
https://api.twitter.com/1.1/geo/id/778af41ffb719450.json | 1 | 0.0% |
https://api.twitter.com/1.1/geo/id/084d0d0155787e9d.json | 1 | 0.0% |
https://api.twitter.com/1.1/geo/id/ac88a4f17a51c7fc.json | 1 | 0.0% |
https://api.twitter.com/1.1/geo/id/07d9c9346c081000.json | 1 | 0.0% |
(Missing) | 97425 | 99.0% |

retweeted_status_quoted_status_possibly_sensitive
Categorical

Distinct count | 3
Unique (%) | 0.2%
Missing (%) | 98.7%
Missing (n) | 97099

False | 1293
True | 1
(Missing) | 97099

Toggle details

Value | Count | Frequency (%) |
False | 1293 | 1.3% |
True | 1 | 0.0% |
(Missing) | 97099 | 98.7% |

retweeted_status_quoted_status_retweet_count
Highly correlated

This variable is highly correlated with `retweeted_status_quoted_status_favorite_count` and should be ignored for analysis

Correlation | 0.99487

retweeted_status_quoted_status_retweeted
Categorical

Distinct count | 2
Unique (%) | 0.1%
Missing (%) | 98.6%
Missing (n) | 96981

False | 1412
(Missing) | 96981

Toggle details

Value | Count | Frequency (%) |
False | 1412 | 1.4% |
(Missing) | 96981 | 98.6% |

retweeted_status_quoted_status_source
Categorical

Distinct count | 28
Unique (%) | 2.0%
Missing (%) | 98.6%
Missing (n) | 96981

Twitter Web Client | 1101
Twitter for iPhone | 88
TweetDeck | 47
Other values (24) | 176
(Missing) | 96981

Toggle details

Value | Count | Frequency (%) |
Twitter Web Client | 1101 | 1.1% |
Twitter for iPhone | 88 | 0.1% |
TweetDeck | 47 | 0.0% |
Tweetbot for Mac | 41 | 0.0% |
Twitter for Android | 35 | 0.0% |
Hootsuite | 30 | 0.0% |
Buffer | 25 | 0.0% |
Twitter for iPad | 6 | 0.0% |
Radian6 -Social Media Management | 5 | 0.0% |
IFTTT | 4 | 0.0% |
twitterfeed | 4 | 0.0% |
Sprout Social | 3 | 0.0% |
Data Pakistan | 3 | 0.0% |
newsycombinator | 3 | 0.0% |
WordPress.com | 3 | 0.0% |
Twitter for Mac | 2 | 0.0% |
Spredfast app | 2 | 0.0% |
Medium | 1 | 0.0% |
Sprinklr | 1 | 0.0% |
HubSpot | 1 | 0.0% |
Other values (7) | 7 | 0.0% |
(Missing) | 96981 | 98.6% |

retweeted_status_quoted_status_text
Categorical

Distinct count | 185
Unique (%) | 13.8%
Missing (%) | 98.6%
Missing (n) | 97055

IITs have been asked to teach Sanskrit: Smriti Irani https://t.co/LYew7hBvJA https://t.co/7eFucdjpmP | 947
Part 6, about data visualization: https://t.co/Zjn0h9cvTy https://t.co/PoDO98Fp8x | 21
One of my best mates at uni had a pet Python. They mad chill https://t.co/iyPVzSWZDk | 16
Other values (181) | 354
(Missing) | 97055

Toggle details

Value | Count | Frequency (%) |
IITs have been asked to teach Sanskrit: Smriti Irani https://t.co/LYew7hBvJA https://t.co/7eFucdjpmP | 947 | 1.0% |
Part 6, about data visualization: https://t.co/Zjn0h9cvTy https://t.co/PoDO98Fp8x | 21 | 0.0% |
One of my best mates at uni had a pet Python. They mad chill https://t.co/iyPVzSWZDk | 16 | 0.0% |
New post: "conda-forge and PyData's CentOS moment" https://t.co/zJrYoOTkQx #pydata | 11 | 0.0% |
I've been trying PyData the last 1-2 years, but will keep using #rstats for a while. https://t.co/MvsN1vwgXC | 10 | 0.0% |
Just released my #Python course. Short, to the point and primes you for learning Python for OSINT: https://t.co/m3SkZoGNUQ | 9 | 0.0% |
Want to learn #HTML #CSS & #Python this summer? Apply for our Summer Intensive course now! https://t.co/mIbtYxQ7Sq https://t.co/0DanixM4FH | 7 | 0.0% |
@NWSSPC #askSPC How can software developers help with weather software in the open source community? Do you use open source tech? | 7 | 0.0% |
@worldbankdata :) library("WDI") WDI(country = "ET", indicator = "SP.POP.TOTL", start = 2014, end = 2015, extra = FALSE, cache = NULL) | 6 | 0.0% |
There are still spots available for my #Python webinar tomorrow: https://t.co/YrEJJSfalx | 6 | 0.0% |
After a year of using NodeJS in production https://t.co/YQ3C1OivjK | 6 | 0.0% |
Data Scientists are you really just Data Janitors? #datascience #data https://t.co/vyzhKgcXG6 | 6 | 0.0% |
Is this the week you learn Python for real? Check out my new course Python Jumpstart by Building 10 Apps https://t.co/VhPK7UrA3Y | 6 | 0.0% |
Just submitted my @PyGotham talk proposal! | 6 | 0.0% |
NEW VIDEO!! Get excited for decision trees. https://t.co/UJqeOia6CW https://t.co/HOenulFPUi | 5 | 0.0% |
Learn why @tom_e_white's #Hadoop the Definitive Guide is listed as 1 of 10 books rec'd to boost your #bigdata career https://t.co/4Tdagcszbx | 5 | 0.0% |
Peter Norvig: Will the Warriors Win? https://t.co/6Em1jt1r4u cc @FiveThirtyEight @docrostov @octonion @treycausey | 5 | 0.0% |
Beaker Lab (alpha) has just been released. Now you can use Beaker directly in the cloud. Check it out at https://t.co/k9FFfIMZBN | 5 | 0.0% |
#2131wetandwild ROYAL SENCHI WHO IS READY 27/05/16 @ruudGyaLouLou_ @official2131 @warninokine @sai_mary https://t.co/dduSMWoMyR | 5 | 0.0% |
This is a belter. https://t.co/X8IRRmQPgT | 4 | 0.0% |
Other values (164) | 245 | 0.2% |
(Missing) | 97055 | 98.6% |

retweeted_status_quoted_status_truncated
Categorical

Distinct count | 2
Unique (%) | 0.1%
Missing (%) | 98.6%
Missing (n) | 96981

False | 1412
(Missing) | 96981

Toggle details

Value | Count | Frequency (%) |
False | 1412 | 1.4% |
(Missing) | 96981 | 98.6% |

retweeted_status_retweet_count
Highly correlated

This variable is highly correlated with `retweeted_status_favorite_count` and should be ignored for analysis

Correlation | 0.95171

retweeted_status_retweeted
Categorical

Distinct count | 2
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

False | 34564
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
False | 34564 | 35.1% |
(Missing) | 63829 | 64.9% |

retweeted_status_source
Categorical

Distinct count | 527
Unique (%) | 1.5%
Missing (%) | 65.1%
Missing (n) | 64013

Twitter Web Client | 8636
Hootsuite | 3408
Twitter for Android | 3403
Other values (523) | 18933
(Missing) | 64013

Toggle details

Value | Count | Frequency (%) |
Twitter Web Client | 8636 | 8.8% |
Hootsuite | 3408 | 3.5% |
Twitter for Android | 3403 | 3.5% |
Twitter for iPhone | 3349 | 3.4% |
Buffer | 3196 | 3.2% |
TweetDeck | 2342 | 2.4% |
IFTTT | 1507 | 1.5% |
dlvr.it | 548 | 0.6% |
twitterfeed | 449 | 0.5% |
Google | 410 | 0.4% |
Tweetbot for Mac | 336 | 0.3% |
Sprout Social | 327 | 0.3% |
Twitter for Mac | 319 | 0.3% |
VoiceStorm | 281 | 0.3% |
Python Trending | 258 | 0.3% |
Twitter for iPad | 252 | 0.3% |
jobfindly python jobs | 224 | 0.2% |
Facebook | 205 | 0.2% |
RightRelevanceTweetApp | 193 | 0.2% |
SocialFlow | 190 | 0.2% |
Other values (506) | 4547 | 4.6% |
(Missing) | 64013 | 65.1% |

retweeted_status_text
Categorical

Distinct count | 9940
Unique (%) | 32.2%
Missing (%) | 68.7%
Missing (n) | 67571

One should understand Sanskrit is the only language which can compete with C++, Java, SOL, Python, Javascript...1/2 https://t.co/QhYq3PcuZy | 944
All computers in India using languages like C+, Java, SOL, Python..should b declared antinational once IITians learn working in sanskrit.2/2 | 865
Rmbr d friendly python? Dis could've been of him (its not) Bt did V need to take a life? #CallOfTheWild #SaveTheWild https://t.co/uMhFFIHrbo | 308
Other values (9936) | 28705
(Missing) | 67571

Toggle details

Value | Count | Frequency (%) |
One should understand Sanskrit is the only language which can compete with C++, Java, SOL, Python, Javascript...1/2 https://t.co/QhYq3PcuZy | 944 | 1.0% |
All computers in India using languages like C+, Java, SOL, Python..should b declared antinational once IITians learn working in sanskrit.2/2 | 865 | 0.9% |
Rmbr d friendly python? Dis could've been of him (its not) Bt did V need to take a life? #CallOfTheWild #SaveTheWild https://t.co/uMhFFIHrbo | 308 | 0.3% |
#Google has started a new #Python #MachineLearning course on YouTube. #sklearn https://t.co/WDFEUdyrbS https://t.co/aoMntyJudr | 290 | 0.3% |
Big Snake Fight | Snake Fight Till Death | Cobra Vs Python Vs Anaconda https://t.co/m4576sRH5a | 220 | 0.2% |
Ubuntu 16.04 LTS released with #Python 3.5 as standard, rather than Python 2.7! Progress! https://t.co/0dEyFM6sVd https://t.co/sYkjvn7hzu | 171 | 0.2% |
Python Custom Yeezy 350 Boosts https://t.co/qpdP0DUKAu | 150 | 0.2% |
Microservices and Python | DevOpsSummit #DevOps #IoT #Microservices https://t.co/99ttVa37RC #Cloud | 145 | 0.1% |
Guy: *points at my shirt* there should be a semicolon at the end Me: it's Python | 133 | 0.1% |
How I defeated an obfuscated and anti-tamper APK with some Python and a home-made Smali emulator. https://t.co/qhwzvuhl1t | 111 | 0.1% |
Awesome Python : A curated list of awesome Python frameworks, packages, software and resources : https://t.co/IW0kXRWfom | 105 | 0.1% |
ICYMI: A simple Python script which will fetch credentials and list proxies for #Opera #VPN https://t.co/1kG77yMvJ2 https://t.co/y8YXIvM57S | 97 | 0.1% |
Today's #coloroftheday is High Risk Red. #TravelTuesday inspiration by Scarlet Starlet: https://t.co/mO4MqPAzTX https://t.co/BjAO7UXyj2 | 96 | 0.1% |
Calling all programmers! Challenge yourself w/ #Electricity4All challenge https://t.co/TLsTPzBGel via @UN_UniteIdeas https://t.co/Tn9trH2Nih | 95 | 0.1% |
The Zen of #Python, illustrated. #programming https://t.co/AebCARp3iO https://t.co/TRNOy1vJXi | 93 | 0.1% |
Great blogs to read | #Python #Psychology https://t.co/afz3mNeaif | 92 | 0.1% |
Why #MachineLearning with #Python is the best combination: https://t.co/hOdcRLTG0k #abdsc #BigData #DataScience https://t.co/TK8DqOw04E | 89 | 0.1% |
Useful #programming tutorial: Understanding #Python metaclasses. https://t.co/elmV7H8Hm8 https://t.co/IO7RTTiqWB | 84 | 0.1% |
Learn how to dig into all sorts of tech -- ranging from the Xbox to Arduino to Python to Bitcoin! https://t.co/F9WgHsGkgm | 84 | 0.1% |
New post from @_samdb_ on WinDbg scripting with python and Windows heap tracing https://t.co/msqJ775MbI https://t.co/8pcxzepzJX | 78 | 0.1% |
Other values (9919) | 26572 | 27.0% |
(Missing) | 67571 | 68.7% |

retweeted_status_truncated
Categorical

Distinct count | 2
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

False | 34564
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
False | 34564 | 35.1% |
(Missing) | 63829 | 64.9% |

retweeted_status_user_contributors_enabled
Categorical

Distinct count | 2
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

False | 34564
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
False | 34564 | 35.1% |
(Missing) | 63829 | 64.9% |

retweeted_status_user_created_at
Categorical

Distinct count | 6486
Unique (%) | 18.8%
Missing (%) | 64.9%
Missing (n) | 63829

Sat Apr 11 07:28:46 +0000 2009 | 1809
Sun Jun 21 20:13:18 +0000 2009 | 885
Fri Mar 23 16:35:17 +0000 2012 | 702
Other values (6482) | 31168
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
Sat Apr 11 07:28:46 +0000 2009 | 1809 | 1.8% |
Sun Jun 21 20:13:18 +0000 2009 | 885 | 0.9% |
Fri Mar 23 16:35:17 +0000 2012 | 702 | 0.7% |
Wed Mar 19 05:26:29 +0000 2008 | 661 | 0.7% |
Thu Feb 05 17:37:26 +0000 2009 | 481 | 0.5% |
Wed Sep 14 22:49:27 +0000 2011 | 362 | 0.4% |
Sat Jan 23 21:48:14 +0000 2016 | 308 | 0.3% |
Tue Aug 25 00:34:00 +0000 2015 | 263 | 0.3% |
Tue Apr 15 18:21:07 +0000 2014 | 258 | 0.3% |
Fri Mar 06 17:16:03 +0000 2009 | 252 | 0.3% |
Wed Dec 23 16:22:14 +0000 2015 | 224 | 0.2% |
Fri Apr 01 14:02:16 +0000 2016 | 220 | 0.2% |
Wed Feb 04 22:35:11 +0000 2015 | 200 | 0.2% |
Mon May 28 23:01:25 +0000 2012 | 194 | 0.2% |
Thu Oct 21 17:45:18 +0000 2010 | 193 | 0.2% |
Thu Nov 20 02:03:11 +0000 2014 | 188 | 0.2% |
Tue Aug 14 15:34:21 +0000 2012 | 176 | 0.2% |
Tue Jun 01 22:38:53 +0000 2010 | 173 | 0.2% |
Fri Jan 28 00:45:00 +0000 2011 | 170 | 0.2% |
Sun Feb 20 01:07:23 +0000 2011 | 165 | 0.2% |
Other values (6465) | 26680 | 27.1% |
(Missing) | 63829 | 64.9% |

retweeted_status_user_default_profile
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

False | 23067
True | 11497
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
False | 23067 | 23.4% |
True | 11497 | 11.7% |
(Missing) | 63829 | 64.9% |

retweeted_status_user_default_profile_image
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

False | 34354
True | 210
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
False | 34354 | 34.9% |
True | 210 | 0.2% |
(Missing) | 63829 | 64.9% |

retweeted_status_user_description
Categorical

Distinct count | 5307
Unique (%) | 18.3%
Missing (%) | 70.6%
Missing (n) | 69449

Not sure if I'm a politician, activist, reader, writer, journalist or.. But I'm an Indian. I like Gandhi, because he always moved ahead of his own identity | 1809
#AI & #MachineLearning researcher. Data tinkerer. Community leader for @DataIsBeautiful. Support my blog: https://t.co/cpRqH03lVP | 885
Big data, machine learning, predictive modeling, R, Hadoop, Python, business analytics, data mining, IoT and operations research: resources, tutorials and more. | 661
Other values (5303) | 25589
(Missing) | 69449

Toggle details

Value | Count | Frequency (%) |
Not sure if I'm a politician, activist, reader, writer, journalist or.. But I'm an Indian. I like Gandhi, because he always moved ahead of his own identity | 1809 | 1.8% |
#AI & #MachineLearning researcher. Data tinkerer. Community leader for @DataIsBeautiful. Support my blog: https://t.co/cpRqH03lVP | 885 | 0.9% |
Big data, machine learning, predictive modeling, R, Hadoop, Python, business analytics, data mining, IoT and operations research: resources, tutorials and more. | 661 | 0.7% |
KDnuggets President, #Analytics, #BigData, #DataMining, #DataScience expert, KDD & SIGKDD co-founder, was Chief Scientist at 2 startups, part-time philosopher. | 481 | 0.5% |
Python Weekly is a free weekly newsletter, which features curated news, articles, new releases, tools and libraries, events, jobs etc related to Python | 362 | 0.4% |
Model (ROCK Calendar Model Pageant Winner - 2012) & New York fiction Author [ NYC - Chicago - Paris - England ] | 308 | 0.3% |
tweeting trending Python repositories on GitHub | 258 | 0.3% |
Linux Evangelist, Malwares ,Kernel dev. Security enthusiast,Jain,Philanthropist & reformist. | 252 | 0.3% |
View all available Python Developer jobs from company sites, job boards and the web at https://t.co/X9YF9QW4pC - thousands of new jobs added daily! | 224 | 0.2% |
Bringing together the global data science community to help foster the exchange of innovative ideas and encourage the growth of open source software. | 200 | 0.2% |
#FOSS Developer and Data Scientist #Android Developer #Gaming #PostgreSQL DBA | 193 | 0.2% |
Live content curated by top Python Influencers | 188 | 0.2% |
The BEST Tech Jobs in California, Period. Careers for: #Backend, #Fullstack, #DataScience, #Android + many more. Post your Job - https://t.co/Az4W3JfVDi | 177 | 0.2% |
Technology Consultant, Graphic Designer, Musician, Composer, Software Programmer, Mobile Application, Unity 3D Programmer, VR Dev | 176 | 0.2% |
Java developers resource center. JCGs is one of the fastest growing Java developers community on the net. Created by Java developers for Java developers | 173 | 0.2% |
polymath poser pontificating personal thoughts from #PDX. From brain.gyrus import #Akkadtum, #Python...#CloudOps #DevOps #IoT #SyntheticData #Cognition #infosec | 170 | 0.2% |
Tweets about SciPy (Scientific Python) and related topics from @JohnDCook. | 165 | 0.2% |
Official twitter account of #UnitedNations. Get the latest information on the #UN. #GlobalGoals | 164 | 0.2% |
#Website for #developers and #IT enthusiasts. #IT #community of new generation. | 162 | 0.2% |
Python 3 Packages and Modules on pypi - As it Happens. | 157 | 0.2% |
Other values (5286) | 21779 | 22.1% |
(Missing) | 69449 | 70.6% |

retweeted_status_user_entities_description_urls
Categorical

Distinct count | 706
Unique (%) | 2.1%
Missing (%) | 65.3%
Missing (n) | 64206

[] | 29099
[{u'url': u'https://t.co/cpRqH03lVP', u'indices': [106, 129], u'expanded_url': u'http://patreon.com/randal_olson', u'display_url': u'patreon.com/randal_olson'}] | 652
[{u'url': u'https://t.co/f4gsbNc00C', u'indices': [118, 141], u'expanded_url': u'http://rocketdatascience.org/', u'display_url': u'rocketdatascience.org'}] | 627
Other values (702) | 3809
(Missing) | 64206

Toggle details

Value | Count | Frequency (%) |
[] | 29099 | 29.6% |
[{u'url': u'https://t.co/cpRqH03lVP', u'indices': [106, 129], u'expanded_url': u'http://patreon.com/randal_olson', u'display_url': u'patreon.com/randal_olson'}] | 652 | 0.7% |
[{u'url': u'https://t.co/f4gsbNc00C', u'indices': [118, 141], u'expanded_url': u'http://rocketdatascience.org/', u'display_url': u'rocketdatascience.org'}] | 627 | 0.6% |
[{u'indices': [106, 129], u'url': u'https://t.co/cpRqH03lVP', u'expanded_url': u'http://patreon.com/randal_olson', u'display_url': u'patreon.com/randal_olson'}] | 233 | 0.2% |
[{u'url': u'https://t.co/X9YF9QW4pC', u'indices': [87, 110], u'expanded_url': u'http://jobfindly.com', u'display_url': u'jobfindly.com'}] | 179 | 0.2% |
[{u'url': u'https://t.co/Az4W3JfVDi', u'indices': [130, 153], u'expanded_url': u'http://www.JobHero.io', u'display_url': u'JobHero.io'}] | 150 | 0.2% |
[{u'url': u'http://t.co/2DOrg6oXi8', u'indices': [55, 77], u'expanded_url': u'http://danstoncloud.com', u'display_url': u'danstoncloud.com'}] | 145 | 0.1% |
[{u'url': u'https://t.co/Pip0u8gh5G', u'indices': [126, 149], u'expanded_url': u'http://www.craigbrownphd.com', u'display_url': u'craigbrownphd.com'}] | 125 | 0.1% |
[{u'url': u'http://t.co/QVTIJZCdlx', u'indices': [106, 128], u'expanded_url': u'http://PentesterAcademy.com', u'display_url': u'PentesterAcademy.com'}, {u'url': u'http://t.co/0vm0BnkqLa', u'indices': [132, 154], u'expanded_url': u'http://Securitytube-Training.com', u'display_url': u'Securitytube-Training.com'}] | 101 | 0.1% |
[{u'url': u'http://t.co/mbTSujJ23b', u'indices': [46, 68], u'expanded_url': u'http://kofapp.com', u'display_url': u'kofapp.com'}] | 80 | 0.1% |
[{u'url': u'http://t.co/16QGv879Ew', u'indices': [97, 119], u'expanded_url': u'http://www.thesillywalk.com', u'display_url': u'thesillywalk.com'}] | 75 | 0.1% |
[{u'indices': [118, 141], u'url': u'https://t.co/f4gsbNc00C', u'expanded_url': u'http://rocketdatascience.org/', u'display_url': u'rocketdatascience.org'}] | 75 | 0.1% |
[{u'url': u'http://t.co/MCO6KA0oGG', u'indices': [0, 22], u'expanded_url': u'http://www.kitploit.com', u'display_url': u'kitploit.com'}] | 68 | 0.1% |
[{u'url': u'http://t.co/PAZvNciaIO', u'indices': [138, 160], u'expanded_url': u'http://Gamification.ir', u'display_url': u'Gamification.ir'}] | 54 | 0.1% |
[{u'url': u'http://t.co/olzt8M25oa', u'indices': [43, 65], u'expanded_url': u'http://opensource.com', u'display_url': u'opensource.com'}] | 52 | 0.1% |
[{u'url': u'https://t.co/4ZEpUIjMlb', u'indices': [25, 48], u'expanded_url': u'http://importpython.com', u'display_url': u'importpython.com'}] | 46 | 0.0% |
[{u'url': u'https://t.co/yEkRurxH5V', u'indices': [103, 126], u'expanded_url': u'https://www.instagram.com/rafred10/', u'display_url': u'instagram.com/rafred10/'}] | 45 | 0.0% |
[{u'indices': [87, 110], u'url': u'https://t.co/X9YF9QW4pC', u'expanded_url': u'http://jobfindly.com', u'display_url': u'jobfindly.com'}] | 45 | 0.0% |
[{u'indices': [86, 109], u'url': u'https://t.co/nkTEEYM5ed', u'expanded_url': u'http://earthobservatory.nasa.gov', u'display_url': u'earthobservatory.nasa.gov'}] | 44 | 0.0% |
[{u'url': u'https://t.co/dzhnHtgKhC', u'indices': [0, 23], u'expanded_url': u'http://misspeachy.com', u'display_url': u'misspeachy.com'}] | 43 | 0.0% |
Other values (685) | 2249 | 2.3% |
(Missing) | 64206 | 65.3% |

retweeted_status_user_entities_url_urls
Categorical

Distinct count | 4563
Unique (%) | 20.3%
Missing (%) | 77.1%
Missing (n) | 75893

[{u'url': u'https://t.co/tpzAYxx9cq', u'indices': [0, 23], u'expanded_url': u'http://www.randalolson.com', u'display_url': u'randalolson.com'}] | 652
[{u'url': u'https://t.co/tWlmeuTlR7', u'indices': [0, 23], u'expanded_url': u'http://www.linkedin.com/in/kirkdborne', u'display_url': u'linkedin.com/in/kirkdborne'}] | 627
[{u'url': u'http://t.co/aWUY84onbG', u'indices': [0, 22], u'expanded_url': u'http://www.kdnuggets.com/', u'display_url': u'kdnuggets.com'}] | 374
Other values (4559) | 20847
(Missing) | 75893

Toggle details

Value | Count | Frequency (%) |
[{u'url': u'https://t.co/tpzAYxx9cq', u'indices': [0, 23], u'expanded_url': u'http://www.randalolson.com', u'display_url': u'randalolson.com'}] | 652 | 0.7% |
[{u'url': u'https://t.co/tWlmeuTlR7', u'indices': [0, 23], u'expanded_url': u'http://www.linkedin.com/in/kirkdborne', u'display_url': u'linkedin.com/in/kirkdborne'}] | 627 | 0.6% |
[{u'url': u'http://t.co/aWUY84onbG', u'indices': [0, 22], u'expanded_url': u'http://www.kdnuggets.com/', u'display_url': u'kdnuggets.com'}] | 374 | 0.4% |
[{u'url': u'http://t.co/D1OMRitAIv', u'indices': [0, 22], u'expanded_url': u'http://www.pythonweekly.com/', u'display_url': u'pythonweekly.com'}] | 347 | 0.4% |
[{u'indices': [0, 23], u'url': u'https://t.co/B2AdRQDuaf', u'expanded_url': u'http://www.delilahalvares.com', u'display_url': u'delilahalvares.com'}] | 308 | 0.3% |
[{u'indices': [0, 23], u'url': u'https://t.co/tpzAYxx9cq', u'expanded_url': u'http://www.randalolson.com', u'display_url': u'randalolson.com'}] | 233 | 0.2% |
[{u'url': u'http://t.co/DivczES801', u'indices': [0, 22], u'expanded_url': u'http://www.javacodegeeks.com', u'display_url': u'javacodegeeks.com'}] | 172 | 0.2% |
[{u'url': u'https://t.co/wXDyVzfUM0', u'indices': [0, 23], u'expanded_url': u'http://bit.ly/JobHero', u'display_url': u'bit.ly/JobHero'}] | 167 | 0.2% |
[{u'url': u'http://t.co/kgJqUNDMpy', u'indices': [0, 22], u'expanded_url': u'http://www.un.org', u'display_url': u'un.org'}] | 164 | 0.2% |
[{u'url': u'https://t.co/UBbHYS8ReL', u'indices': [0, 23], u'expanded_url': u'http://odsc.com', u'display_url': u'odsc.com'}] | 157 | 0.2% |
[{u'url': u'https://t.co/Xm6V2081pG', u'indices': [0, 23], u'expanded_url': u'http://devbattles.com', u'display_url': u'devbattles.com'}] | 156 | 0.2% |
[{u'url': u'https://t.co/o7Zlm2tvAr', u'indices': [0, 23], u'expanded_url': u'http://alicegoldfuss.com', u'display_url': u'alicegoldfuss.com'}] | 147 | 0.1% |
[{u'url': u'https://t.co/iHBjgnH6dc', u'indices': [0, 23], u'expanded_url': u'https://www.facebook.com/laurent.miltgen', u'display_url': u'facebook.com/laurent.miltgen'}] | 145 | 0.1% |
[{u'url': u'https://t.co/NuLC7DH3ui', u'indices': [0, 23], u'expanded_url': u'http://psychopyrate.tumblr.com', u'display_url': u'psychopyrate.tumblr.com'}] | 134 | 0.1% |
[{u'url': u'http://t.co/PVtXT9K1OX', u'indices': [0, 22], u'expanded_url': u'http://bit.ly/1uLmkxZ', u'display_url': u'bit.ly/1uLmkxZ'}] | 128 | 0.1% |
[{u'url': u'https://t.co/vxXDDto9Wa', u'indices': [0, 23], u'expanded_url': u'https://www.michalspacek.cz/', u'display_url': u'michalspacek.cz'}] | 123 | 0.1% |
[{u'url': u'https://t.co/vtMHCfZpoO', u'indices': [0, 23], u'expanded_url': u'http://JohnDCook.com', u'display_url': u'JohnDCook.com'}] | 117 | 0.1% |
[{u'url': u'https://t.co/WCQmGdVwIc', u'indices': [0, 23], u'expanded_url': u'https://plot.ly/', u'display_url': u'plot.ly'}] | 114 | 0.1% |
[{u'url': u'http://t.co/xfZ3CeBbeY', u'indices': [0, 22], u'expanded_url': u'http://planet.python.org', u'display_url': u'planet.python.org'}] | 113 | 0.1% |
[{u'url': u'http://t.co/ZhoOQdg9HF', u'indices': [0, 22], u'expanded_url': u'http://RealPython.com', u'display_url': u'RealPython.com'}] | 110 | 0.1% |
Other values (4542) | 18012 | 18.3% |
(Missing) | 75893 | 77.1% |

retweeted_status_user_favourites_count
Numeric

Distinct count | 2986
Unique (%) | 8.6%
Missing (%) | 64.9%
Missing (n) | 63829

Mean | 6556.5
Minimum | 0
Maximum | 424500
Zeros (%) | 3.5%

Toggle details

Quantile statistics

Minimum | 0
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 424500
Range | 424500
Interquartile range |

Descriptive statistics

Standard deviation | 19015
Coef of variation | 2.9001
Kurtosis | 37.738
Mean | 6556.5
MAD | 9544.1
Skewness | 5.0031
Sum | 226620000
Variance | 361570000
Memory size | 768.8 KiB

retweeted_status_user_followers_count
Numeric

Distinct count | 3982
Unique (%) | 11.5%
Missing (%) | 64.9%
Missing (n) | 63829

Mean | 165880
Minimum | 0
Maximum | 38508000
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 0
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 38508000
Range | 38508000
Interquartile range |

Descriptive statistics

Standard deviation | 1035900
Coef of variation | 6.2448
Kurtosis | 370.68
Mean | 165880
MAD | 263780
Skewness | 15.982
Sum | 5733600000
Variance | 1.0731e+12
Memory size | 768.8 KiB

retweeted_status_user_friends_count
Numeric

Distinct count | 2514
Unique (%) | 7.3%
Missing (%) | 64.9%
Missing (n) | 63829

Mean | 6972.4
Minimum | 0
Maximum | 554700
Zeros (%) | 1.1%

Toggle details

Quantile statistics

Minimum | 0
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 554700
Range | 554700
Interquartile range |

Descriptive statistics

Standard deviation | 20665
Coef of variation | 2.9638
Kurtosis | 33.534
Mean | 6972.4
MAD | 10340
Skewness | 4.4376
Sum | 240990000
Variance | 427040000
Memory size | 768.8 KiB

retweeted_status_user_geo_enabled
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

False | 21118
True | 13446
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
False | 21118 | 21.5% |
True | 13446 | 13.7% |
(Missing) | 63829 | 64.9% |

retweeted_status_user_has_extended_profile
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

False | 30441
True | 4123
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
False | 30441 | 30.9% |
True | 4123 | 4.2% |
(Missing) | 63829 | 64.9% |

retweeted_status_user_id
Numeric

Distinct count | 6486
Unique (%) | 18.8%
Missing (%) | 64.9%
Missing (n) | 63829

Mean | 2.6921e+16
Minimum | 22
Maximum | 7.2671e+17
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 22
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 7.2671e+17
Range | 7.2671e+17
Interquartile range |

Descriptive statistics

Standard deviation | 1.3602e+17
Coef of variation | 5.0527
Kurtosis | 21.577
Mean | 2.6921e+16
MAD | 5.1812e+16
Skewness | 4.8553
Sum | 9.305e+2
Variance | 1.8502e+34
Memory size | 768.8 KiB

retweeted_status_user_id_str
Highly correlated

This variable is highly correlated with `retweeted_status_user_id` and should be ignored for analysis

Correlation | 1

retweeted_status_user_is_translation_enabled
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

False | 33945
True | 619
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
False | 33945 | 34.5% |
True | 619 | 0.6% |
(Missing) | 63829 | 64.9% |

retweeted_status_user_is_translator
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63829

False | 34547
True | 17
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
False | 34547 | 35.1% |
True | 17 | 0.0% |
(Missing) | 63829 | 64.9% |

retweeted_status_user_lang
Categorical

Distinct count | 35
Unique (%) | 0.1%
Missing (%) | 64.9%
Missing (n) | 63829

en | 31040
es | 948
fr | 543
Other values (31) | 2033
(Missing) | 63829

Toggle details

Value | Count | Frequency (%) |
en | 31040 | 31.5% |
es | 948 | 1.0% |
fr | 543 | 0.6% |
en-gb | 432 | 0.4% |
de | 315 | 0.3% |
it | 266 | 0.3% |
vi | 228 | 0.2% |
sv | 141 | 0.1% |
ru | 113 | 0.1% |
pt | 111 | 0.1% |
pl | 88 | 0.1% |
nl | 74 | 0.1% |
ja | 61 | 0.1% |
en-GB | 40 | 0.0% |
ko | 29 | 0.0% |
zh-CN | 18 | 0.0% |
id | 14 | 0.0% |
ar | 13 | 0.0% |
uk | 12 | 0.0% |
fi | 11 | 0.0% |
Other values (14) | 67 | 0.1% |
(Missing) | 63829 | 64.9% |

retweeted_status_user_listed_count
Numeric

Distinct count | 1213
Unique (%) | 3.5%
Missing (%) | 64.9%
Missing (n) | 63829

Mean | 1364.6
Minimum | 0
Maximum | 173930
Zeros (%) | 0.8%

Toggle details

Quantile statistics

Minimum | 0
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 173930
Range | 173930
Interquartile range |

Descriptive statistics

Standard deviation | 6070.1
Coef of variation | 4.4482
Kurtosis | 205.52
Mean | 1364.6
MAD | 1774.2
Skewness | 12.793
Sum | 47166000
Variance | 36846000
Memory size | 768.8 KiB

retweeted_status_user_location
Categorical

Distinct count | 2695
Unique (%) | 10.4%
Missing (%) | 73.7%
Missing (n) | 72481

Delhi | 1812
Philadelphia, PA | 908
Seattle, WA | 793
Other values (2691) | 22399
(Missing) | 72481

Toggle details

Value | Count | Frequency (%) |
Delhi | 1812 | 1.8% |
Philadelphia, PA | 908 | 0.9% |
Seattle, WA | 793 | 0.8% |
Booz Allen Hamilton | 702 | 0.7% |
Brookline, MA, USA | 481 | 0.5% |
New York, NY | 358 | 0.4% |
United States | 346 | 0.4% |
San Francisco, CA | 345 | 0.4% |
USA | 313 | 0.3% |
New York, England | 308 | 0.3% |
Worldwide | 302 | 0.3% |
Interwebs | 258 | 0.3% |
In 0's & 1's of capacitor | 252 | 0.3% |
London | 251 | 0.3% |
Boston, MA | 200 | 0.2% |
Portland, OR | 199 | 0.2% |
Austin, TX | 197 | 0.2% |
SF Bay Area, CA | 194 | 0.2% |
Colorado | 186 | 0.2% |
San Francisco | 183 | 0.2% |
Other values (2674) | 17324 | 17.6% |
(Missing) | 72481 | 73.7% |

retweeted_status_user_name
Categorical

Distinct count | 6039
Unique (%) | 18.2%
Missing (%) | 66.3%
Missing (n) | 65260

Manish Sisodia | 1809
Randy Olson | 885
Kirk Borne | 702
Other values (6035) | 29737
(Missing) | 65260

Toggle details

Value | Count | Frequency (%) |
Manish Sisodia | 1809 | 1.8% |
Randy Olson | 885 | 0.9% |
Kirk Borne | 702 | 0.7% |
Big Data Science | 661 | 0.7% |
Gregory Piatetsky | 481 | 0.5% |
Python Weekly | 362 | 0.4% |
Delilah Alvares | 308 | 0.3% |
#TWD Fan Page | 263 | 0.3% |
Python Trending | 258 | 0.3% |
Binni Shah | 252 | 0.3% |
Python Dev Jobs | 224 | 0.2% |
cho | 220 | 0.2% |
Open Data Science | 200 | 0.2% |
Python | 199 | 0.2% |
JobHero.io | 194 | 0.2% |
Lennin Caro | 193 | 0.2% |
Rick King | 176 | 0.2% |
Java Code Geeks | 173 | 0.2% |
mike grimshaw | 170 | 0.2% |
Scientific Python | 165 | 0.2% |
Other values (6018) | 25238 | 25.7% |
(Missing) | 65260 | 66.3% |

retweeted_status_user_profile_background_color
Categorical

Distinct count | 732
Unique (%) | 2.1%
Missing (%) | 64.9%
Missing (n) | 63841

C0DEED | 12827
000000 | 5357
1A1B1F | 2672
Other values (728) | 13696
(Missing) | 63841

Toggle details

Value | Count | Frequency (%) |
C0DEED | 12827 | 13.0% |
000000 | 5357 | 5.4% |
1A1B1F | 2672 | 2.7% |
131516 | 1869 | 1.9% |
F5F8FA | 1648 | 1.7% |
FFFFFF | 1274 | 1.3% |
352726 | 857 | 0.9% |
0099B9 | 844 | 0.9% |
ACDED6 | 610 | 0.6% |
022330 | 581 | 0.6% |
9AE4E8 | 483 | 0.5% |
C6E2EE | 420 | 0.4% |
709397 | 276 | 0.3% |
642D8B | 249 | 0.3% |
FFF04D | 179 | 0.2% |
0197D6 | 164 | 0.2% |
EDECE9 | 159 | 0.2% |
213350 | 123 | 0.1% |
B2DFDA | 112 | 0.1% |
EBEBEB | 104 | 0.1% |
Other values (711) | 3744 | 3.8% |
(Missing) | 63841 | 64.9% |

retweeted_status_user_profile_background_image_url
Categorical

Distinct count | 2114
Unique (%) | 6.4%
Missing (%) | 66.5%
Missing (n) | 65443

http://abs.twimg.com/images/themes/theme1/bg.png | 14240
http://abs.twimg.com/images/themes/theme14/bg.gif | 1702
http://abs.twimg.com/images/themes/theme9/bg.gif | 1350
Other values (2110) | 15658
(Missing) | 65443

Toggle details

Value | Count | Frequency (%) |
http://abs.twimg.com/images/themes/theme1/bg.png | 14240 | 14.5% |
http://abs.twimg.com/images/themes/theme14/bg.gif | 1702 | 1.7% |
http://abs.twimg.com/images/themes/theme9/bg.gif | 1350 | 1.4% |
http://pbs.twimg.com/profile_background_images/457629516702035968/lKWBWYYG.jpeg | 885 | 0.9% |
http://pbs.twimg.com/profile_background_images/378800000110442114/094a0b4d38b70e3871a1bda7d7fe2341.jpeg | 702 | 0.7% |
http://abs.twimg.com/images/themes/theme15/bg.png | 687 | 0.7% |
http://pbs.twimg.com/profile_background_images/33516583/water10x.gif | 661 | 0.7% |
http://abs.twimg.com/images/themes/theme18/bg.gif | 611 | 0.6% |
http://pbs.twimg.com/profile_background_images/378800000050609482/c32d3d654da4eb7c0518e7bba2609522.jpeg | 481 | 0.5% |
http://abs.twimg.com/images/themes/theme4/bg.gif | 390 | 0.4% |
http://pbs.twimg.com/profile_background_images/378800000036903738/3118fc770e5420a70d36d7f2eaca238e.jpeg | 252 | 0.3% |
http://abs.twimg.com/images/themes/theme10/bg.gif | 213 | 0.2% |
http://abs.twimg.com/images/themes/theme2/bg.gif | 205 | 0.2% |
http://pbs.twimg.com/profile_background_images/208825921/Debian_Desktop_Wallpaper_Fight_For_Open_Source_Logo.jpg | 193 | 0.2% |
http://abs.twimg.com/images/themes/theme19/bg.gif | 184 | 0.2% |
http://abs.twimg.com/images/themes/theme6/bg.gif | 183 | 0.2% |
http://pbs.twimg.com/profile_background_images/611680364235362304/iyRt2eBI.jpg | 170 | 0.2% |
http://abs.twimg.com/images/themes/theme3/bg.gif | 169 | 0.2% |
http://pbs.twimg.com/profile_background_images/765681180/1001e289be48bdb34f8e07948b5f2a7a.jpeg | 164 | 0.2% |
http://pbs.twimg.com/profile_background_images/605063482271232000/tv_pbe2Z.jpg | 145 | 0.1% |
Other values (2093) | 9363 | 9.5% |
(Missing) | 65443 | 66.5% |

retweeted_status_user_profile_background_image_url_https
Categorical

Distinct count | 2114
Unique (%) | 6.4%
Missing (%) | 66.5%
Missing (n) | 65443

https://abs.twimg.com/images/themes/theme1/bg.png | 14240
https://abs.twimg.com/images/themes/theme14/bg.gif | 1702
https://abs.twimg.com/images/themes/theme9/bg.gif | 1350
Other values (2110) | 15658
(Missing) | 65443

Toggle details

Value | Count | Frequency (%) |
https://abs.twimg.com/images/themes/theme1/bg.png | 14240 | 14.5% |
https://abs.twimg.com/images/themes/theme14/bg.gif | 1702 | 1.7% |
https://abs.twimg.com/images/themes/theme9/bg.gif | 1350 | 1.4% |
https://pbs.twimg.com/profile_background_images/457629516702035968/lKWBWYYG.jpeg | 885 | 0.9% |
https://pbs.twimg.com/profile_background_images/378800000110442114/094a0b4d38b70e3871a1bda7d7fe2341.jpeg | 702 | 0.7% |
https://abs.twimg.com/images/themes/theme15/bg.png | 687 | 0.7% |
https://pbs.twimg.com/profile_background_images/33516583/water10x.gif | 661 | 0.7% |
https://abs.twimg.com/images/themes/theme18/bg.gif | 611 | 0.6% |
https://pbs.twimg.com/profile_background_images/378800000050609482/c32d3d654da4eb7c0518e7bba2609522.jpeg | 481 | 0.5% |
https://abs.twimg.com/images/themes/theme4/bg.gif | 390 | 0.4% |
https://pbs.twimg.com/profile_background_images/378800000036903738/3118fc770e5420a70d36d7f2eaca238e.jpeg | 252 | 0.3% |
https://abs.twimg.com/images/themes/theme10/bg.gif | 213 | 0.2% |
https://abs.twimg.com/images/themes/theme2/bg.gif | 205 | 0.2% |
https://pbs.twimg.com/profile_background_images/208825921/Debian_Desktop_Wallpaper_Fight_For_Open_Source_Logo.jpg | 193 | 0.2% |
https://abs.twimg.com/images/themes/theme19/bg.gif | 184 | 0.2% |
https://abs.twimg.com/images/themes/theme6/bg.gif | 183 | 0.2% |
https://pbs.twimg.com/profile_background_images/611680364235362304/iyRt2eBI.jpg | 170 | 0.2% |
https://abs.twimg.com/images/themes/theme3/bg.gif | 169 | 0.2% |
https://pbs.twimg.com/profile_background_images/765681180/1001e289be48bdb34f8e07948b5f2a7a.jpeg | 164 | 0.2% |
https://pbs.twimg.com/profile_background_images/605063482271232000/tv_pbe2Z.jpg | 145 | 0.1% |
Other values (2093) | 9363 | 9.5% |
(Missing) | 65443 | 66.5% |

retweeted_status_user_profile_background_tile
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63841

False | 26607
True | 7945
(Missing) | 63841

Toggle details

Value | Count | Frequency (%) |
False | 26607 | 27.0% |
True | 7945 | 8.1% |
(Missing) | 63841 | 64.9% |

retweeted_status_user_profile_banner_url
Categorical

Distinct count | 4893
Unique (%) | 18.1%
Missing (%) | 72.6%
Missing (n) | 71385

https://pbs.twimg.com/profile_banners/30417501/1365833343 | 1809
https://pbs.twimg.com/profile_banners/49413866/1439914461 | 885
https://pbs.twimg.com/profile_banners/534563976/1450104430 | 702
Other values (4889) | 23612
(Missing) | 71385

Toggle details

Value | Count | Frequency (%) |
https://pbs.twimg.com/profile_banners/30417501/1365833343 | 1809 | 1.8% |
https://pbs.twimg.com/profile_banners/49413866/1439914461 | 885 | 0.9% |
https://pbs.twimg.com/profile_banners/534563976/1450104430 | 702 | 0.7% |
https://pbs.twimg.com/profile_banners/14174897/1401028953 | 661 | 0.7% |
https://pbs.twimg.com/profile_banners/20167623/1367620090 | 481 | 0.5% |
https://pbs.twimg.com/profile_banners/4804550526/1458217261 | 308 | 0.3% |
https://pbs.twimg.com/profile_banners/3331829713/1443335296 | 263 | 0.3% |
https://pbs.twimg.com/profile_banners/2445802928/1397586592 | 258 | 0.3% |
https://pbs.twimg.com/profile_banners/715902102615171072/1459519674 | 220 | 0.2% |
https://pbs.twimg.com/profile_banners/3018841323/1453829160 | 200 | 0.2% |
https://pbs.twimg.com/profile_banners/593222868/1459225544 | 194 | 0.2% |
https://pbs.twimg.com/profile_banners/205824307/1436887338 | 193 | 0.2% |
https://pbs.twimg.com/profile_banners/757365218/1416410613 | 176 | 0.2% |
https://pbs.twimg.com/profile_banners/150820027/1393781870 | 173 | 0.2% |
https://pbs.twimg.com/profile_banners/243877974/1434962331 | 170 | 0.2% |
https://pbs.twimg.com/profile_banners/254791849/1458355479 | 165 | 0.2% |
https://pbs.twimg.com/profile_banners/14159148/1460565548 | 164 | 0.2% |
https://pbs.twimg.com/profile_banners/3179754226/1461412745 | 163 | 0.2% |
https://pbs.twimg.com/profile_banners/2377678050/1416924179 | 162 | 0.2% |
https://pbs.twimg.com/profile_banners/1637123371/1418028606 | 150 | 0.2% |
Other values (4872) | 19511 | 19.8% |
(Missing) | 71385 | 72.6% |

retweeted_status_user_profile_image_url
Categorical

Distinct count | 6417
Unique (%) | 18.6%
Missing (%) | 64.9%
Missing (n) | 63841

http://pbs.twimg.com/profile_images/634951311801257984/FtTpdBj7_normal.jpg | 1809
http://pbs.twimg.com/profile_images/618964235779862528/nLQhBWfq_normal.jpg | 885
http://pbs.twimg.com/profile_images/680246148762828801/flXTNSKT_normal.jpg | 702
Other values (6413) | 31156
(Missing) | 63841

Toggle details

Value | Count | Frequency (%) |
http://pbs.twimg.com/profile_images/634951311801257984/FtTpdBj7_normal.jpg | 1809 | 1.8% |
http://pbs.twimg.com/profile_images/618964235779862528/nLQhBWfq_normal.jpg | 885 | 0.9% |
http://pbs.twimg.com/profile_images/680246148762828801/flXTNSKT_normal.jpg | 702 | 0.7% |
http://pbs.twimg.com/profile_images/1198161733/analitycbridge_normal.png | 661 | 0.7% |
http://pbs.twimg.com/profile_images/1174228552/gpsc2_normal.jpg | 481 | 0.5% |
http://pbs.twimg.com/profile_images/1554238582/python_normal.jpg | 362 | 0.4% |
http://pbs.twimg.com/profile_images/691023532600401920/NbB3An-D_normal.jpg | 308 | 0.3% |
http://pbs.twimg.com/profile_images/650086883016339456/uOT485eU_normal.jpg | 263 | 0.3% |
http://pbs.twimg.com/profile_images/456490947287605248/4oklmBWe_normal.png | 258 | 0.3% |
http://pbs.twimg.com/profile_images/711864271903322112/TF7Pgylt_normal.jpg | 252 | 0.3% |
http://pbs.twimg.com/profile_images/679698663698911232/sixEllZl_normal.jpg | 224 | 0.2% |
http://pbs.twimg.com/profile_images/715902908751962112/6NGxgnWv_normal.jpg | 220 | 0.2% |
http://pbs.twimg.com/profile_images/623923923441348612/HxO7gaZZ_normal.png | 200 | 0.2% |
http://pbs.twimg.com/profile_images/609201325046280192/WqwLYJNg_normal.jpg | 194 | 0.2% |
http://pbs.twimg.com/profile_images/620976524448153600/FaP0gL2J_normal.jpg | 193 | 0.2% |
http://pbs.twimg.com/profile_images/535252199073275904/9JrlgXqh_normal.png | 188 | 0.2% |
http://pbs.twimg.com/profile_images/474218179682504705/XO7iB9e7_normal.jpeg | 176 | 0.2% |
http://pbs.twimg.com/profile_images/2928906892/098968d4c7f39c870935f8aae12a8a14_normal.png | 173 | 0.2% |
http://pbs.twimg.com/profile_images/611686609407180800/hZKDoHLq_normal.jpg | 170 | 0.2% |
http://pbs.twimg.com/profile_images/710923156655984640/8Z95ugd__normal.jpg | 165 | 0.2% |
Other values (6396) | 26668 | 27.1% |
(Missing) | 63841 | 64.9% |

retweeted_status_user_profile_image_url_https
Categorical

Distinct count | 6417
Unique (%) | 18.6%
Missing (%) | 64.9%
Missing (n) | 63841

https://pbs.twimg.com/profile_images/634951311801257984/FtTpdBj7_normal.jpg | 1809
https://pbs.twimg.com/profile_images/618964235779862528/nLQhBWfq_normal.jpg | 885
https://pbs.twimg.com/profile_images/680246148762828801/flXTNSKT_normal.jpg | 702
Other values (6413) | 31156
(Missing) | 63841

Toggle details

Value | Count | Frequency (%) |
https://pbs.twimg.com/profile_images/634951311801257984/FtTpdBj7_normal.jpg | 1809 | 1.8% |
https://pbs.twimg.com/profile_images/618964235779862528/nLQhBWfq_normal.jpg | 885 | 0.9% |
https://pbs.twimg.com/profile_images/680246148762828801/flXTNSKT_normal.jpg | 702 | 0.7% |
https://pbs.twimg.com/profile_images/1198161733/analitycbridge_normal.png | 661 | 0.7% |
https://pbs.twimg.com/profile_images/1174228552/gpsc2_normal.jpg | 481 | 0.5% |
https://pbs.twimg.com/profile_images/1554238582/python_normal.jpg | 362 | 0.4% |
https://pbs.twimg.com/profile_images/691023532600401920/NbB3An-D_normal.jpg | 308 | 0.3% |
https://pbs.twimg.com/profile_images/650086883016339456/uOT485eU_normal.jpg | 263 | 0.3% |
https://pbs.twimg.com/profile_images/456490947287605248/4oklmBWe_normal.png | 258 | 0.3% |
https://pbs.twimg.com/profile_images/711864271903322112/TF7Pgylt_normal.jpg | 252 | 0.3% |
https://pbs.twimg.com/profile_images/679698663698911232/sixEllZl_normal.jpg | 224 | 0.2% |
https://pbs.twimg.com/profile_images/715902908751962112/6NGxgnWv_normal.jpg | 220 | 0.2% |
https://pbs.twimg.com/profile_images/623923923441348612/HxO7gaZZ_normal.png | 200 | 0.2% |
https://pbs.twimg.com/profile_images/609201325046280192/WqwLYJNg_normal.jpg | 194 | 0.2% |
https://pbs.twimg.com/profile_images/620976524448153600/FaP0gL2J_normal.jpg | 193 | 0.2% |
https://pbs.twimg.com/profile_images/535252199073275904/9JrlgXqh_normal.png | 188 | 0.2% |
https://pbs.twimg.com/profile_images/474218179682504705/XO7iB9e7_normal.jpeg | 176 | 0.2% |
https://pbs.twimg.com/profile_images/2928906892/098968d4c7f39c870935f8aae12a8a14_normal.png | 173 | 0.2% |
https://pbs.twimg.com/profile_images/611686609407180800/hZKDoHLq_normal.jpg | 170 | 0.2% |
https://pbs.twimg.com/profile_images/710923156655984640/8Z95ugd__normal.jpg | 165 | 0.2% |
Other values (6396) | 26668 | 27.1% |
(Missing) | 63841 | 64.9% |

retweeted_status_user_profile_link_color
Categorical

Distinct count | 1406
Unique (%) | 4.1%
Missing (%) | 64.9%
Missing (n) | 63841

0084B4 | 13306
3B94D9 | 2472
2B7BB9 | 1602
Other values (1402) | 17172
(Missing) | 63841

Toggle details

Value | Count | Frequency (%) |
0084B4 | 13306 | 13.5% |
3B94D9 | 2472 | 2.5% |
2B7BB9 | 1602 | 1.6% |
009999 | 1186 | 1.2% |
2FC2EF | 1158 | 1.2% |
0099B9 | 845 | 0.9% |
ABB8C2 | 718 | 0.7% |
080808 | 664 | 0.7% |
038543 | 569 | 0.6% |
4A913C | 561 | 0.6% |
FA743E | 557 | 0.6% |
1B95E0 | 446 | 0.5% |
000000 | 432 | 0.4% |
94D487 | 253 | 0.3% |
815E32 | 252 | 0.3% |
DD2E44 | 231 | 0.2% |
FF0000 | 226 | 0.2% |
1F98C7 | 224 | 0.2% |
89C9FA | 177 | 0.2% |
004899 | 167 | 0.2% |
Other values (1385) | 8506 | 8.6% |
(Missing) | 63841 | 64.9% |

retweeted_status_user_profile_sidebar_border_color
Categorical

Distinct count | 261
Unique (%) | 0.8%
Missing (%) | 64.9%
Missing (n) | 63841

C0DEED | 12772
FFFFFF | 6983
000000 | 6709
Other values (257) | 8088
(Missing) | 63841

Toggle details

Value | Count | Frequency (%) |
C0DEED | 12772 | 13.0% |
FFFFFF | 6983 | 7.1% |
000000 | 6709 | 6.8% |
EEEEEE | 1754 | 1.8% |
181A1E | 1298 | 1.3% |
829D5E | 835 | 0.8% |
5ED4DC | 722 | 0.7% |
A8C7F7 | 469 | 0.5% |
87BC44 | 287 | 0.3% |
BDDCAD | 246 | 0.3% |
C6E2EE | 212 | 0.2% |
65B0DA | 174 | 0.2% |
86A4A6 | 170 | 0.2% |
0F3013 | 132 | 0.1% |
42516A | 123 | 0.1% |
D3D2CF | 110 | 0.1% |
F5F5F5 | 96 | 0.1% |
DEDEDE | 96 | 0.1% |
DFDFDF | 94 | 0.1% |
D9B17E | 90 | 0.1% |
Other values (240) | 1180 | 1.2% |
(Missing) | 63841 | 64.9% |

retweeted_status_user_profile_sidebar_fill_color
Categorical

Distinct count | 509
Unique (%) | 1.5%
Missing (%) | 64.9%
Missing (n) | 63841

DDEEF6 | 16163
000000 | 5181
252429 | 2683
Other values (505) | 10525
(Missing) | 63841

Toggle details

Value | Count | Frequency (%) |
DDEEF6 | 16163 | 16.4% |
000000 | 5181 | 5.3% |
252429 | 2683 | 2.7% |
EFEFEF | 1788 | 1.8% |
95E8EC | 984 | 1.0% |
C0DFEC | 763 | 0.8% |
CAD9D8 | 661 | 0.7% |
F6F6F6 | 557 | 0.6% |
FFFFFF | 535 | 0.5% |
DDFFCC | 367 | 0.4% |
E0FF92 | 290 | 0.3% |
DAECF4 | 276 | 0.3% |
DE3B97 | 252 | 0.3% |
99CC33 | 235 | 0.2% |
A0C5C7 | 205 | 0.2% |
7AC3EE | 196 | 0.2% |
E3E2DE | 168 | 0.2% |
9CED76 | 132 | 0.1% |
EEEEEE | 130 | 0.1% |
F3F3F3 | 128 | 0.1% |
Other values (488) | 2858 | 2.9% |
(Missing) | 63841 | 64.9% |

retweeted_status_user_profile_text_color
Categorical

Distinct count | 398
Unique (%) | 1.2%
Missing (%) | 64.9%
Missing (n) | 63841

333333 | 20866
000000 | 6011
666666 | 2596
Other values (394) | 5079
(Missing) | 63841

Toggle details

Value | Count | Frequency (%) |
333333 | 20866 | 21.2% |
000000 | 6011 | 6.1% |
666666 | 2596 | 2.6% |
3C3940 | 987 | 1.0% |
3E4415 | 921 | 0.9% |
663B12 | 277 | 0.3% |
F651E0 | 252 | 0.3% |
3D1957 | 197 | 0.2% |
634047 | 166 | 0.2% |
949294 | 145 | 0.1% |
269434 | 132 | 0.1% |
853A49 | 116 | 0.1% |
4A4A4A | 97 | 0.1% |
005523 | 77 | 0.1% |
362720 | 67 | 0.1% |
2B2A2B | 66 | 0.1% |
777777 | 62 | 0.1% |
0C3E53 | 59 | 0.1% |
6B6B6B | 55 | 0.1% |
2A2C2B | 54 | 0.1% |
Other values (377) | 1349 | 1.4% |
(Missing) | 63841 | 64.9% |

retweeted_status_user_profile_use_background_image
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63841

True | 27860
False | 6692
(Missing) | 63841

Toggle details

Value | Count | Frequency (%) |
True | 27860 | 28.3% |
False | 6692 | 6.8% |
(Missing) | 63841 | 64.9% |

retweeted_status_user_protected
Categorical

Distinct count | 2
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63841

False | 34552
(Missing) | 63841

Toggle details

Value | Count | Frequency (%) |
False | 34552 | 35.1% |
(Missing) | 63841 | 64.9% |

retweeted_status_user_screen_name
Categorical

Distinct count | 6485
Unique (%) | 18.8%
Missing (%) | 64.9%
Missing (n) | 63841

msisodia | 1809
randal_olson | 885
KirkDBorne | 702
Other values (6481) | 31156
(Missing) | 63841

Toggle details

Value | Count | Frequency (%) |
msisodia | 1809 | 1.8% |
randal_olson | 885 | 0.9% |
KirkDBorne | 702 | 0.7% |
analyticbridge | 661 | 0.7% |
kdnuggets | 481 | 0.5% |
PythonWeekly | 362 | 0.4% |
Delilah_Alvares | 308 | 0.3% |
FTWDFans | 263 | 0.3% |
pythontrending | 258 | 0.3% |
binitamshah | 252 | 0.3% |
jobfindlypython | 224 | 0.2% |
cho79596190 | 220 | 0.2% |
odsc | 200 | 0.2% |
JobHero_io | 194 | 0.2% |
lennincaro | 193 | 0.2% |
PythonRR | 188 | 0.2% |
RickKing16 | 176 | 0.2% |
javacodegeeks | 173 | 0.2% |
mikegrimshaw2 | 170 | 0.2% |
SciPyTip | 165 | 0.2% |
Other values (6464) | 26668 | 27.1% |
(Missing) | 63841 | 64.9% |

retweeted_status_user_statuses_count
Numeric

Distinct count | 5927
Unique (%) | 17.2%
Missing (%) | 64.9%
Missing (n) | 63841

Mean | 25505
Minimum | 1
Maximum | 1235400
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 1
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 1235400
Range | 1235400
Interquartile range |

Descriptive statistics

Standard deviation | 58313
Coef of variation | 2.2863
Kurtosis | 79.438
Mean | 25505
MAD | 29516
Skewness | 6.9428
Sum | 881260000
Variance | 3400400000
Memory size | 768.8 KiB

retweeted_status_user_time_zone
Categorical

Distinct count | 142
Unique (%) | 0.6%
Missing (%) | 74.3%
Missing (n) | 73090

Pacific Time (US & Canada) | 6162
Eastern Time (US & Canada) | 6009
London | 1928
Other values (138) | 11204
(Missing) | 73090

Toggle details

Value | Count | Frequency (%) |
Pacific Time (US & Canada) | 6162 | 6.3% |
Eastern Time (US & Canada) | 6009 | 6.1% |
London | 1928 | 2.0% |
Central Time (US & Canada) | 1698 | 1.7% |
Amsterdam | 589 | 0.6% |
Athens | 536 | 0.5% |
Berlin | 496 | 0.5% |
Atlantic Time (Canada) | 493 | 0.5% |
Paris | 481 | 0.5% |
Quito | 460 | 0.5% |
New Delhi | 395 | 0.4% |
Madrid | 337 | 0.3% |
Mountain Time (US & Canada) | 336 | 0.3% |
Rome | 316 | 0.3% |
Arizona | 265 | 0.3% |
Brasilia | 232 | 0.2% |
Brussels | 207 | 0.2% |
Caracas | 204 | 0.2% |
Dublin | 194 | 0.2% |
Sydney | 168 | 0.2% |
Other values (121) | 3797 | 3.9% |
(Missing) | 73090 | 74.3% |

retweeted_status_user_url
Categorical

Distinct count | 4471
Unique (%) | 16.2%
Missing (%) | 71.9%
Missing (n) | 70757

http://t.co/4JAW1UO9Y8 | 1809
https://t.co/tpzAYxx9cq | 885
https://t.co/tWlmeuTlR7 | 702
Other values (4467) | 24240
(Missing) | 70757

Toggle details

Value | Count | Frequency (%) |
http://t.co/4JAW1UO9Y8 | 1809 | 1.8% |
https://t.co/tpzAYxx9cq | 885 | 0.9% |
https://t.co/tWlmeuTlR7 | 702 | 0.7% |
http://t.co/43tj0Ez1jT | 661 | 0.7% |
http://t.co/aWUY84onbG | 481 | 0.5% |
http://t.co/D1OMRitAIv | 362 | 0.4% |
https://t.co/B2AdRQDuaf | 308 | 0.3% |
https://t.co/bPrpNFHP42 | 258 | 0.3% |
https://t.co/LfZIicBDza | 252 | 0.3% |
https://t.co/LvNObmuCkf | 224 | 0.2% |
https://t.co/UBbHYS8ReL | 200 | 0.2% |
https://t.co/wXDyVzfUM0 | 194 | 0.2% |
http://t.co/PVtXT9K1OX | 188 | 0.2% |
http://t.co/DivczES801 | 173 | 0.2% |
https://t.co/vrO1K4Vzvf | 170 | 0.2% |
https://t.co/vtMHCfZpoO | 165 | 0.2% |
http://t.co/kgJqUNDMpy | 164 | 0.2% |
https://t.co/Xm6V2081pG | 162 | 0.2% |
http://t.co/OuWBVQWCpU | 157 | 0.2% |
https://t.co/o7Zlm2tvAr | 150 | 0.2% |
Other values (4450) | 19971 | 20.3% |
(Missing) | 70757 | 71.9% |

retweeted_status_user_utc_offset
Numeric

Distinct count | 29
Unique (%) | 0.1%
Missing (%) | 74.3%
Missing (n) | 73090

Mean | -9104.8
Minimum | -39600
Maximum | 46800
Zeros (%) | 0.1%

Toggle details

Quantile statistics

Minimum | -39600
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 46800
Range | 86400
Interquartile range |

Descriptive statistics

Standard deviation | 15863
Coef of variation | -1.7422
Kurtosis | -0.062692
Mean | -9104.8
MAD | 13502
Skewness | 0.8389
Sum | -230380000
Variance | 251620000
Memory size | 768.8 KiB

retweeted_status_user_verified
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 64.9%
Missing (n) | 63841

False | 31064
True | 3488
(Missing) | 63841

Toggle details

Value | Count | Frequency (%) |
False | 31064 | 31.6% |
True | 3488 | 3.5% |
(Missing) | 63841 | 64.9% |

source
Categorical

Distinct count | 1681
Unique (%) | 1.7%
Missing (%) | 0.8%
Missing (n) | 767

Twitter Web Client | 16142
IFTTT | 13634
Twitter for Android | 11177
Other values (1677) | 56673

Toggle details

Value | Count | Frequency (%) |
Twitter Web Client | 16142 | 16.4% |
IFTTT | 13634 | 13.9% |
Twitter for Android | 11177 | 11.4% |
Twitter for iPhone | 10030 | 10.2% |
dlvr.it | 5150 | 5.2% |
jobfindly python jobs | 3254 | 3.3% |
twitterfeed | 3182 | 3.2% |
Python RT Bot | 2920 | 3.0% |
TweetDeck | 2606 | 2.6% |
Facebook | 2438 | 2.5% |
Hootsuite | 1771 | 1.8% |
Buffer | 1615 | 1.6% |
RoundTeam | 1474 | 1.5% |
Google | 1054 | 1.1% |
Twitter for iPad | 1011 | 1.0% |
Twittertest145368 | 684 | 0.7% |
Cheap Bots, Done Quick! | 559 | 0.6% |
Instagram | 499 | 0.5% |
Twitter for Mac | 490 | 0.5% |
SocialOomph | 478 | 0.5% |
Other values (1660) | 17458 | 17.7% |
(Missing) | 767 | 0.8% |

text
Categorical

Distinct count | 71549
Unique (%) | 72.7%
Missing (%) | 0.0%
Missing (n) | 12

'RT @msisodia: One should understand Sanskrit is the only language which can compete with C++, Java, SOL, Python, Javascript...1/2 https://t\xe2\x80\xa6' | 944
'RT @msisodia: All computers in India using languages like C+, Java, SOL, Python..should b declared antinational once IITians learn working\xe2\x80\xa6' | 865
"RT @Delilah_Alvares: Rmbr d friendly python? Dis could've been of him (its not)\nBt did V need to take a life?\n#CallOfTheWild #SaveTheWild h\xe2\x80\xa6" | 308
Other values (71545) | 96264

Toggle details

Value | Count | Frequency (%) |
'RT @msisodia: One should understand Sanskrit is the only language which can compete with C++, Java, SOL, Python, Javascript...1/2 https://t\xe2\x80\xa6' | 944 | 1.0% |
'RT @msisodia: All computers in India using languages like C+, Java, SOL, Python..should b declared antinational once IITians learn working\xe2\x80\xa6' | 865 | 0.9% |
"RT @Delilah_Alvares: Rmbr d friendly python? Dis could've been of him (its not)\nBt did V need to take a life?\n#CallOfTheWild #SaveTheWild h\xe2\x80\xa6" | 308 | 0.3% |
'RT @randal_olson: #Google has started a new #Python #MachineLearning course on YouTube. #sklearn\n\nhttps://t.co/WDFEUdyrbS https://t.co/aoMn\xe2\x80\xa6' | 290 | 0.3% |
"RT @FTWDFans: Best #TWD signature weapon!\n\xe2\x80\xa2 Round of 8 \xe2\x80\xa2\n\nRT ~ Rick Grimes' Colt Python\nLIKE ~ Tyreese's Hammer\n\n#TheWalkingDead https://t.\xe2\x80\xa6" | 263 | 0.3% |
RT @cho79596190: Big Snake Fight | Snake Fight Till Death | Cobra Vs Python Vs Anaconda https://t.co/m4576sRH5a | 220 | 0.2% |
'RT @randal_olson: Ubuntu 16.04 LTS released with #Python 3.5 as standard, rather than Python 2.7! Progress!\n\nhttps://t.co/0dEyFM6sVd https:\xe2\x80\xa6' | 171 | 0.2% |
RT @SneakerPics23: Python Custom Yeezy 350 Boosts https://t.co/qpdP0DUKAu | 150 | 0.2% |
RT @kubernan: Microservices and Python | DevOpsSummit #DevOps #IoT #Microservices https://t.co/99ttVa37RC #Cloud | 145 | 0.1% |
'RT @fashionkiIIas: Custom Yeezy Boost 350\xe2\x80\x99s with genuine tan python. https://t.co/bmzH4MVi94' | 139 | 0.1% |
RT @alicegoldfuss: Guy: *points at my shirt* there should be a semicolon at the end Me: it's Python | 133 | 0.1% |
'RT @KirkDBorne: Why #MachineLearning with #Python is the best combination: https://t.co/hOdcRLTG0k #abdsc #BigData #DataScience https://t.c\xe2\x80\xa6' | 126 | 0.1% |
'RT @craigbrownphd: Top news: Machine Learning with Python- Why do they form the best combination -\xe2\x80\xa6 https://t.co/5mCv2YPZPT, see more https\xe2\x80\xa6' | 125 | 0.1% |
'RT @SkeetWarrior_: Python stroke game tho....\xf0\x9f\x91\x8c https://t.co/jbLCwPRmqI' | 116 | 0.1% |
RT @evilsocket: How I defeated an obfuscated and anti-tamper APK with some Python and a home-made Smali emulator. https://t.co/qhwzvuhl1t | 111 | 0.1% |
RT @binitamshah: Awesome Python : A curated list of awesome Python frameworks, packages, software and resources : https://t.co/IW0kXRWfom | 105 | 0.1% |
'RT @spazef0rze: ICYMI: A simple Python script which will fetch credentials and list proxies for #Opera #VPN https://t.co/1kG77yMvJ2 https:/\xe2\x80\xa6' | 97 | 0.1% |
"RT @500px: Today's #coloroftheday is High Risk Red. #TravelTuesday inspiration by Scarlet Starlet: https://t.co/mO4MqPAzTX https://t.co/BjA\xe2\x80\xa6" | 96 | 0.1% |
'RT @UN: Calling all programmers! Challenge yourself w/ #Electricity4All challenge https://t.co/TLsTPzBGel via @UN_UniteIdeas https://t.co/T\xe2\x80\xa6' | 95 | 0.1% |
RT @randal_olson: The Zen of #Python, illustrated. #programming https://t.co/AebCARp3iO https://t.co/TRNOy1vJXi | 93 | 0.1% |
Other values (71528) | 93789 | 95.3% |

truncated
Categorical

Distinct count | 2
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 12

False | 98381
(Missing) | 12

Toggle details

Value | Count | Frequency (%) |
False | 98381 | 100.0% |
(Missing) | 12 | 0.0% |

user_contributors_enabled
Categorical

Distinct count | 2
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 12

False | 98381
(Missing) | 12

Toggle details

Value | Count | Frequency (%) |
False | 98381 | 100.0% |
(Missing) | 12 | 0.0% |

user_created_at
Categorical

Distinct count | 37931
Unique (%) | 38.6%
Missing (%) | 0.0%
Missing (n) | 12

Wed Dec 23 16:22:14 +0000 2015 | 3254
Tue Nov 06 05:44:46 +0000 2012 | 3035
Sat Dec 05 13:21:09 +0000 2015 | 2920
Other values (37927) | 89172

Toggle details

Value | Count | Frequency (%) |
Wed Dec 23 16:22:14 +0000 2015 | 3254 | 3.3% |
Tue Nov 06 05:44:46 +0000 2012 | 3035 | 3.1% |
Sat Dec 05 13:21:09 +0000 2015 | 2920 | 3.0% |
Thu Dec 17 14:01:09 +0000 2015 | 930 | 0.9% |
Thu Dec 24 08:02:08 +0000 2015 | 922 | 0.9% |
Wed Dec 23 07:01:41 +0000 2015 | 912 | 0.9% |
Sat Nov 28 11:03:01 +0000 2015 | 892 | 0.9% |
Wed Aug 05 03:47:32 +0000 2015 | 842 | 0.9% |
Thu Jul 17 12:12:55 +0000 2014 | 710 | 0.7% |
Sun Apr 10 19:39:41 +0000 2016 | 685 | 0.7% |
Mon Jul 14 14:18:44 +0000 2014 | 675 | 0.7% |
Thu Apr 23 07:23:04 +0000 2015 | 484 | 0.5% |
Sat Jan 09 13:59:00 +0000 2016 | 431 | 0.4% |
Tue May 08 19:54:45 +0000 2012 | 396 | 0.4% |
Sun Mar 01 15:48:00 +0000 2015 | 375 | 0.4% |
Sat Jun 08 13:36:41 +0000 2013 | 375 | 0.4% |
Sun Jul 21 17:32:57 +0000 2013 | 354 | 0.4% |
Sun Apr 29 10:41:11 +0000 2012 | 341 | 0.3% |
Fri Apr 08 15:39:56 +0000 2016 | 337 | 0.3% |
Thu Dec 05 19:01:21 +0000 2013 | 301 | 0.3% |
Other values (37910) | 79210 | 80.5% |

user_default_profile
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 12

False | 50800
True | 47581
(Missing) | 12

Toggle details

Value | Count | Frequency (%) |
False | 50800 | 51.6% |
True | 47581 | 48.4% |
(Missing) | 12 | 0.0% |

user_default_profile_image
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 12

False | 95559
True | 2822
(Missing) | 12

Toggle details

Value | Count | Frequency (%) |
False | 95559 | 97.1% |
True | 2822 | 2.9% |
(Missing) | 12 | 0.0% |

user_description
Categorical

Distinct count | 27457
Unique (%) | 36.1%
Missing (%) | 22.7%
Missing (n) | 22323

View all available Python Developer jobs from company sites, job boards and the web at https://t.co/X9YF9QW4pC - thousands of new jobs added daily! | 3254
We've had our share of hard times, But that's the price we paid And through it all we kept the promise that we made, I swear you'll never be lonely. | 3035
I am a bot that cares about everything Python! Created by @masnun | 2920
Other values (27453) | 66861
(Missing) | 22323

Toggle details

Value | Count | Frequency (%) |
View all available Python Developer jobs from company sites, job boards and the web at https://t.co/X9YF9QW4pC - thousands of new jobs added daily! | 3254 | 3.3% |
We've had our share of hard times, But that's the price we paid And through it all we kept the promise that we made, I swear you'll never be lonely. | 3035 | 3.1% |
I am a bot that cares about everything Python! Created by @masnun | 2920 | 3.0% |
Music,sports,photografy,travel,shopping,internet | 1559 | 1.6% |
Daily #Programming Issues: Stay connected & Stay Updated. #JS #HTML #CSS #PHP etc. | 922 | 0.9% |
Daily #Technology Issues & solutions: The height quality on going #Technology events, #news and #information through. Stay connected & keep updated yourself. | 892 | 0.9% |
Learn Python Programming in Delhi NCR #Python Classes in Gurgaon (Age: 9 to 90 Years) #PythonGurgaon #Programming #Data #Coding #R #Gurgaon #DelhiNCR #Analytics | 842 | 0.9% |
Python Jobs - Follow this account for Python job tweets | 710 | 0.7% |
I tweet about Python, tech, and some of the most random things you can imagine. | 685 | 0.7% |
Follow this account for PYTHON job tweets from ITJobPro the biggest IT job site on the planet. more at http://t.co/kLxn6Xf2Cs | 675 | 0.7% |
Latest #IT, #Programming, #Tech questions. Yet Unsolved Questions. | 431 | 0.4% |
Bid at the last second on Ebay FREE | 413 | 0.4% |
News & links about Python programming. | 396 | 0.4% |
Auto-retweeting Python tweets from the accounts we follow - enjoy! | 375 | 0.4% |
For website development, tech consultant, agile development, mobile development and project management contact me khaninejad@gmail.com | 359 | 0.4% |
Our mission is to provide high quality #technology & #programming information's through our website. | 301 | 0.3% |
Teaching practical programming through real-world applications | 243 | 0.2% |
Live content curated by top Python Influencers | 232 | 0.2% |
I'm a robot. Powered by Cheap Bots Done Quick! | 194 | 0.2% |
3D, science, visualization, sketching, experimentation & fun raspberry projects | 189 | 0.2% |
Other values (27436) | 57443 | 58.4% |
(Missing) | 22323 | 22.7% |

user_entities_description_urls
Categorical

Distinct count | 2671
Unique (%) | 2.7%
Missing (%) | 1.1%
Missing (n) | 1074

[] | 86822
[{u'url': u'https://t.co/X9YF9QW4pC', u'indices': [87, 110], u'expanded_url': u'http://jobfindly.com', u'display_url': u'jobfindly.com'}] | 2704
[{u'url': u'http://t.co/kLxn6Xf2Cs', u'indices': [103, 125], u'expanded_url': u'http://www.ITJobPro.com', u'display_url': u'ITJobPro.com'}] | 553
Other values (2667) | 7240
(Missing) | 1074

Toggle details

Value | Count | Frequency (%) |
[] | 86822 | 88.2% |
[{u'url': u'https://t.co/X9YF9QW4pC', u'indices': [87, 110], u'expanded_url': u'http://jobfindly.com', u'display_url': u'jobfindly.com'}] | 2704 | 2.7% |
[{u'url': u'http://t.co/kLxn6Xf2Cs', u'indices': [103, 125], u'expanded_url': u'http://www.ITJobPro.com', u'display_url': u'ITJobPro.com'}] | 553 | 0.6% |
[{u'indices': [87, 110], u'url': u'https://t.co/X9YF9QW4pC', u'expanded_url': u'http://jobfindly.com', u'display_url': u'jobfindly.com'}] | 550 | 0.6% |
[{u'url': u'https://t.co/k0vLqXpCe0', u'indices': [134, 157], u'expanded_url': u'http://www.pythondiario.com', u'display_url': u'pythondiario.com'}] | 315 | 0.3% |
[{u'url': u'https://t.co/nOHhViYGqn', u'indices': [12, 35], u'expanded_url': u'http://Livecoding.tv', u'display_url': u'Livecoding.tv'}] | 160 | 0.2% |
[{u'indices': [103, 125], u'url': u'http://t.co/kLxn6Xf2Cs', u'expanded_url': u'http://www.ITJobPro.com', u'display_url': u'ITJobPro.com'}] | 122 | 0.1% |
[{u'url': u'https://t.co/X9YF9QW4pC', u'indices': [74, 97], u'expanded_url': u'http://jobfindly.com', u'display_url': u'jobfindly.com'}] | 107 | 0.1% |
[{u'url': u'http://t.co/rHlyfe7p7r', u'indices': [36, 58], u'expanded_url': u'http://SimbaSystems.com', u'display_url': u'SimbaSystems.com'}] | 96 | 0.1% |
[{u'url': u'https://t.co/Az4W3JfVDi', u'indices': [130, 153], u'expanded_url': u'http://www.JobHero.io', u'display_url': u'JobHero.io'}] | 73 | 0.1% |
[{u'url': u'https://t.co/X9YF9QW4pC', u'indices': [85, 108], u'expanded_url': u'http://jobfindly.com', u'display_url': u'jobfindly.com'}] | 67 | 0.1% |
[{u'url': u'https://t.co/DtzsVwixrY', u'indices': [116, 139], u'expanded_url': u'http://cesarnogueira.strikingly.com', u'display_url': u'cesarnogueira.strikingly.com'}] | 64 | 0.1% |
[{u'url': u'https://t.co/jGalvTuMDJ', u'indices': [107, 130], u'expanded_url': u'http://bit.ly/1jweClX', u'display_url': u'bit.ly/1jweClX'}] | 64 | 0.1% |
[{u'indices': [134, 157], u'url': u'https://t.co/k0vLqXpCe0', u'expanded_url': u'http://www.pythondiario.com', u'display_url': u'pythondiario.com'}] | 60 | 0.1% |
[{u'url': u'http://t.co/kzmQwJIxfD', u'indices': [108, 130], u'expanded_url': u'http://RDAHealthcare.com', u'display_url': u'RDAHealthcare.com'}] | 59 | 0.1% |
[{u'url': u'https://t.co/8BDMCGIRGL', u'indices': [116, 139], u'expanded_url': u'http://twitch.tv/ultraz_python', u'display_url': u'twitch.tv/ultraz_python'}] | 59 | 0.1% |
[{u'url': u'https://t.co/D7cuGXA0dl', u'indices': [84, 107], u'expanded_url': u'http://damianofusco.com', u'display_url': u'damianofusco.com'}] | 57 | 0.1% |
[{u'url': u'https://t.co/ipcaEoDUNy', u'indices': [0, 23], u'expanded_url': u'http://recuweb.com', u'display_url': u'recuweb.com'}] | 52 | 0.1% |
[{u'url': u'https://t.co/gpyYZwA8Tl', u'indices': [85, 108], u'expanded_url': u'http://dustcloud.io', u'display_url': u'dustcloud.io'}] | 44 | 0.0% |
[{u'url': u'http://t.co/QVTIJZCdlx', u'indices': [106, 128], u'expanded_url': u'http://PentesterAcademy.com', u'display_url': u'PentesterAcademy.com'}, {u'url': u'http://t.co/0vm0BnkqLa', u'indices': [132, 154], u'expanded_url': u'http://Securitytube-Training.com', u'display_url': u'Securitytube-Training.com'}] | 42 | 0.0% |
Other values (2650) | 5249 | 5.3% |
(Missing) | 1074 | 1.1% |

user_entities_url_urls
Categorical

Distinct count | 19771
Unique (%) | 38.4%
Missing (%) | 47.7%
Missing (n) | 46930

[{u'indices': [0, 23], u'url': u'https://t.co/Hl1m7P4xmV', u'expanded_url': u'http://masnun.me', u'display_url': u'masnun.me'}] | 2133
[{u'url': u'http://t.co/8Q0jl1AtKI', u'indices': [0, 22], u'expanded_url': u'http://immortal.ucoz.com', u'display_url': u'immortal.ucoz.com'}] | 1973
[{u'indices': [0, 22], u'url': u'http://t.co/8Q0jl1AtKI', u'expanded_url': u'http://immortal.ucoz.com', u'display_url': u'immortal.ucoz.com'}] | 1062
Other values (19767) | 46295
(Missing) | 46930

Toggle details

Value | Count | Frequency (%) |
[{u'indices': [0, 23], u'url': u'https://t.co/Hl1m7P4xmV', u'expanded_url': u'http://masnun.me', u'display_url': u'masnun.me'}] | 2133 | 2.2% |
[{u'url': u'http://t.co/8Q0jl1AtKI', u'indices': [0, 22], u'expanded_url': u'http://immortal.ucoz.com', u'display_url': u'immortal.ucoz.com'}] | 1973 | 2.0% |
[{u'indices': [0, 22], u'url': u'http://t.co/8Q0jl1AtKI', u'expanded_url': u'http://immortal.ucoz.com', u'display_url': u'immortal.ucoz.com'}] | 1062 | 1.1% |
[{u'url': u'https://t.co/P4ba2SMKJa', u'indices': [0, 23], u'expanded_url': u'http://goo.gl/UY8WFO', u'display_url': u'goo.gl/UY8WFO'}] | 798 | 0.8% |
[{u'url': u'https://t.co/PygshDFQhI', u'indices': [0, 23], u'expanded_url': u'http://goo.gl/TgRN9d', u'display_url': u'goo.gl/TgRN9d'}] | 793 | 0.8% |
[{u'url': u'https://t.co/Hl1m7P4xmV', u'indices': [0, 23], u'expanded_url': u'http://masnun.me', u'display_url': u'masnun.me'}] | 788 | 0.8% |
[{u'url': u'https://t.co/ZxdvO1ZaiT', u'indices': [0, 23], u'expanded_url': u'http://goo.gl/Q5C3zU', u'display_url': u'goo.gl/Q5C3zU'}] | 786 | 0.8% |
[{u'url': u'https://t.co/34LPPFZfCm', u'indices': [0, 23], u'expanded_url': u'http://goo.gl/01bWHF', u'display_url': u'goo.gl/01bWHF'}] | 784 | 0.8% |
[{u'url': u'http://t.co/kLxn6Xf2Cs', u'indices': [0, 22], u'expanded_url': u'http://www.ITJobPro.com', u'display_url': u'ITJobPro.com'}] | 608 | 0.6% |
[{u'url': u'https://t.co/w7yC4guo2R', u'indices': [0, 23], u'expanded_url': u'http://goo.gl/HMTN68', u'display_url': u'goo.gl/HMTN68'}] | 382 | 0.4% |
[{u'url': u'http://t.co/1m4ijr2w8A', u'indices': [0, 22], u'expanded_url': u'http://www.pythondiario.com', u'display_url': u'pythondiario.com'}] | 315 | 0.3% |
[{u'url': u'https://t.co/wNpsm4ziGC', u'indices': [0, 23], u'expanded_url': u'http://goo.gl/hFqZa2', u'display_url': u'goo.gl/hFqZa2'}] | 259 | 0.3% |
[{u'url': u'https://t.co/VSX5CctduJ', u'indices': [0, 23], u'expanded_url': u'http://dragplus.com/page/python', u'display_url': u'dragplus.com/page/python'}] | 238 | 0.2% |
[{u'indices': [0, 23], u'url': u'https://t.co/ZxdvO1ZaiT', u'expanded_url': u'http://goo.gl/Q5C3zU', u'display_url': u'goo.gl/Q5C3zU'}] | 215 | 0.2% |
[{u'url': u'http://t.co/PVtXT9K1OX', u'indices': [0, 22], u'expanded_url': u'http://bit.ly/1uLmkxZ', u'display_url': u'bit.ly/1uLmkxZ'}] | 192 | 0.2% |
[{u'url': u'http://t.co/ZhoOQdg9HF', u'indices': [0, 22], u'expanded_url': u'http://RealPython.com', u'display_url': u'RealPython.com'}] | 190 | 0.2% |
[{u'url': u'https://t.co/dUzwcEMlDd', u'indices': [0, 23], u'expanded_url': u'http://www.youbidder.com/', u'display_url': u'youbidder.com'}] | 187 | 0.2% |
[{u'url': u'https://t.co/dUzwcEuKLF', u'indices': [0, 23], u'expanded_url': u'http://www.youbidder.com/', u'display_url': u'youbidder.com'}] | 178 | 0.2% |
[{u'url': u'https://t.co/nOHhViYGqn', u'indices': [0, 23], u'expanded_url': u'http://Livecoding.tv', u'display_url': u'Livecoding.tv'}] | 160 | 0.2% |
[{u'indices': [0, 22], u'url': u'http://t.co/kLxn6Xf2Cs', u'expanded_url': u'http://www.ITJobPro.com', u'display_url': u'ITJobPro.com'}] | 141 | 0.1% |
Other values (19750) | 39281 | 39.9% |
(Missing) | 46930 | 47.7% |

user_favourites_count
Numeric

Distinct count | 9311
Unique (%) | 9.5%
Missing (%) | 0.0%
Missing (n) | 14

Mean | 2610.8
Minimum | 0
Maximum | 661640
Zeros (%) | 25.4%

Toggle details

Quantile statistics

Minimum | 0
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 661640
Range | 661640
Interquartile range |

Descriptive statistics

Standard deviation | 11280
Coef of variation | 4.3205
Kurtosis | 282.33
Mean | 2610.8
MAD | 3999.6
Skewness | 12.066
Sum | 256850000
Variance | 127240000
Memory size | 768.8 KiB

user_followers_count
Numeric

Distinct count | 6617
Unique (%) | 6.7%
Missing (%) | 0.0%
Missing (n) | 14

Mean | 3093.8
Minimum | 0
Maximum | 10384000
Zeros (%) | 0.1%

Toggle details

Quantile statistics

Minimum | 0
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 10384000
Range | 10384000
Interquartile range |

Descriptive statistics

Standard deviation | 61975
Coef of variation | 20.032
Kurtosis | 15340
Mean | 3093.8
MAD | 4563.7
Skewness | 115.54
Sum | 304370000
Variance | 3841000000
Memory size | 768.8 KiB

user_friends_count
Numeric

Distinct count | 4727
Unique (%) | 4.8%
Missing (%) | 0.0%
Missing (n) | 14

Mean | 1291.9
Minimum | 0
Maximum | 382460
Zeros (%) | 8.1%

Toggle details

Quantile statistics

Minimum | 0
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 382460
Range | 382460
Interquartile range |

Descriptive statistics

Standard deviation | 5654.1
Coef of variation | 4.3767
Kurtosis | 785.76
Mean | 1291.9
MAD | 1592.9
Skewness | 20.519
Sum | 127090000
Variance | 31969000
Memory size | 768.8 KiB

user_geo_enabled
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 14

False | 74145
True | 24234
(Missing) | 14

Toggle details

Value | Count | Frequency (%) |
False | 74145 | 75.4% |
True | 24234 | 24.6% |
(Missing) | 14 | 0.0% |

user_has_extended_profile
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 14

False | 85583
True | 12796
(Missing) | 14

Toggle details

Value | Count | Frequency (%) |
False | 85583 | 87.0% |
True | 12796 | 13.0% |
(Missing) | 14 | 0.0% |

user_id
Numeric

Distinct count | 37932
Unique (%) | 38.6%
Missing (%) | 0.0%
Missing (n) | 14

Mean | 6.713e+16
Minimum | 22
Maximum | 7.2749e+17
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 22
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 7.2749e+17
Range | 7.2749e+17
Interquartile range |

Descriptive statistics

Standard deviation | 2.0859e+17
Coef of variation | 3.1073
Kurtosis | 5.7621
Mean | 6.713e+16
MAD | 1.2166e+17
Skewness | 2.7858
Sum | 6.6042e+21
Variance | 4.351e+34
Memory size | 768.8 KiB

user_id_str
Highly correlated

This variable is highly correlated with `user_id` and should be ignored for analysis

Correlation | 1

user_is_translation_enabled
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 14

False | 96076
True | 2303
(Missing) | 14

Toggle details

Value | Count | Frequency (%) |
False | 96076 | 97.6% |
True | 2303 | 2.3% |
(Missing) | 14 | 0.0% |

user_is_translator
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 14

False | 98352
True | 27
(Missing) | 14

Toggle details

Value | Count | Frequency (%) |
False | 98352 | 100.0% |
True | 27 | 0.0% |
(Missing) | 14 | 0.0% |

user_lang
Categorical

Distinct count | 52
Unique (%) | 0.1%
Missing (%) | 0.0%
Missing (n) | 14

en | 79424
es | 4966
en-gb | 4400
Other values (48) | 9589

Toggle details

Value | Count | Frequency (%) |
en | 79424 | 80.7% |
es | 4966 | 5.0% |
en-gb | 4400 | 4.5% |
fr | 2166 | 2.2% |
pl | 2102 | 2.1% |
de | 1072 | 1.1% |
ja | 654 | 0.7% |
it | 653 | 0.7% |
pt | 647 | 0.7% |
ru | 461 | 0.5% |
nl | 380 | 0.4% |
id | 193 | 0.2% |
en-GB | 125 | 0.1% |
ko | 113 | 0.1% |
zh-cn | 111 | 0.1% |
tr | 96 | 0.1% |
da | 90 | 0.1% |
th | 87 | 0.1% |
ca | 73 | 0.1% |
sv | 69 | 0.1% |
Other values (31) | 497 | 0.5% |

user_listed_count
Numeric

Distinct count | 1978
Unique (%) | 2.0%
Missing (%) | 0.0%
Missing (n) | 14

Mean | 349.9
Minimum | 0
Maximum | 95363
Zeros (%) | 3.8%

Toggle details

Quantile statistics

Minimum | 0
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 95363
Range | 95363
Interquartile range |

Descriptive statistics

Standard deviation | 1054
Coef of variation | 3.0123
Kurtosis | 778.3
Mean | 349.9
MAD | 427.61
Skewness | 15.136
Sum | 34422000
Variance | 1110900
Memory size | 768.8 KiB

user_location
Categorical

Distinct count | 11672
Unique (%) | 16.9%
Missing (%) | 29.9%
Missing (n) | 29408

United States | 3834
Yogyakarta | 3037
Khulna, Bangladesh | 2922
Other values (11668) | 59192
(Missing) | 29408

Toggle details

Value | Count | Frequency (%) |
United States | 3834 | 3.9% |
Yogyakarta | 3037 | 3.1% |
Khulna, Bangladesh | 2922 | 3.0% |
USA | 2495 | 2.5% |
New York, USA | 2028 | 2.1% |
Worldwide | 1869 | 1.9% |
FR | 922 | 0.9% |
RU | 912 | 0.9% |
CN | 892 | 0.9% |
Gurgaon, Haryana, India | 844 | 0.9% |
San Francisco, CA | 595 | 0.6% |
India | 578 | 0.6% |
London | 572 | 0.6% |
UK | 450 | 0.5% |
New York, NY | 417 | 0.4% |
Seattle, WA | 395 | 0.4% |
London, England | 392 | 0.4% |
Uruguay | 383 | 0.4% |
Brighton & Hove, UK | 376 | 0.4% |
Boston, MA | 333 | 0.3% |
Other values (11651) | 44739 | 45.5% |
(Missing) | 29408 | 29.9% |

user_name
Categorical

Distinct count | 34039
Unique (%) | 36.5%
Missing (%) | 5.3%
Missing (n) | 5255

Python Dev Jobs | 3254
Arteri Wisanggeni | 3035
Python RT Bot | 2920
Other values (34035) | 83929
(Missing) | 5255

Toggle details

Value | Count | Frequency (%) |
Python Dev Jobs | 3254 | 3.3% |
Arteri Wisanggeni | 3035 | 3.1% |
Python RT Bot | 2920 | 3.0% |
Micheal Hartwig | 1031 | 1.0% |
Rahaman M | 930 | 0.9% |
Star Tech Wall | 912 | 0.9% |
Daily Tech Issues | 892 | 0.9% |
Python Jobs | 883 | 0.9% |
Programming Gurgaon | 842 | 0.9% |
ThePythonNoob | 685 | 0.7% |
python Jobs | 675 | 0.7% |
LinuxFera | 484 | 0.5% |
Python Hub | 396 | 0.4% |
Cool Python | 375 | 0.4% |
PythonDiario | 375 | 0.4% |
Python Agent | 354 | 0.4% |
rssnest | 341 | 0.3% |
Jeffrey MacAskill | 337 | 0.3% |
Monally 67-K | 301 | 0.3% |
Python | 285 | 0.3% |
Other values (34018) | 73831 | 75.0% |
(Missing) | 5255 | 5.3% |

user_profile_background_color
Categorical

Distinct count | 2865
Unique (%) | 2.9%
Missing (%) | 0.0%
Missing (n) | 14

C0DEED | 36333
000000 | 16223
F5F8FA | 16206
Other values (2861) | 29617

Toggle details

Value | Count | Frequency (%) |
C0DEED | 36333 | 36.9% |
000000 | 16223 | 16.5% |
F5F8FA | 16206 | 16.5% |
131516 | 3783 | 3.8% |
FFFFFF | 3217 | 3.3% |
1A1B1F | 2618 | 2.7% |
022330 | 1877 | 1.9% |
FFF04D | 1204 | 1.2% |
0099B9 | 1124 | 1.1% |
9AE4E8 | 1105 | 1.1% |
C6E2EE | 917 | 0.9% |
352726 | 832 | 0.8% |
642D8B | 770 | 0.8% |
ACDED6 | 596 | 0.6% |
B2DFDA | 584 | 0.6% |
EBEBEB | 556 | 0.6% |
709397 | 508 | 0.5% |
EDECE9 | 446 | 0.5% |
D4D4D4 | 302 | 0.3% |
FF6699 | 295 | 0.3% |
Other values (2844) | 8883 | 9.0% |

user_profile_background_image_url
Categorical

Distinct count | 10149
Unique (%) | 12.3%
Missing (%) | 16.5%
Missing (n) | 16195

http://abs.twimg.com/images/themes/theme1/bg.png | 44281
http://abs.twimg.com/images/themes/theme14/bg.gif | 3340
http://pbs.twimg.com/profile_background_images/378800000113347361/14a4001fdcadb7bedc32306b371968c9.jpeg | 3035
Other values (10145) | 31542
(Missing) | 16195

Toggle details

Value | Count | Frequency (%) |
http://abs.twimg.com/images/themes/theme1/bg.png | 44281 | 45.0% |
http://abs.twimg.com/images/themes/theme14/bg.gif | 3340 | 3.4% |
http://pbs.twimg.com/profile_background_images/378800000113347361/14a4001fdcadb7bedc32306b371968c9.jpeg | 3035 | 3.1% |
http://abs.twimg.com/images/themes/theme9/bg.gif | 2274 | 2.3% |
http://abs.twimg.com/images/themes/theme15/bg.png | 1859 | 1.9% |
http://abs.twimg.com/images/themes/theme19/bg.gif | 1169 | 1.2% |
http://abs.twimg.com/images/themes/theme4/bg.gif | 1089 | 1.1% |
http://abs.twimg.com/images/themes/theme5/bg.gif | 806 | 0.8% |
http://abs.twimg.com/images/themes/theme18/bg.gif | 768 | 0.8% |
http://abs.twimg.com/images/themes/theme10/bg.gif | 701 | 0.7% |
http://abs.twimg.com/images/themes/theme2/bg.gif | 695 | 0.7% |
http://abs.twimg.com/images/themes/theme13/bg.gif | 574 | 0.6% |
http://abs.twimg.com/images/themes/theme7/bg.gif | 517 | 0.5% |
http://abs.twimg.com/images/themes/theme6/bg.gif | 460 | 0.5% |
http://abs.twimg.com/images/themes/theme11/bg.gif | 428 | 0.4% |
http://abs.twimg.com/images/themes/theme3/bg.gif | 413 | 0.4% |
http://abs.twimg.com/images/themes/theme16/bg.gif | 379 | 0.4% |
http://pbs.twimg.com/profile_background_images/378800000153451973/ONrDftuz.png | 301 | 0.3% |
http://abs.twimg.com/images/themes/theme17/bg.gif | 295 | 0.3% |
http://abs.twimg.com/images/themes/theme8/bg.gif | 266 | 0.3% |
Other values (10128) | 18548 | 18.9% |
(Missing) | 16195 | 16.5% |

user_profile_background_image_url_https
Categorical

Distinct count | 10149
Unique (%) | 12.3%
Missing (%) | 16.5%
Missing (n) | 16195

https://abs.twimg.com/images/themes/theme1/bg.png | 44281
https://abs.twimg.com/images/themes/theme14/bg.gif | 3340
https://pbs.twimg.com/profile_background_images/378800000113347361/14a4001fdcadb7bedc32306b371968c9.jpeg | 3035
Other values (10145) | 31542
(Missing) | 16195

Toggle details

Value | Count | Frequency (%) |
https://abs.twimg.com/images/themes/theme1/bg.png | 44281 | 45.0% |
https://abs.twimg.com/images/themes/theme14/bg.gif | 3340 | 3.4% |
https://pbs.twimg.com/profile_background_images/378800000113347361/14a4001fdcadb7bedc32306b371968c9.jpeg | 3035 | 3.1% |
https://abs.twimg.com/images/themes/theme9/bg.gif | 2274 | 2.3% |
https://abs.twimg.com/images/themes/theme15/bg.png | 1859 | 1.9% |
https://abs.twimg.com/images/themes/theme19/bg.gif | 1169 | 1.2% |
https://abs.twimg.com/images/themes/theme4/bg.gif | 1089 | 1.1% |
https://abs.twimg.com/images/themes/theme5/bg.gif | 806 | 0.8% |
https://abs.twimg.com/images/themes/theme18/bg.gif | 768 | 0.8% |
https://abs.twimg.com/images/themes/theme10/bg.gif | 701 | 0.7% |
https://abs.twimg.com/images/themes/theme2/bg.gif | 695 | 0.7% |
https://abs.twimg.com/images/themes/theme13/bg.gif | 574 | 0.6% |
https://abs.twimg.com/images/themes/theme7/bg.gif | 517 | 0.5% |
https://abs.twimg.com/images/themes/theme6/bg.gif | 460 | 0.5% |
https://abs.twimg.com/images/themes/theme11/bg.gif | 428 | 0.4% |
https://abs.twimg.com/images/themes/theme3/bg.gif | 413 | 0.4% |
https://abs.twimg.com/images/themes/theme16/bg.gif | 379 | 0.4% |
https://pbs.twimg.com/profile_background_images/378800000153451973/ONrDftuz.png | 301 | 0.3% |
https://abs.twimg.com/images/themes/theme17/bg.gif | 295 | 0.3% |
https://abs.twimg.com/images/themes/theme8/bg.gif | 266 | 0.3% |
Other values (10128) | 18548 | 18.9% |
(Missing) | 16195 | 16.5% |

user_profile_background_tile
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 14

False | 82798
True | 15581
(Missing) | 14

Toggle details

Value | Count | Frequency (%) |
False | 82798 | 84.2% |
True | 15581 | 15.8% |
(Missing) | 14 | 0.0% |

user_profile_banner_url
Categorical

Distinct count | 27131
Unique (%) | 42.8%
Missing (%) | 35.6%
Missing (n) | 35040

https://pbs.twimg.com/profile_banners/929084149/1384047845 | 3035
https://pbs.twimg.com/profile_banners/4584958124/1450362043 | 930
https://pbs.twimg.com/profile_banners/4641990870/1450947361 | 922
Other values (27127) | 58466
(Missing) | 35040

Toggle details

Value | Count | Frequency (%) |
https://pbs.twimg.com/profile_banners/929084149/1384047845 | 3035 | 3.1% |
https://pbs.twimg.com/profile_banners/4584958124/1450362043 | 930 | 0.9% |
https://pbs.twimg.com/profile_banners/4641990870/1450947361 | 922 | 0.9% |
https://pbs.twimg.com/profile_banners/4635820598/1450854576 | 912 | 0.9% |
https://pbs.twimg.com/profile_banners/4387442232/1448962831 | 892 | 0.9% |
https://pbs.twimg.com/profile_banners/2653603423/1409131763 | 710 | 0.7% |
https://pbs.twimg.com/profile_banners/2645582425/1405347580 | 675 | 0.7% |
https://pbs.twimg.com/profile_banners/3197146924/1429801967 | 484 | 0.5% |
https://pbs.twimg.com/profile_banners/4733645773/1452349946 | 431 | 0.4% |
https://pbs.twimg.com/profile_banners/1492944818/1414002980 | 375 | 0.4% |
https://pbs.twimg.com/profile_banners/3065738848/1425232512 | 375 | 0.4% |
https://pbs.twimg.com/profile_banners/2231898000/1433744813 | 301 | 0.3% |
https://pbs.twimg.com/profile_banners/715995842436579328/1459541835 | 194 | 0.2% |
https://pbs.twimg.com/profile_banners/723266701169680384/1461276660 | 189 | 0.2% |
https://pbs.twimg.com/profile_banners/4415348663/1455724217 | 173 | 0.2% |
https://pbs.twimg.com/profile_banners/3333416974/1434707660 | 157 | 0.2% |
https://pbs.twimg.com/profile_banners/1263046495/1458294232 | 148 | 0.2% |
https://pbs.twimg.com/profile_banners/1960996338/1452151408 | 146 | 0.1% |
https://pbs.twimg.com/profile_banners/781457996/1460647208 | 138 | 0.1% |
https://pbs.twimg.com/profile_banners/32970503/1399255152 | 136 | 0.1% |
Other values (27110) | 52030 | 52.9% |
(Missing) | 35040 | 35.6% |

user_profile_image_url
Categorical

Distinct count | 36954
Unique (%) | 37.6%
Missing (%) | 0.0%
Missing (n) | 14

http://pbs.twimg.com/profile_images/679698663698911232/sixEllZl_normal.jpg | 3254
http://pbs.twimg.com/profile_images/2813636657/599521f69e2bc210a57323b64d8e39e6_normal.jpeg | 3035
http://pbs.twimg.com/profile_images/673131136818667521/1fz-EhCP_normal.png | 2920
Other values (36950) | 89170

Toggle details

Value | Count | Frequency (%) |
http://pbs.twimg.com/profile_images/679698663698911232/sixEllZl_normal.jpg | 3254 | 3.3% |
http://pbs.twimg.com/profile_images/2813636657/599521f69e2bc210a57323b64d8e39e6_normal.jpeg | 3035 | 3.1% |
http://pbs.twimg.com/profile_images/673131136818667521/1fz-EhCP_normal.png | 2920 | 3.0% |
http://pbs.twimg.com/profile_images/677493910256484352/-EdVaVPl_normal.jpg | 930 | 0.9% |
http://pbs.twimg.com/profile_images/679948461953781761/pDo9356K_normal.jpg | 922 | 0.9% |
http://abs.twimg.com/sticky/default_profile_images/default_profile_4_normal.png | 913 | 0.9% |
http://pbs.twimg.com/profile_images/679566117187145728/UUo30Zpm_normal.jpg | 912 | 0.9% |
http://pbs.twimg.com/profile_images/671623862916812800/yGsDKiP4_normal.jpg | 892 | 0.9% |
http://pbs.twimg.com/profile_images/662602436222193664/qKuvsfnG_normal.jpg | 842 | 0.9% |
http://pbs.twimg.com/profile_images/489744857980620802/8Izpb7XG_normal.jpeg | 710 | 0.7% |
http://pbs.twimg.com/profile_images/719249208163717120/DgVQwdxD_normal.jpg | 685 | 0.7% |
http://pbs.twimg.com/profile_images/488689251236593664/pX4JrI1R_normal.png | 675 | 0.7% |
http://pbs.twimg.com/profile_images/591140429963329536/dvpnJvpI_normal.jpg | 484 | 0.5% |
http://abs.twimg.com/sticky/default_profile_images/default_profile_5_normal.png | 478 | 0.5% |
http://pbs.twimg.com/profile_images/685832525327933440/qpvcfSZK_normal.png | 431 | 0.4% |
http://pbs.twimg.com/profile_images/2213121578/icon_normal.png | 396 | 0.4% |
http://pbs.twimg.com/profile_images/524992384728178688/fydaiABp_normal.png | 375 | 0.4% |
http://pbs.twimg.com/profile_images/572091631055028224/Pkx__FSB_normal.png | 375 | 0.4% |
http://abs.twimg.com/sticky/default_profile_images/default_profile_3_normal.png | 369 | 0.4% |
http://pbs.twimg.com/profile_images/378800000166760298/a10833155e60c0a7e4c50713626893a9_normal.png | 354 | 0.4% |
Other values (36933) | 78427 | 79.7% |

user_profile_image_url_https
Categorical

Distinct count | 36954
Unique (%) | 37.6%
Missing (%) | 0.0%
Missing (n) | 14

https://pbs.twimg.com/profile_images/679698663698911232/sixEllZl_normal.jpg | 3254
https://pbs.twimg.com/profile_images/2813636657/599521f69e2bc210a57323b64d8e39e6_normal.jpeg | 3035
https://pbs.twimg.com/profile_images/673131136818667521/1fz-EhCP_normal.png | 2920
Other values (36950) | 89170

Toggle details

Value | Count | Frequency (%) |
https://pbs.twimg.com/profile_images/679698663698911232/sixEllZl_normal.jpg | 3254 | 3.3% |
https://pbs.twimg.com/profile_images/2813636657/599521f69e2bc210a57323b64d8e39e6_normal.jpeg | 3035 | 3.1% |
https://pbs.twimg.com/profile_images/673131136818667521/1fz-EhCP_normal.png | 2920 | 3.0% |
https://pbs.twimg.com/profile_images/677493910256484352/-EdVaVPl_normal.jpg | 930 | 0.9% |
https://pbs.twimg.com/profile_images/679948461953781761/pDo9356K_normal.jpg | 922 | 0.9% |
https://abs.twimg.com/sticky/default_profile_images/default_profile_4_normal.png | 913 | 0.9% |
https://pbs.twimg.com/profile_images/679566117187145728/UUo30Zpm_normal.jpg | 912 | 0.9% |
https://pbs.twimg.com/profile_images/671623862916812800/yGsDKiP4_normal.jpg | 892 | 0.9% |
https://pbs.twimg.com/profile_images/662602436222193664/qKuvsfnG_normal.jpg | 842 | 0.9% |
https://pbs.twimg.com/profile_images/489744857980620802/8Izpb7XG_normal.jpeg | 710 | 0.7% |
https://pbs.twimg.com/profile_images/719249208163717120/DgVQwdxD_normal.jpg | 685 | 0.7% |
https://pbs.twimg.com/profile_images/488689251236593664/pX4JrI1R_normal.png | 675 | 0.7% |
https://pbs.twimg.com/profile_images/591140429963329536/dvpnJvpI_normal.jpg | 484 | 0.5% |
https://abs.twimg.com/sticky/default_profile_images/default_profile_5_normal.png | 478 | 0.5% |
https://pbs.twimg.com/profile_images/685832525327933440/qpvcfSZK_normal.png | 431 | 0.4% |
https://pbs.twimg.com/profile_images/2213121578/icon_normal.png | 396 | 0.4% |
https://pbs.twimg.com/profile_images/572091631055028224/Pkx__FSB_normal.png | 375 | 0.4% |
https://pbs.twimg.com/profile_images/524992384728178688/fydaiABp_normal.png | 375 | 0.4% |
https://abs.twimg.com/sticky/default_profile_images/default_profile_3_normal.png | 369 | 0.4% |
https://pbs.twimg.com/profile_images/378800000166760298/a10833155e60c0a7e4c50713626893a9_normal.png | 354 | 0.4% |
Other values (36933) | 78427 | 79.7% |

user_profile_link_color
Categorical

Distinct count | 5376
Unique (%) | 5.5%
Missing (%) | 0.0%
Missing (n) | 14

0084B4 | 37873
2B7BB9 | 16182
3B94D9 | 4113
Other values (5372) | 40211

Toggle details

Value | Count | Frequency (%) |
0084B4 | 37873 | 38.5% |
2B7BB9 | 16182 | 16.4% |
3B94D9 | 4113 | 4.2% |
870202 | 3035 | 3.1% |
009999 | 2230 | 2.3% |
ABB8C2 | 1845 | 1.9% |
2FC2EF | 1833 | 1.9% |
4A913C | 1809 | 1.8% |
000000 | 1419 | 1.4% |
0099B9 | 1101 | 1.1% |
DD2E44 | 1068 | 1.1% |
1B95E0 | 931 | 0.9% |
9266CC | 888 | 0.9% |
FA743E | 852 | 0.9% |
0152A1 | 783 | 0.8% |
0151A1 | 763 | 0.8% |
1F98C7 | 758 | 0.8% |
FF0000 | 737 | 0.7% |
89C9FA | 728 | 0.7% |
038543 | 594 | 0.6% |
Other values (5355) | 18837 | 19.1% |

user_profile_sidebar_border_color
Categorical

Distinct count | 1061
Unique (%) | 1.1%
Missing (%) | 0.0%
Missing (n) | 14

C0DEED | 51014
000000 | 22259
FFFFFF | 10390
Other values (1057) | 14716

Toggle details

Value | Count | Frequency (%) |
C0DEED | 51014 | 51.8% |
000000 | 22259 | 22.6% |
FFFFFF | 10390 | 10.6% |
EEEEEE | 3203 | 3.3% |
181A1E | 1810 | 1.8% |
A8C7F7 | 1514 | 1.5% |
829D5E | 691 | 0.7% |
C6E2EE | 672 | 0.7% |
BDDCAD | 650 | 0.7% |
5ED4DC | 644 | 0.7% |
65B0DA | 428 | 0.4% |
DFDFDF | 424 | 0.4% |
D3D2CF | 346 | 0.4% |
86A4A6 | 340 | 0.3% |
87BC44 | 339 | 0.3% |
FFF8AD | 265 | 0.3% |
CC3366 | 237 | 0.2% |
D9B17E | 222 | 0.2% |
F2E195 | 204 | 0.2% |
DBE9ED | 158 | 0.2% |
Other values (1040) | 2569 | 2.6% |

user_profile_sidebar_fill_color
Categorical

Distinct count | 1950
Unique (%) | 2.0%
Missing (%) | 0.0%
Missing (n) | 14

DDEEF6 | 57378
000000 | 15936
95E8EC | 3854
Other values (1946) | 21211

Toggle details

Value | Count | Frequency (%) |
DDEEF6 | 57378 | 58.3% |
000000 | 15936 | 16.2% |
95E8EC | 3854 | 3.9% |
EFEFEF | 3609 | 3.7% |
252429 | 2614 | 2.7% |
C0DFEC | 1915 | 1.9% |
FFFFFF | 1185 | 1.2% |
DAECF4 | 880 | 0.9% |
DDFFCC | 843 | 0.9% |
99CC33 | 724 | 0.7% |
F6F6F6 | 660 | 0.7% |
7AC3EE | 583 | 0.6% |
F3F3F3 | 529 | 0.5% |
A0C5C7 | 489 | 0.5% |
E3E2DE | 446 | 0.5% |
F6FFD1 | 388 | 0.4% |
E0FF92 | 378 | 0.4% |
E5507E | 295 | 0.3% |
FFF7CC | 286 | 0.3% |
EADEAA | 272 | 0.3% |
Other values (1929) | 5115 | 5.2% |

user_profile_text_color
Categorical

Distinct count | 1602
Unique (%) | 1.6%
Missing (%) | 0.0%
Missing (n) | 14

333333 | 67420
000000 | 17070
3C3940 | 3871
Other values (1598) | 10018

Toggle details

Value | Count | Frequency (%) |
333333 | 67420 | 68.5% |
000000 | 17070 | 17.3% |
3C3940 | 3871 | 3.9% |
666666 | 2725 | 2.8% |
663B12 | 877 | 0.9% |
3E4415 | 852 | 0.9% |
3D1957 | 576 | 0.6% |
634047 | 437 | 0.4% |
362720 | 294 | 0.3% |
0C3E53 | 289 | 0.3% |
FF385F | 137 | 0.1% |
FFFFFF | 130 | 0.1% |
0084B4 | 77 | 0.1% |
448668 | 63 | 0.1% |
17406C | 52 | 0.1% |
618238 | 51 | 0.1% |
1D1325 | 49 | 0.0% |
269434 | 49 | 0.0% |
5E412F | 45 | 0.0% |
2A2C2B | 43 | 0.0% |
Other values (1581) | 3272 | 3.3% |

user_profile_use_background_image
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 14

True | 81400
False | 16979
(Missing) | 14

Toggle details

Value | Count | Frequency (%) |
True | 81400 | 82.7% |
False | 16979 | 17.3% |
(Missing) | 14 | 0.0% |

user_protected
Categorical

Distinct count | 2
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 14

False | 98379
(Missing) | 14

Toggle details

Value | Count | Frequency (%) |
False | 98379 | 100.0% |
(Missing) | 14 | 0.0% |

user_screen_name
Categorical

Distinct count | 37937
Unique (%) | 38.6%
Missing (%) | 0.0%
Missing (n) | 14

jobfindlypython | 3254
artwisanggeni | 3035
PythonRTBot | 2920
Other values (37933) | 89170

Toggle details

Value | Count | Frequency (%) |
jobfindlypython | 3254 | 3.3% |
artwisanggeni | 3035 | 3.1% |
PythonRTBot | 2920 | 3.0% |
MTotolrahaman | 930 | 0.9% |
HartwigMicheal | 922 | 0.9% |
startechwall | 912 | 0.9% |
AdamSmitht1 | 892 | 0.9% |
programmingncr | 842 | 0.9% |
python_IT_jobs | 710 | 0.7% |
ThePythonNoob | 685 | 0.7% |
python_job | 675 | 0.7% |
Linuxfera | 484 | 0.5% |
itntunes | 431 | 0.4% |
PythonHub | 396 | 0.4% |
cool_python | 375 | 0.4% |
PythonDiario | 375 | 0.4% |
Python_Agent | 354 | 0.4% |
rssnest | 341 | 0.3% |
Jeffrey_MacAsk | 337 | 0.3% |
GovsInfo | 301 | 0.3% |
Other values (37916) | 79208 | 80.5% |

user_statuses_count
Numeric

Distinct count | 23139
Unique (%) | 23.5%
Missing (%) | 0.0%
Missing (n) | 14

Mean | 63832
Minimum | 1
Maximum | 2357100
Zeros (%) | 0.0%

Toggle details

Quantile statistics

Minimum | 1
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 2357100
Range | 2357100
Interquartile range |

Descriptive statistics

Standard deviation | 137480
Coef of variation | 2.1538
Kurtosis | 25.619
Mean | 63832
MAD | 79195
Skewness | 4.341
Sum | 6279800000
Variance | 18902000000
Memory size | 768.8 KiB

user_time_zone
Categorical

Distinct count | 210
Unique (%) | 0.4%
Missing (%) | 41.3%
Missing (n) | 40653

Pacific Time (US & Canada) | 13368
Eastern Time (US & Canada) | 7112
London | 4476
Other values (206) | 32784
(Missing) | 40653

Toggle details

Value | Count | Frequency (%) |
Pacific Time (US & Canada) | 13368 | 13.6% |
Eastern Time (US & Canada) | 7112 | 7.2% |
London | 4476 | 4.5% |
Central Time (US & Canada) | 3656 | 3.7% |
Jakarta | 3275 | 3.3% |
Amsterdam | 1381 | 1.4% |
New Delhi | 1368 | 1.4% |
Atlantic Time (Canada) | 1178 | 1.2% |
Paris | 1162 | 1.2% |
Madrid | 980 | 1.0% |
Quito | 949 | 1.0% |
Mountain Time (US & Canada) | 856 | 0.9% |
Arizona | 839 | 0.9% |
Athens | 744 | 0.8% |
Brasilia | 714 | 0.7% |
Chennai | 665 | 0.7% |
Belgrade | 631 | 0.6% |
Berlin | 606 | 0.6% |
Buenos Aires | 598 | 0.6% |
Rome | 534 | 0.5% |
Other values (189) | 12648 | 12.9% |
(Missing) | 40653 | 41.3% |

user_url
Categorical

Distinct count | 19961
Unique (%) | 33.5%
Missing (%) | 39.4%
Missing (n) | 38739

https://t.co/LvNObmuCkf | 3254
http://t.co/8Q0jl1AtKI | 3035
https://t.co/Hl1m7P4xmV | 2921
Other values (19957) | 50444
(Missing) | 38739

Toggle details

Value | Count | Frequency (%) |
https://t.co/LvNObmuCkf | 3254 | 3.3% |
http://t.co/8Q0jl1AtKI | 3035 | 3.1% |
https://t.co/Hl1m7P4xmV | 2921 | 3.0% |
https://t.co/ZxdvO1ZaiT | 1001 | 1.0% |
https://t.co/P4ba2SMKJa | 938 | 1.0% |
https://t.co/34LPPFZfCm | 922 | 0.9% |
https://t.co/PygshDFQhI | 912 | 0.9% |
http://t.co/kLxn6Xf2Cs | 749 | 0.8% |
https://t.co/w7yC4guo2R | 431 | 0.4% |
http://t.co/1m4ijr2w8A | 375 | 0.4% |
https://t.co/VSX5CctduJ | 354 | 0.4% |
https://t.co/wNpsm4ziGC | 301 | 0.3% |
http://t.co/ZhoOQdg9HF | 243 | 0.2% |
http://t.co/PVtXT9K1OX | 232 | 0.2% |
https://t.co/dUzwcEMlDd | 217 | 0.2% |
https://t.co/dUzwcEuKLF | 205 | 0.2% |
https://t.co/un8gIvlDUI | 194 | 0.2% |
https://t.co/nOHhViYGqn | 173 | 0.2% |
https://t.co/KQQKa5yMTG | 172 | 0.2% |
http://t.co/v4V1PsslQt | 157 | 0.2% |
Other values (19940) | 42868 | 43.6% |
(Missing) | 38739 | 39.4% |

user_utc_offset
Numeric

Distinct count | 32
Unique (%) | 0.1%
Missing (%) | 41.3%
Missing (n) | 40653

Mean | -5418.3
Minimum | -39600
Maximum | 46800
Zeros (%) | 0.3%

Toggle details

Quantile statistics

Minimum | -39600
5-th percentile |
Q1 |
Median |
Q3 |
95-th percentile |
Maximum | 46800
Range | 86400
Interquartile range |

Descriptive statistics

Standard deviation | 18537
Coef of variation | -3.4212
Kurtosis | -0.91517
Mean | -5418.3
MAD | 16547
Skewness | 0.50367
Sum | -312850000
Variance | 343610000
Memory size | 768.8 KiB

user_verified
Categorical

Distinct count | 3
Unique (%) | 0.0%
Missing (%) | 0.0%
Missing (n) | 14

False | 98057
True | 322
(Missing) | 14

Toggle details

Value | Count | Frequency (%) |
False | 98057 | 99.7% |
True | 322 | 0.3% |
(Missing) | 14 | 0.0% |

# Sample

| coordinates_coordinates | coordinates_type | created_at | entities_hashtags | entities_media | entities_symbols | entities_urls | entities_user_mentions | favorite_count | favorited | geo_coordinates | geo_type | id_str | in_reply_to_screen_name | in_reply_to_status_id | in_reply_to_status_id_str | in_reply_to_user_id | in_reply_to_user_id_str | is_quote_status | lang | lat | lon | metadata_iso_language_code | metadata_result_type | place_bounding_box_coordinates | place_bounding_box_type | place_contained_within | place_country | place_country_code | place_full_name | place_id | place_name | place_place_type | place_url | possibly_sensitive | quoted_status_created_at | quoted_status_entities_hashtags | quoted_status_entities_symbols | quoted_status_entities_urls | quoted_status_entities_user_mentions | quoted_status_favorite_count | quoted_status_favorited | quoted_status_is_quote_status | quoted_status_lang | quoted_status_metadata_iso_language_code | quoted_status_metadata_result_type | quoted_status_possibly_sensitive | quoted_status_retweet_count | quoted_status_retweeted | quoted_status_source | quoted_status_text | quoted_status_truncated | quoted_status_user_contributors_enabled | quoted_status_user_created_at | quoted_status_user_default_profile | quoted_status_user_default_profile_image | quoted_status_user_description | quoted_status_user_entities_description_urls | quoted_status_user_entities_url_urls | quoted_status_user_favourites_count | quoted_status_user_followers_count | quoted_status_user_friends_count | quoted_status_user_geo_enabled | quoted_status_user_has_extended_profile | quoted_status_user_id | quoted_status_user_id_str | quoted_status_user_is_translation_enabled | quoted_status_user_is_translator | quoted_status_user_lang | quoted_status_user_listed_count | quoted_status_user_location | quoted_status_user_name | quoted_status_user_profile_background_color | quoted_status_user_profile_background_image_url | quoted_status_user_profile_background_image_url_https | quoted_status_user_profile_background_tile | quoted_status_user_profile_banner_url | quoted_status_user_profile_image_url | quoted_status_user_profile_image_url_https | quoted_status_user_profile_link_color | quoted_status_user_profile_sidebar_border_color | quoted_status_user_profile_sidebar_fill_color | quoted_status_user_profile_text_color | quoted_status_user_profile_use_background_image | quoted_status_user_protected | quoted_status_user_screen_name | quoted_status_user_statuses_count | quoted_status_user_time_zone | quoted_status_user_url | quoted_status_user_utc_offset | quoted_status_user_verified | retweet_count | retweeted | retweeted_status_created_at | retweeted_status_entities_hashtags | retweeted_status_entities_media | retweeted_status_entities_symbols | retweeted_status_entities_urls | retweeted_status_entities_user_mentions | retweeted_status_favorite_count | retweeted_status_favorited | retweeted_status_id | retweeted_status_id_str | retweeted_status_in_reply_to_screen_name | retweeted_status_in_reply_to_status_id | retweeted_status_in_reply_to_status_id_str | retweeted_status_in_reply_to_user_id | retweeted_status_in_reply_to_user_id_str | retweeted_status_is_quote_status | retweeted_status_lang | retweeted_status_metadata_iso_language_code | retweeted_status_metadata_result_type | retweeted_status_place_bounding_box_coordinates | retweeted_status_place_bounding_box_type | retweeted_status_place_contained_within | retweeted_status_place_country | retweeted_status_place_country_code | retweeted_status_place_full_name | retweeted_status_place_id | retweeted_status_place_name | retweeted_status_place_place_type | retweeted_status_place_url | retweeted_status_possibly_sensitive | retweeted_status_quoted_status_created_at | retweeted_status_quoted_status_entities_hashtags | retweeted_status_quoted_status_entities_media | retweeted_status_quoted_status_entities_symbols | retweeted_status_quoted_status_entities_urls | retweeted_status_quoted_status_entities_user_mentions | retweeted_status_quoted_status_favorite_count | retweeted_status_quoted_status_favorited | retweeted_status_quoted_status_is_quote_status | retweeted_status_quoted_status_lang | retweeted_status_quoted_status_metadata_iso_language_code | retweeted_status_quoted_status_metadata_result_type | retweeted_status_quoted_status_place_bounding_box_coordinates | retweeted_status_quoted_status_place_bounding_box_type | retweeted_status_quoted_status_place_contained_within | retweeted_status_quoted_status_place_country | retweeted_status_quoted_status_place_country_code | retweeted_status_quoted_status_place_full_name | retweeted_status_quoted_status_place_id | retweeted_status_quoted_status_place_name | retweeted_status_quoted_status_place_place_type | retweeted_status_quoted_status_place_url | retweeted_status_quoted_status_possibly_sensitive | retweeted_status_quoted_status_retweet_count | retweeted_status_quoted_status_retweeted | retweeted_status_quoted_status_source | retweeted_status_quoted_status_text | retweeted_status_quoted_status_truncated | retweeted_status_retweet_count | retweeted_status_retweeted | retweeted_status_source | retweeted_status_text | retweeted_status_truncated | retweeted_status_user_contributors_enabled | retweeted_status_user_created_at | retweeted_status_user_default_profile | retweeted_status_user_default_profile_image | retweeted_status_user_description | retweeted_status_user_entities_description_urls | retweeted_status_user_entities_url_urls | retweeted_status_user_favourites_count | retweeted_status_user_followers_count | retweeted_status_user_friends_count | retweeted_status_user_geo_enabled | retweeted_status_user_has_extended_profile | retweeted_status_user_id | retweeted_status_user_id_str | retweeted_status_user_is_translation_enabled | retweeted_status_user_is_translator | retweeted_status_user_lang | retweeted_status_user_listed_count | retweeted_status_user_location | retweeted_status_user_name | retweeted_status_user_profile_background_color | retweeted_status_user_profile_background_image_url | retweeted_status_user_profile_background_image_url_https | retweeted_status_user_profile_background_tile | retweeted_status_user_profile_banner_url | retweeted_status_user_profile_image_url | retweeted_status_user_profile_image_url_https | retweeted_status_user_profile_link_color | retweeted_status_user_profile_sidebar_border_color | retweeted_status_user_profile_sidebar_fill_color | retweeted_status_user_profile_text_color | retweeted_status_user_profile_use_background_image | retweeted_status_user_protected | retweeted_status_user_screen_name | retweeted_status_user_statuses_count | retweeted_status_user_time_zone | retweeted_status_user_url | retweeted_status_user_utc_offset | retweeted_status_user_verified | source | text | truncated | user_contributors_enabled | user_created_at | user_default_profile | user_default_profile_image | user_description | user_entities_description_urls | user_entities_url_urls | user_favourites_count | user_followers_count | user_friends_count | user_geo_enabled | user_has_extended_profile | user_id | user_id_str | user_is_translation_enabled | user_is_translator | user_lang | user_listed_count | user_location | user_name | user_profile_background_color | user_profile_background_image_url | user_profile_background_image_url_https | user_profile_background_tile | user_profile_banner_url | user_profile_image_url | user_profile_image_url_https | user_profile_link_color | user_profile_sidebar_border_color | user_profile_sidebar_fill_color | user_profile_text_color | user_profile_use_background_image | user_protected | user_screen_name | user_statuses_count | user_time_zone | user_url | user_utc_offset | user_verified | quoted_status_id | quoted_status_id_str | retweeted_status_quoted_status_id | retweeted_status_quoted_status_id_str
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
id |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
724281574129180672 | NaN | NaN | Sun Apr 24 16:59:18 +0000 2016 | [] | NaN | [] | [{u'url': u'https://t.co/HshSAeTMYc', u'indice... | [] | 0 | False | NaN | NaN | 724281574129180672 | NaN | NaN | NaN | NaN | NaN | False | en | NaN | NaN | en | recent | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | False | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 0.0 | False | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | <a href="http://twitterfeed.com" rel="nofollow... | World's Largest Python Discovered in Nepal: WA... | False | False | Tue Mar 24 14:13:53 +0000 2015 | True | False | NaN | [] | [{u'url': u'http://t.co/mkBfH8QmsX', u'indices... | 0.0 | 776.0 | 1910.0 | True | False | 3.110464e+09 | 3.110464e+09 | False | False | en | 4.0 | Lokoja, Kogi State, Nigeria. | Ukpe Thompson | C0DEED | http://abs.twimg.com/images/themes/theme1/bg.png | https://abs.twimg.com/images/themes/theme1/bg.png | False | https://pbs.twimg.com/profile_banners/31104639... | http://pbs.twimg.com/profile_images/5852217706... | https://pbs.twimg.com/profile_images/585221770... | 0084B4 | C0DEED | DDEEF6 | 333333 | True | False | newsymag | 2159.0 | Pacific Time (US & Canada) | http://t.co/mkBfH8QmsX | -25200.0 | False | -1.0 | -1.0 | -1.0 | -1.0
724281535587856384 | NaN | NaN | Sun Apr 24 16:59:09 +0000 2016 | [{u'indices': [109, 119], u'text': u'developer... | NaN | [] | [{u'url': u'https://t.co/m2mVrc3RrQ', u'indice... | [{u'indices': [23, 34], u'screen_name': u'Expe... | 0 | False | NaN | NaN | 724281535587856384 | NaN | NaN | NaN | NaN | NaN | False | en | NaN | NaN | en | recent | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | False | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 0.0 | False | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | <a href="http://bufferapp.com" rel="nofollow">... | "\xf0\x9f\x8e\xb7 \xf0\x9f\x92\x8e STOP! Could... | False | False | Sun Mar 10 22:59:25 +0000 2013 | False | False | THE best place to find a job at a startup. Bro... | [] | [{u'url': u'http://t.co/1ZmWTfHGbb', u'indices... | 105.0 | 2615.0 | 591.0 | False | False | 1.258139e+09 | 1.258139e+09 | True | False | en | 966.0 | London, UK | Unicorn Hunt | C0DEED | http://pbs.twimg.com/profile_background_images... | https://pbs.twimg.com/profile_background_image... | True | https://pbs.twimg.com/profile_banners/12581385... | http://pbs.twimg.com/profile_images/5611581146... | https://pbs.twimg.com/profile_images/561158114... | 0084B4 | FFFFFF | DDEEF6 | 333333 | True | False | unicornhuntio | 14193.0 | London | http://t.co/1ZmWTfHGbb | 3600.0 | False | -1.0 | -1.0 | -1.0 | -1.0
724281501622345729 | NaN | NaN | Sun Apr 24 16:59:01 +0000 2016 | [] | NaN | [] | [{u'url': u'https://t.co/OkNkEwTDy0', u'indice... | [] | 0 | False | NaN | NaN | 724281501622345729 | NaN | NaN | NaN | NaN | NaN | False | en | NaN | NaN | en | recent | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | False | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 0.0 | False | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | <a href="http://www.facebook.com/twitter" rel=... | My Little Python:Changing the world: Artist of... | False | False | Fri Aug 05 21:51:13 +0000 2011 | False | False | My Little Python is an effort to get people, e... | [] | [{u'url': u'http://t.co/qDaRIvSCJo', u'indices... | 11176.0 | 772.0 | 1248.0 | True | False | 3.492971e+08 | 3.492971e+08 | True | False | en | 85.0 | Serpentville | Pythons | 000000 | http://abs.twimg.com/images/themes/theme1/bg.png | https://abs.twimg.com/images/themes/theme1/bg.png | False | https://pbs.twimg.com/profile_banners/34929713... | http://pbs.twimg.com/profile_images/7068950313... | https://pbs.twimg.com/profile_images/706895031... | F5ABB5 | 000000 | 000000 | 000000 | False | False | mylittlepython | 18747.0 | Central Time (US & Canada) | http://t.co/qDaRIvSCJo | -18000.0 | False | -1.0 | -1.0 | -1.0 | -1.0
724281482357837825 | NaN | NaN | Sun Apr 24 16:58:56 +0000 2016 | [] | NaN | [] | [{u'url': u'https://t.co/fAscOq05Dl', u'indice... | [] | 0 | False | NaN | NaN | 724281482357837825 | NaN | NaN | NaN | NaN | NaN | False | en | NaN | NaN | en | recent | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | False | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 0.0 | False | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | <a href="http://twitterfeed.com" rel="nofollow... | Artist of the Day:Arder: This cute snake art c... | False | False | Fri Aug 05 21:51:13 +0000 2011 | False | False | My Little Python is an effort to get people, e... | [] | [{u'url': u'http://t.co/qDaRIvSCJo', u'indices... | 11176.0 | 772.0 | 1248.0 | True | False | 3.492971e+08 | 3.492971e+08 | True | False | en | 85.0 | Serpentville | Pythons | 000000 | http://abs.twimg.com/images/themes/theme1/bg.png | https://abs.twimg.com/images/themes/theme1/bg.png | False | https://pbs.twimg.com/profile_banners/34929713... | http://pbs.twimg.com/profile_images/7068950313... | https://pbs.twimg.com/profile_images/706895031... | F5ABB5 | 000000 | 000000 | 000000 | False | False | mylittlepython | 18747.0 | Central Time (US & Canada) | http://t.co/qDaRIvSCJo | -18000.0 | False | -1.0 | -1.0 | -1.0 | -1.0
724281441157300225 | NaN | NaN | Sun Apr 24 16:58:46 +0000 2016 | [{u'indices': [0, 7], u'text': u'python'}] | NaN | [] | [] | [] | 0 | False | NaN | NaN | 724281441157300225 | NaN | NaN | NaN | NaN | NaN | False | en | NaN | NaN | en | recent | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | 0.0 | False | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | NaN | <a href="http://twitter.com" rel="nofollow">Tw... | #python syntax seems to be a good pill against... | False | False | Sat Nov 17 07:33:05 +0000 2007 | True | False | Vilnius JUG and Vilnius Scala leader, software... | [] | [{u'url': u'http://t.co/BwyylijNJ8', u'indices... | 325.0 | 309.0 | 222.0 | False | False | 1.032677e+07 | 1.032677e+07 | False | False | en | 31.0 | Vilnius | Vaidas Pilkauskas | C0DEED | http://abs.twimg.com/images/themes/theme1/bg.png | https://abs.twimg.com/images/themes/theme1/bg.png | False | https://pbs.twimg.com/profile_banners/10326772... | http://pbs.twimg.com/profile_images/6134131342... | https://pbs.twimg.com/profile_images/613413134... | 0084B4 | C0DEED | DDEEF6 | 333333 | True | False | liucijus | 958.0 | Vilnius | http://t.co/BwyylijNJ8 | 10800.0 | False | -1.0 | -1.0 | -1.0 | -1.0